#if defined(TARGET_BUILTIN) && !defined(RISCVV_BUILTIN)
#define RISCVV_BUILTIN(ID, TYPE, ATTRS) TARGET_BUILTIN(ID, TYPE, ATTRS, "zve32x")
#endif
RISCVV_BUILTIN(__builtin_rvv_sf_vqmaccu_2x8x2,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vqmaccu_2x8x2_tu,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_x,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_x_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_i_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_xv_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_iv_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_vv_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_fv_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_xvv_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_ivv_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_vvv_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_fvv_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_x_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_i,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_i_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_xv,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_xv_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_iv,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_iv_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_vv,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_vv_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_fv,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_fv_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_xvv,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_xvv_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_ivv,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_ivv_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_vvv,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_vvv_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_fvv,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_fvv_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_xvw_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_ivw_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_vvw_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_fvw_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_xvw,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_xvw_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_ivw,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_ivw_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_vvw,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_vvw_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_fvw,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vc_v_fvw_se,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_x_f_qf_rm,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_x_f_qf_rm_tu,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_x_f_qf_rm_m,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_x_f_qf_rm_tum,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_x_f_qf_rm_tumu,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_x_f_qf_rm_mu,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vqmacc_2x8x2,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vqmacc_2x8x2_tu,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vqmaccus_2x8x2,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vqmaccus_2x8x2_tu,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vqmaccsu_2x8x2,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vqmaccsu_2x8x2_tu,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vqmaccu_4x8x4,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vqmaccu_4x8x4_tu,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vqmacc_4x8x4,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vqmacc_4x8x4_tu,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vqmaccus_4x8x4,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vqmaccus_4x8x4_tu,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vqmaccsu_4x8x4,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vqmaccsu_4x8x4_tu,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfwmacc_4x4x4,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfwmacc_4x4x4_tu,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_xu_f_qf_rm,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_xu_f_qf_rm_tu,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_xu_f_qf_rm_m,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_xu_f_qf_rm_tum,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_xu_f_qf_rm_tumu,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_xu_f_qf_rm_mu,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_x_f_qf,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_x_f_qf_tu,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_x_f_qf_m,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_x_f_qf_tum,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_x_f_qf_tumu,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_x_f_qf_mu,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_xu_f_qf,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_xu_f_qf_tu,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_xu_f_qf_m,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_xu_f_qf_tum,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_xu_f_qf_tumu,"", "n")
RISCVV_BUILTIN(__builtin_rvv_sf_vfnrclip_xu_f_qf_mu,"", "n")
#undef RISCVV_BUILTIN
