#ifdef GET_SVE_BUILTINS
TARGET_BUILTIN(__builtin_sve_svaba_n_s16, "q8sq8sq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaba_n_s32, "q4iq4iq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaba_n_s64, "q2Wiq2Wiq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaba_n_s8, "q16Scq16Scq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaba_n_u16, "q8Usq8Usq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaba_n_u32, "q4Uiq4Uiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaba_n_u64, "q2UWiq2UWiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaba_n_u8, "q16Ucq16Ucq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaba_s16, "q8sq8sq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaba_s32, "q4iq4iq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaba_s64, "q2Wiq2Wiq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaba_s8, "q16Scq16Scq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaba_u16, "q8Usq8Usq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaba_u32, "q4Uiq4Uiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaba_u64, "q2UWiq2UWiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaba_u8, "q16Ucq16Ucq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalb_n_s16, "q8sq8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalb_n_s32, "q4iq4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalb_n_s64, "q2Wiq2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalb_n_u16, "q8Usq8Usq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalb_n_u32, "q4Uiq4Uiq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalb_n_u64, "q2UWiq2UWiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalb_s16, "q8sq8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalb_s32, "q4iq4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalb_s64, "q2Wiq2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalb_u16, "q8Usq8Usq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalb_u32, "q4Uiq4Uiq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalb_u64, "q2UWiq2UWiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalt_n_s16, "q8sq8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalt_n_s32, "q4iq4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalt_n_s64, "q2Wiq2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalt_n_u16, "q8Usq8Usq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalt_n_u32, "q4Uiq4Uiq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalt_n_u64, "q2UWiq2UWiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalt_s16, "q8sq8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalt_s32, "q4iq4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalt_s64, "q2Wiq2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalt_u16, "q8Usq8Usq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalt_u32, "q4Uiq4Uiq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabalt_u64, "q2UWiq2UWiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabd_f16_m, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_f16_x, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_f16_z, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_f32_m, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_f32_x, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_f32_z, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_f64_m, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_f64_x, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_f64_z, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_f16_m, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_f16_x, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_f16_z, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_f32_m, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_f32_x, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_f32_z, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_f64_m, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_f64_x, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_f64_z, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_s16_m, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_s16_x, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_s16_z, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_s32_m, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_s32_x, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_s32_z, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_s64_m, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_s64_x, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_s64_z, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_s8_m, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_s8_x, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_s8_z, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_u16_m, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_u16_x, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_u16_z, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_u32_m, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_u32_x, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_u32_z, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_u8_m, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_u8_x, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_n_u8_z, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_s16_m, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_s16_x, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_s16_z, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_s32_m, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_s32_x, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_s32_z, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_s8_m, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_s8_x, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_s8_z, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_u16_m, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_u16_x, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_u16_z, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabd_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabdlb_n_s16, "q8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlb_n_s32, "q4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlb_n_s64, "q2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlb_n_u16, "q8Usq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlb_n_u32, "q4Uiq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlb_n_u64, "q2UWiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlb_s16, "q8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlb_s32, "q4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlb_s64, "q2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlb_u16, "q8Usq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlb_u32, "q4Uiq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlb_u64, "q2UWiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlt_n_s16, "q8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlt_n_s32, "q4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlt_n_s64, "q2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlt_n_u16, "q8Usq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlt_n_u32, "q4Uiq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlt_n_u64, "q2UWiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlt_s16, "q8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlt_s32, "q4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlt_s64, "q2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlt_u16, "q8Usq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlt_u32, "q4Uiq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabdlt_u64, "q2UWiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svabs_f16_m, "q8hq8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabs_f16_x, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabs_f16_z, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabs_f32_m, "q4fq4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabs_f32_x, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabs_f32_z, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabs_f64_m, "q2dq2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabs_f64_x, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabs_f64_z, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabs_s16_m, "q8sq8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabs_s16_x, "q8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabs_s16_z, "q8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabs_s32_m, "q4iq4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabs_s32_x, "q4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabs_s32_z, "q4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabs_s64_m, "q2Wiq2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabs_s64_x, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabs_s64_z, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabs_s8_m, "q16Scq16Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabs_s8_x, "q16Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svabs_s8_z, "q16Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svacge_f16, "q16bq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svacge_f32, "q16bq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svacge_f64, "q16bq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svacge_n_f16, "q16bq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svacge_n_f32, "q16bq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svacge_n_f64, "q16bq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svacgt_f16, "q16bq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svacgt_f32, "q16bq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svacgt_f64, "q16bq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svacgt_n_f16, "q16bq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svacgt_n_f32, "q16bq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svacgt_n_f64, "q16bq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svacle_f16, "q16bq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svacle_f32, "q16bq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svacle_f64, "q16bq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svacle_n_f16, "q16bq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svacle_n_f32, "q16bq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svacle_n_f64, "q16bq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svaclt_f16, "q16bq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svaclt_f32, "q16bq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svaclt_f64, "q16bq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svaclt_n_f16, "q16bq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svaclt_n_f32, "q16bq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svaclt_n_f64, "q16bq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadalp_s16_m, "q8sq16bq8sq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadalp_s16_x, "q8sq16bq8sq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadalp_s16_z, "q8sq16bq8sq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadalp_s32_m, "q4iq16bq4iq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadalp_s32_x, "q4iq16bq4iq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadalp_s32_z, "q4iq16bq4iq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadalp_s64_m, "q2Wiq16bq2Wiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadalp_s64_x, "q2Wiq16bq2Wiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadalp_s64_z, "q2Wiq16bq2Wiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadalp_u16_m, "q8Usq16bq8Usq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadalp_u16_x, "q8Usq16bq8Usq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadalp_u16_z, "q8Usq16bq8Usq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadalp_u32_m, "q4Uiq16bq4Uiq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadalp_u32_x, "q4Uiq16bq4Uiq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadalp_u32_z, "q4Uiq16bq4Uiq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadalp_u64_m, "q2UWiq16bq2UWiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadalp_u64_x, "q2UWiq16bq2UWiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadalp_u64_z, "q2UWiq16bq2UWiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadclb_n_u32, "q4Uiq4Uiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadclb_n_u64, "q2UWiq2UWiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadclb_u32, "q4Uiq4Uiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadclb_u64, "q2UWiq2UWiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadclt_n_u32, "q4Uiq4Uiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadclt_n_u64, "q2UWiq2UWiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadclt_u32, "q4Uiq4Uiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadclt_u64, "q2UWiq2UWiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadd_bf16_m, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svadd_bf16_x, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svadd_bf16_z, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svadd_f16_m, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_f16_x, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_f16_z, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_f32_m, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_f32_x, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_f32_z, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_f64_m, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_f64_x, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_f64_z, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_bf16_m, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svadd_n_bf16_x, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svadd_n_bf16_z, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svadd_n_f16_m, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_f16_x, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_f16_z, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_f32_m, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_f32_x, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_f32_z, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_f64_m, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_f64_x, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_f64_z, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_s16_m, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_s16_x, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_s16_z, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_s32_m, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_s32_x, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_s32_z, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_s64_m, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_s64_x, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_s64_z, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_s8_m, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_s8_x, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_s8_z, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_u16_m, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_u16_x, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_u16_z, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_u32_m, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_u32_x, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_u32_z, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_u8_m, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_u8_x, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_n_u8_z, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_s16_m, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_s16_x, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_s16_z, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_s32_m, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_s32_x, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_s32_z, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_s8_m, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_s8_x, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_s8_z, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_single_s16_x2, "q16sq16sq8s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svadd_single_s16_x4, "q32sq32sq8s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svadd_single_s32_x2, "q8iq8iq4i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svadd_single_s32_x4, "q16iq16iq4i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svadd_single_s64_x2, "q4Wiq4Wiq2Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svadd_single_s64_x4, "q8Wiq8Wiq2Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svadd_single_s8_x2, "q32Scq32Scq16Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svadd_single_s8_x4, "q64Scq64Scq16Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svadd_single_u16_x2, "q16Usq16Usq8Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svadd_single_u16_x4, "q32Usq32Usq8Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svadd_single_u32_x2, "q8Uiq8Uiq4Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svadd_single_u32_x4, "q16Uiq16Uiq4Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svadd_single_u64_x2, "q4UWiq4UWiq2UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svadd_single_u64_x4, "q8UWiq8UWiq2UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svadd_single_u8_x2, "q32Ucq32Ucq16Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svadd_single_u8_x4, "q64Ucq64Ucq16Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svadd_u16_m, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_u16_x, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_u16_z, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadd_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svadda_f16, "hq16bhq8h", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svadda_f32, "fq16bfq4f", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svadda_f64, "dq16bdq2d", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svaddhnb_n_s16, "q16Scq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnb_n_s32, "q8sq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnb_n_s64, "q4iq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnb_n_u16, "q16Ucq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnb_n_u32, "q8Usq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnb_n_u64, "q4Uiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnb_s16, "q16Scq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnb_s32, "q8sq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnb_s64, "q4iq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnb_u16, "q16Ucq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnb_u32, "q8Usq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnb_u64, "q4Uiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnt_n_s16, "q16Scq16Scq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnt_n_s32, "q8sq8sq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnt_n_s64, "q4iq4iq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnt_n_u16, "q16Ucq16Ucq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnt_n_u32, "q8Usq8Usq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnt_n_u64, "q4Uiq4Uiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnt_s16, "q16Scq16Scq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnt_s32, "q8sq8sq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnt_s64, "q4iq4iq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnt_u16, "q16Ucq16Ucq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnt_u32, "q8Usq8Usq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddhnt_u64, "q4Uiq4Uiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlb_n_s16, "q8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlb_n_s32, "q4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlb_n_s64, "q2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlb_n_u16, "q8Usq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlb_n_u32, "q4Uiq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlb_n_u64, "q2UWiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlb_s16, "q8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlb_s32, "q4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlb_s64, "q2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlb_u16, "q8Usq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlb_u32, "q4Uiq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlb_u64, "q2UWiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlbt_n_s16, "q8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlbt_n_s32, "q4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlbt_n_s64, "q2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlbt_s16, "q8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlbt_s32, "q4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlbt_s64, "q2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlt_n_s16, "q8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlt_n_s32, "q4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlt_n_s64, "q2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlt_n_u16, "q8Usq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlt_n_u32, "q4Uiq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlt_n_u64, "q2UWiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlt_s16, "q8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlt_s32, "q4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlt_s64, "q2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlt_u16, "q8Usq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlt_u32, "q4Uiq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddlt_u64, "q2UWiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_f16_m, "q8hq16bq8hq8h", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_f16_x, "q8hq16bq8hq8h", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_f32_m, "q4fq16bq4fq4f", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_f32_x, "q4fq16bq4fq4f", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_f64_m, "q2dq16bq2dq2d", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_f64_x, "q2dq16bq2dq2d", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_s16_m, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_s16_x, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_s32_m, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_s32_x, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_s8_m, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_s8_x, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_u16_m, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_u16_x, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddp_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddqv_f16, "V8hq16bq8h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svaddqv_f32, "V4fq16bq4f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svaddqv_f64, "V2dq16bq2d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svaddqv_s16, "V8sq16bq8s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svaddqv_s32, "V4iq16bq4i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svaddqv_s64, "V2Wiq16bq2Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svaddqv_s8, "V16Scq16bq16Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svaddqv_u16, "V8Usq16bq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svaddqv_u32, "V4Uiq16bq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svaddqv_u64, "V2UWiq16bq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svaddqv_u8, "V16Ucq16bq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svaddv_f16, "hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svaddv_f32, "fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svaddv_f64, "dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svaddv_s16, "Wiq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svaddv_s32, "Wiq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svaddv_s64, "Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svaddv_s8, "Wiq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svaddv_u16, "UWiq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svaddv_u32, "UWiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svaddv_u64, "UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svaddv_u8, "UWiq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svaddwb_n_s16, "q8sq8sSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwb_n_s32, "q4iq4is", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwb_n_s64, "q2Wiq2Wii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwb_n_u16, "q8Usq8UsUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwb_n_u32, "q4Uiq4UiUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwb_n_u64, "q2UWiq2UWiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwb_s16, "q8sq8sq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwb_s32, "q4iq4iq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwb_s64, "q2Wiq2Wiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwb_u16, "q8Usq8Usq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwb_u32, "q4Uiq4Uiq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwb_u64, "q2UWiq2UWiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwt_n_s16, "q8sq8sSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwt_n_s32, "q4iq4is", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwt_n_s64, "q2Wiq2Wii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwt_n_u16, "q8Usq8UsUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwt_n_u32, "q4Uiq4UiUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwt_n_u64, "q2UWiq2UWiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwt_s16, "q8sq8sq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwt_s32, "q4iq4iq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwt_s64, "q2Wiq2Wiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwt_u16, "q8Usq8Usq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwt_u32, "q4Uiq4Uiq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svaddwt_u64, "q2UWiq2UWiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svadrb_u32base_s32offset, "q4Uiq4Uiq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svadrb_u32base_u32offset, "q4Uiq4Uiq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svadrb_u64base_s64offset, "q2UWiq2UWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svadrb_u64base_u64offset, "q2UWiq2UWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svadrd_u32base_s32index, "q4Uiq4Uiq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svadrd_u32base_u32index, "q4Uiq4Uiq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svadrd_u64base_s64index, "q2UWiq2UWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svadrd_u64base_u64index, "q2UWiq2UWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svadrh_u32base_s32index, "q4Uiq4Uiq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svadrh_u32base_u32index, "q4Uiq4Uiq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svadrh_u64base_s64index, "q2UWiq2UWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svadrh_u64base_u64index, "q2UWiq2UWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svadrw_u32base_s32index, "q4Uiq4Uiq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svadrw_u32base_u32index, "q4Uiq4Uiq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svadrw_u64base_s64index, "q2UWiq2UWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svadrw_u64base_u64index, "q2UWiq2UWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svaesd_u8, "q16Ucq16Ucq16Uc", "n", "sve,sve2,sve-aes")
TARGET_BUILTIN(__builtin_sve_svaese_u8, "q16Ucq16Ucq16Uc", "n", "sve,sve2,sve-aes")
TARGET_BUILTIN(__builtin_sve_svaesimc_u8, "q16Ucq16Uc", "n", "sve,sve2,sve-aes")
TARGET_BUILTIN(__builtin_sve_svaesmc_u8, "q16Ucq16Uc", "n", "sve,sve2,sve-aes")
TARGET_BUILTIN(__builtin_sve_svamax_f16_m, "q8hq16bq8hq8h", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamax_f16_x, "q8hq16bq8hq8h", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamax_f16_x2, "q16hq16hq16h", "n", "sme,sme2,faminmax")
TARGET_BUILTIN(__builtin_sve_svamax_f16_x4, "q32hq32hq32h", "n", "sme,sme2,faminmax")
TARGET_BUILTIN(__builtin_sve_svamax_f16_z, "q8hq16bq8hq8h", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamax_f32_m, "q4fq16bq4fq4f", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamax_f32_x, "q4fq16bq4fq4f", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamax_f32_x2, "q8fq8fq8f", "n", "sme,sme2,faminmax")
TARGET_BUILTIN(__builtin_sve_svamax_f32_x4, "q16fq16fq16f", "n", "sme,sme2,faminmax")
TARGET_BUILTIN(__builtin_sve_svamax_f32_z, "q4fq16bq4fq4f", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamax_f64_m, "q2dq16bq2dq2d", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamax_f64_x, "q2dq16bq2dq2d", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamax_f64_x2, "q4dq4dq4d", "n", "sme,sme2,faminmax")
TARGET_BUILTIN(__builtin_sve_svamax_f64_x4, "q8dq8dq8d", "n", "sme,sme2,faminmax")
TARGET_BUILTIN(__builtin_sve_svamax_f64_z, "q2dq16bq2dq2d", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamax_n_f16_m, "q8hq16bq8hh", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamax_n_f16_x, "q8hq16bq8hh", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamax_n_f16_z, "q8hq16bq8hh", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamax_n_f32_m, "q4fq16bq4ff", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamax_n_f32_x, "q4fq16bq4ff", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamax_n_f32_z, "q4fq16bq4ff", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamax_n_f64_m, "q2dq16bq2dd", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamax_n_f64_x, "q2dq16bq2dd", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamax_n_f64_z, "q2dq16bq2dd", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamin_f16_m, "q8hq16bq8hq8h", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamin_f16_x, "q8hq16bq8hq8h", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamin_f16_x2, "q16hq16hq16h", "n", "sme,sme2,faminmax")
TARGET_BUILTIN(__builtin_sve_svamin_f16_x4, "q32hq32hq32h", "n", "sme,sme2,faminmax")
TARGET_BUILTIN(__builtin_sve_svamin_f16_z, "q8hq16bq8hq8h", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamin_f32_m, "q4fq16bq4fq4f", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamin_f32_x, "q4fq16bq4fq4f", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamin_f32_x2, "q8fq8fq8f", "n", "sme,sme2,faminmax")
TARGET_BUILTIN(__builtin_sve_svamin_f32_x4, "q16fq16fq16f", "n", "sme,sme2,faminmax")
TARGET_BUILTIN(__builtin_sve_svamin_f32_z, "q4fq16bq4fq4f", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamin_f64_m, "q2dq16bq2dq2d", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamin_f64_x, "q2dq16bq2dq2d", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamin_f64_x2, "q4dq4dq4d", "n", "sme,sme2,faminmax")
TARGET_BUILTIN(__builtin_sve_svamin_f64_x4, "q8dq8dq8d", "n", "sme,sme2,faminmax")
TARGET_BUILTIN(__builtin_sve_svamin_f64_z, "q2dq16bq2dq2d", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamin_n_f16_m, "q8hq16bq8hh", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamin_n_f16_x, "q8hq16bq8hh", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamin_n_f16_z, "q8hq16bq8hh", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamin_n_f32_m, "q4fq16bq4ff", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamin_n_f32_x, "q4fq16bq4ff", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamin_n_f32_z, "q4fq16bq4ff", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamin_n_f64_m, "q2dq16bq2dd", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamin_n_f64_x, "q2dq16bq2dd", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svamin_n_f64_z, "q2dq16bq2dd", "n", "(sve,sve2,faminmax)|(sme,sme2,faminmax)")
TARGET_BUILTIN(__builtin_sve_svand_b_z, "q16bq16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_s16_m, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_s16_x, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_s16_z, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_s32_m, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_s32_x, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_s32_z, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_s64_m, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_s64_x, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_s64_z, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_s8_m, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_s8_x, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_s8_z, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_u16_m, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_u16_x, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_u16_z, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_u32_m, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_u32_x, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_u32_z, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_u8_m, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_u8_x, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_n_u8_z, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_s16_m, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_s16_x, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_s16_z, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_s32_m, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_s32_x, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_s32_z, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_s8_m, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_s8_x, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_s8_z, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_u16_m, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_u16_x, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_u16_z, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svand_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svandqv_s16, "V8sq16bq8s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svandqv_s32, "V4iq16bq4i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svandqv_s64, "V2Wiq16bq2Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svandqv_s8, "V16Scq16bq16Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svandqv_u16, "V8Usq16bq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svandqv_u32, "V4Uiq16bq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svandqv_u64, "V2UWiq16bq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svandqv_u8, "V16Ucq16bq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svandv_s16, "sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svandv_s32, "iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svandv_s64, "Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svandv_s8, "Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svandv_u16, "Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svandv_u32, "Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svandv_u64, "UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svandv_u8, "Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_n_s16_m, "q8sq16bq8sUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_n_s16_x, "q8sq16bq8sUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_n_s16_z, "q8sq16bq8sUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_n_s32_m, "q4iq16bq4iUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_n_s32_x, "q4iq16bq4iUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_n_s32_z, "q4iq16bq4iUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_n_s64_m, "q2Wiq16bq2WiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_n_s64_x, "q2Wiq16bq2WiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_n_s64_z, "q2Wiq16bq2WiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_n_s8_m, "q16Scq16bq16ScUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_n_s8_x, "q16Scq16bq16ScUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_n_s8_z, "q16Scq16bq16ScUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_s16_m, "q8sq16bq8sq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_s16_x, "q8sq16bq8sq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_s16_z, "q8sq16bq8sq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_s32_m, "q4iq16bq4iq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_s32_x, "q4iq16bq4iq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_s32_z, "q4iq16bq4iq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_s64_m, "q2Wiq16bq2Wiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_s64_x, "q2Wiq16bq2Wiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_s64_z, "q2Wiq16bq2Wiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_s8_m, "q16Scq16bq16Scq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_s8_x, "q16Scq16bq16Scq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_s8_z, "q16Scq16bq16Scq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_wide_n_s16_m, "q8sq16bq8sUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_wide_n_s16_x, "q8sq16bq8sUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_wide_n_s16_z, "q8sq16bq8sUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_wide_n_s32_m, "q4iq16bq4iUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_wide_n_s32_x, "q4iq16bq4iUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_wide_n_s32_z, "q4iq16bq4iUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_wide_n_s8_m, "q16Scq16bq16ScUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_wide_n_s8_x, "q16Scq16bq16ScUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_wide_n_s8_z, "q16Scq16bq16ScUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_wide_s16_m, "q8sq16bq8sq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_wide_s16_x, "q8sq16bq8sq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_wide_s16_z, "q8sq16bq8sq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_wide_s32_m, "q4iq16bq4iq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_wide_s32_x, "q4iq16bq4iq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_wide_s32_z, "q4iq16bq4iq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_wide_s8_m, "q16Scq16bq16Scq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_wide_s8_x, "q16Scq16bq16Scq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasr_wide_s8_z, "q16Scq16bq16Scq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasrd_n_s16_m, "q8sq16bq8sIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasrd_n_s16_x, "q8sq16bq8sIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasrd_n_s16_z, "q8sq16bq8sIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasrd_n_s32_m, "q4iq16bq4iIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasrd_n_s32_x, "q4iq16bq4iIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasrd_n_s32_z, "q4iq16bq4iIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasrd_n_s64_m, "q2Wiq16bq2WiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasrd_n_s64_x, "q2Wiq16bq2WiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasrd_n_s64_z, "q2Wiq16bq2WiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasrd_n_s8_m, "q16Scq16bq16ScIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasrd_n_s8_x, "q16Scq16bq16ScIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svasrd_n_s8_z, "q16Scq16bq16ScIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbcax_n_s16, "q8sq8sq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbcax_n_s32, "q4iq4iq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbcax_n_s64, "q2Wiq2Wiq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbcax_n_s8, "q16Scq16Scq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbcax_n_u16, "q8Usq8Usq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbcax_n_u32, "q4Uiq4Uiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbcax_n_u64, "q2UWiq2UWiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbcax_n_u8, "q16Ucq16Ucq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbcax_s16, "q8sq8sq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbcax_s32, "q4iq4iq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbcax_s64, "q2Wiq2Wiq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbcax_s8, "q16Scq16Scq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbcax_u16, "q8Usq8Usq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbcax_u32, "q4Uiq4Uiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbcax_u64, "q2UWiq2UWiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbcax_u8, "q16Ucq16Ucq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbdep_n_u16, "q8Usq8UsUs", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbdep_n_u32, "q4Uiq4UiUi", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbdep_n_u64, "q2UWiq2UWiUWi", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbdep_n_u8, "q16Ucq16UcUc", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbdep_u16, "q8Usq8Usq8Us", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbdep_u32, "q4Uiq4Uiq4Ui", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbdep_u64, "q2UWiq2UWiq2UWi", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbdep_u8, "q16Ucq16Ucq16Uc", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbext_n_u16, "q8Usq8UsUs", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbext_n_u32, "q4Uiq4UiUi", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbext_n_u64, "q2UWiq2UWiUWi", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbext_n_u8, "q16Ucq16UcUc", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbext_u16, "q8Usq8Usq8Us", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbext_u32, "q4Uiq4Uiq4Ui", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbext_u64, "q2UWiq2UWiq2UWi", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbext_u8, "q16Ucq16Ucq16Uc", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbfdot_f32, "q4fq4fq8yq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svbfdot_lane_f32, "q4fq4fq8yq8yIUWi", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svbfdot_n_f32, "q4fq4fq8yy", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svbfmlalb_f32, "q4fq4fq8yq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svbfmlalb_lane_f32, "q4fq4fq8yq8yIUWi", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svbfmlalb_n_f32, "q4fq4fq8yy", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svbfmlalt_f32, "q4fq4fq8yq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svbfmlalt_lane_f32, "q4fq4fq8yq8yIUWi", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svbfmlalt_n_f32, "q4fq4fq8yy", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svbfmlslb_f32, "q4fq4fq8yq8y", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svbfmlslb_lane_f32, "q4fq4fq8yq8yIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svbfmlslt_f32, "q4fq4fq8yq8y", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svbfmlslt_lane_f32, "q4fq4fq8yq8yIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svbfmmla_f32, "q4fq4fq8yq8y", "n", "sve,bf16")
TARGET_BUILTIN(__builtin_sve_svbgrp_n_u16, "q8Usq8UsUs", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbgrp_n_u32, "q4Uiq4UiUi", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbgrp_n_u64, "q2UWiq2UWiUWi", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbgrp_n_u8, "q16Ucq16UcUc", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbgrp_u16, "q8Usq8Usq8Us", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbgrp_u32, "q4Uiq4Uiq4Ui", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbgrp_u64, "q2UWiq2UWiq2UWi", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbgrp_u8, "q16Ucq16Ucq16Uc", "n", "sve,sve2,sve-bitperm")
TARGET_BUILTIN(__builtin_sve_svbic_b_z, "q16bq16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_s16_m, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_s16_x, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_s16_z, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_s32_m, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_s32_x, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_s32_z, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_s64_m, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_s64_x, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_s64_z, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_s8_m, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_s8_x, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_s8_z, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_u16_m, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_u16_x, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_u16_z, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_u32_m, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_u32_x, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_u32_z, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_u8_m, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_u8_x, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_n_u8_z, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_s16_m, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_s16_x, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_s16_z, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_s32_m, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_s32_x, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_s32_z, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_s8_m, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_s8_x, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_s8_z, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_u16_m, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_u16_x, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_u16_z, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbic_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbrka_b_m, "q16bq16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbrka_b_z, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbrkb_b_m, "q16bq16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbrkb_b_z, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbrkn_b_z, "q16bq16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbrkpa_b_z, "q16bq16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbrkpb_b_z, "q16bq16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svbsl1n_n_s16, "q8sq8sq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl1n_n_s32, "q4iq4iq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl1n_n_s64, "q2Wiq2Wiq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl1n_n_s8, "q16Scq16Scq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl1n_n_u16, "q8Usq8Usq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl1n_n_u32, "q4Uiq4Uiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl1n_n_u64, "q2UWiq2UWiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl1n_n_u8, "q16Ucq16Ucq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl1n_s16, "q8sq8sq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl1n_s32, "q4iq4iq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl1n_s64, "q2Wiq2Wiq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl1n_s8, "q16Scq16Scq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl1n_u16, "q8Usq8Usq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl1n_u32, "q4Uiq4Uiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl1n_u64, "q2UWiq2UWiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl1n_u8, "q16Ucq16Ucq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl2n_n_s16, "q8sq8sq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl2n_n_s32, "q4iq4iq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl2n_n_s64, "q2Wiq2Wiq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl2n_n_s8, "q16Scq16Scq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl2n_n_u16, "q8Usq8Usq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl2n_n_u32, "q4Uiq4Uiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl2n_n_u64, "q2UWiq2UWiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl2n_n_u8, "q16Ucq16Ucq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl2n_s16, "q8sq8sq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl2n_s32, "q4iq4iq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl2n_s64, "q2Wiq2Wiq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl2n_s8, "q16Scq16Scq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl2n_u16, "q8Usq8Usq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl2n_u32, "q4Uiq4Uiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl2n_u64, "q2UWiq2UWiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl2n_u8, "q16Ucq16Ucq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl_n_s16, "q8sq8sq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl_n_s32, "q4iq4iq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl_n_s64, "q2Wiq2Wiq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl_n_s8, "q16Scq16Scq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl_n_u16, "q8Usq8Usq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl_n_u32, "q4Uiq4Uiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl_n_u64, "q2UWiq2UWiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl_n_u8, "q16Ucq16Ucq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl_s16, "q8sq8sq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl_s32, "q4iq4iq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl_s64, "q2Wiq2Wiq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl_s8, "q16Scq16Scq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl_u16, "q8Usq8Usq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl_u32, "q4Uiq4Uiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl_u64, "q2UWiq2UWiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svbsl_u8, "q16Ucq16Ucq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcadd_f16_m, "q8hq16bq8hq8hIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcadd_f16_x, "q8hq16bq8hq8hIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcadd_f16_z, "q8hq16bq8hq8hIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcadd_f32_m, "q4fq16bq4fq4fIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcadd_f32_x, "q4fq16bq4fq4fIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcadd_f32_z, "q4fq16bq4fq4fIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcadd_f64_m, "q2dq16bq2dq2dIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcadd_f64_x, "q2dq16bq2dq2dIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcadd_f64_z, "q2dq16bq2dq2dIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcadd_s16, "q8sq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcadd_s32, "q4iq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcadd_s64, "q2Wiq2Wiq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcadd_s8, "q16Scq16Scq16ScIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcadd_u16, "q8Usq8Usq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcadd_u32, "q4Uiq4Uiq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcadd_u64, "q2UWiq2UWiq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcadd_u8, "q16Ucq16Ucq16UcIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcdot_lane_s32, "q4iq4iq16Scq16ScIUWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcdot_lane_s64, "q2Wiq2Wiq8sq8sIUWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcdot_s32, "q4iq4iq16Scq16ScIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcdot_s64, "q2Wiq2Wiq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svclamp_bf16, "q8yq8yq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svclamp_f16, "q8hq8hq8hq8h", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svclamp_f32, "q4fq4fq4fq4f", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svclamp_f64, "q2dq2dq2dq2d", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svclamp_s16, "q8sq8sq8sq8s", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svclamp_s32, "q4iq4iq4iq4i", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svclamp_s64, "q2Wiq2Wiq2Wiq2Wi", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svclamp_s8, "q16Scq16Scq16Scq16Sc", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svclamp_single_bf16_x2, "q16yq16yq8yq8y", "n", "sme,sme2,sve-b16b16")
TARGET_BUILTIN(__builtin_sve_svclamp_single_bf16_x4, "q32yq32yq8yq8y", "n", "sme,sme2,sve-b16b16")
TARGET_BUILTIN(__builtin_sve_svclamp_single_f16_x2, "q16hq16hq8hq8h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_f16_x4, "q32hq32hq8hq8h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_f32_x2, "q8fq8fq4fq4f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_f32_x4, "q16fq16fq4fq4f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_f64_x2, "q4dq4dq2dq2d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_f64_x4, "q8dq8dq2dq2d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_s16_x2, "q16sq16sq8sq8s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_s16_x4, "q32sq32sq8sq8s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_s32_x2, "q8iq8iq4iq4i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_s32_x4, "q16iq16iq4iq4i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_s64_x2, "q4Wiq4Wiq2Wiq2Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_s64_x4, "q8Wiq8Wiq2Wiq2Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_s8_x2, "q32Scq32Scq16Scq16Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_s8_x4, "q64Scq64Scq16Scq16Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_u16_x2, "q16Usq16Usq8Usq8Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_u16_x4, "q32Usq32Usq8Usq8Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_u32_x2, "q8Uiq8Uiq4Uiq4Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_u32_x4, "q16Uiq16Uiq4Uiq4Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_u64_x2, "q4UWiq4UWiq2UWiq2UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_u64_x4, "q8UWiq8UWiq2UWiq2UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_u8_x2, "q32Ucq32Ucq16Ucq16Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_single_u8_x4, "q64Ucq64Ucq16Ucq16Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svclamp_u16, "q8Usq8Usq8Usq8Us", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svclamp_u32, "q4Uiq4Uiq4Uiq4Ui", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svclamp_u64, "q2UWiq2UWiq2UWiq2UWi", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svclamp_u8, "q16Ucq16Ucq16Ucq16Uc", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_bf16, "q8yq16bq8yq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svclasta_f16, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_f32, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_f64, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_n_bf16, "yq16byq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svclasta_n_f16, "hq16bhq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_n_f32, "fq16bfq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_n_f64, "dq16bdq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_n_s16, "sq16bsq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_n_s32, "iq16biq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_n_s64, "Wiq16bWiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_n_s8, "Scq16bScq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_n_u16, "Usq16bUsq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_n_u32, "Uiq16bUiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_n_u64, "UWiq16bUWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_n_u8, "Ucq16bUcq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_s16, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_s32, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_s64, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_s8, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_u16, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_u32, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_u64, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclasta_u8, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_bf16, "q8yq16bq8yq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svclastb_f16, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_f32, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_f64, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_n_bf16, "yq16byq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svclastb_n_f16, "hq16bhq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_n_f32, "fq16bfq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_n_f64, "dq16bdq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_n_s16, "sq16bsq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_n_s32, "iq16biq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_n_s64, "Wiq16bWiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_n_s8, "Scq16bScq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_n_u16, "Usq16bUsq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_n_u32, "Uiq16bUiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_n_u64, "UWiq16bUWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_n_u8, "Ucq16bUcq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_s16, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_s32, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_s64, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_s8, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_u16, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_u32, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_u64, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclastb_u8, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcls_s16_m, "q8Usq8Usq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcls_s16_x, "q8Usq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcls_s16_z, "q8Usq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcls_s32_m, "q4Uiq4Uiq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcls_s32_x, "q4Uiq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcls_s32_z, "q4Uiq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcls_s64_m, "q2UWiq2UWiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcls_s64_x, "q2UWiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcls_s64_z, "q2UWiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcls_s8_m, "q16Ucq16Ucq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcls_s8_x, "q16Ucq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcls_s8_z, "q16Ucq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_s16_m, "q8Usq8Usq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_s16_x, "q8Usq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_s16_z, "q8Usq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_s32_m, "q4Uiq4Uiq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_s32_x, "q4Uiq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_s32_z, "q4Uiq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_s64_m, "q2UWiq2UWiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_s64_x, "q2UWiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_s64_z, "q2UWiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_s8_m, "q16Ucq16Ucq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_s8_x, "q16Ucq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_s8_z, "q16Ucq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_u16_m, "q8Usq8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_u16_x, "q8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_u16_z, "q8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_u32_m, "q4Uiq4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_u32_x, "q4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_u32_z, "q4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_u64_m, "q2UWiq2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_u64_x, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_u64_z, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_u8_m, "q16Ucq16Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_u8_x, "q16Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svclz_u8_z, "q16Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_f16_m, "q8hq16bq8hq8hq8hIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_f16_x, "q8hq16bq8hq8hq8hIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_f16_z, "q8hq16bq8hq8hq8hIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_f32_m, "q4fq16bq4fq4fq4fIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_f32_x, "q4fq16bq4fq4fq4fIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_f32_z, "q4fq16bq4fq4fq4fIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_f64_m, "q2dq16bq2dq2dq2dIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_f64_x, "q2dq16bq2dq2dq2dIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_f64_z, "q2dq16bq2dq2dq2dIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_lane_f16, "q8hq8hq8hq8hIUWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_lane_f32, "q4fq4fq4fq4fIUWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_lane_s16, "q8sq8sq8sq8sIUWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_lane_s32, "q4iq4iq4iq4iIUWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_lane_u16, "q8Usq8Usq8Usq8UsIUWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_lane_u32, "q4Uiq4Uiq4Uiq4UiIUWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_s16, "q8sq8sq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_s32, "q4iq4iq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_s64, "q2Wiq2Wiq2Wiq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_s8, "q16Scq16Scq16Scq16ScIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_u16, "q8Usq8Usq8Usq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_u32, "q4Uiq4Uiq4Uiq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_u64, "q2UWiq2UWiq2UWiq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcmla_u8, "q16Ucq16Ucq16Ucq16UcIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_f16, "q16bq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_f32, "q16bq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_f64, "q16bq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_n_f16, "q16bq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_n_f32, "q16bq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_n_f64, "q16bq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_n_s16, "q16bq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_n_s32, "q16bq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_n_s64, "q16bq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_n_s8, "q16bq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_n_u16, "q16bq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_n_u32, "q16bq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_n_u64, "q16bq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_n_u8, "q16bq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_s16, "q16bq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_s32, "q16bq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_s64, "q16bq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_s8, "q16bq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_u16, "q16bq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_u32, "q16bq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_u64, "q16bq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_u8, "q16bq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_wide_n_s16, "q16bq16bq8sWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_wide_n_s32, "q16bq16bq4iWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_wide_n_s8, "q16bq16bq16ScWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_wide_s16, "q16bq16bq8sq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_wide_s32, "q16bq16bq4iq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpeq_wide_s8, "q16bq16bq16Scq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_f16, "q16bq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_f32, "q16bq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_f64, "q16bq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_n_f16, "q16bq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_n_f32, "q16bq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_n_f64, "q16bq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_n_s16, "q16bq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_n_s32, "q16bq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_n_s64, "q16bq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_n_s8, "q16bq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_n_u16, "q16bq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_n_u32, "q16bq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_n_u64, "q16bq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_n_u8, "q16bq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_s16, "q16bq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_s32, "q16bq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_s64, "q16bq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_s8, "q16bq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_u16, "q16bq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_u32, "q16bq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_u64, "q16bq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_u8, "q16bq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_wide_n_s16, "q16bq16bq8sWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_wide_n_s32, "q16bq16bq4iWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_wide_n_s8, "q16bq16bq16ScWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_wide_n_u16, "q16bq16bq8UsUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_wide_n_u32, "q16bq16bq4UiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_wide_n_u8, "q16bq16bq16UcUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_wide_s16, "q16bq16bq8sq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_wide_s32, "q16bq16bq4iq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_wide_s8, "q16bq16bq16Scq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_wide_u16, "q16bq16bq8Usq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_wide_u32, "q16bq16bq4Uiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpge_wide_u8, "q16bq16bq16Ucq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_f16, "q16bq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_f32, "q16bq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_f64, "q16bq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_n_f16, "q16bq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_n_f32, "q16bq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_n_f64, "q16bq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_n_s16, "q16bq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_n_s32, "q16bq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_n_s64, "q16bq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_n_s8, "q16bq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_n_u16, "q16bq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_n_u32, "q16bq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_n_u64, "q16bq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_n_u8, "q16bq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_s16, "q16bq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_s32, "q16bq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_s64, "q16bq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_s8, "q16bq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_u16, "q16bq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_u32, "q16bq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_u64, "q16bq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_u8, "q16bq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_wide_n_s16, "q16bq16bq8sWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_wide_n_s32, "q16bq16bq4iWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_wide_n_s8, "q16bq16bq16ScWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_wide_n_u16, "q16bq16bq8UsUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_wide_n_u32, "q16bq16bq4UiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_wide_n_u8, "q16bq16bq16UcUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_wide_s16, "q16bq16bq8sq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_wide_s32, "q16bq16bq4iq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_wide_s8, "q16bq16bq16Scq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_wide_u16, "q16bq16bq8Usq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_wide_u32, "q16bq16bq4Uiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpgt_wide_u8, "q16bq16bq16Ucq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_f16, "q16bq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_f32, "q16bq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_f64, "q16bq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_n_f16, "q16bq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_n_f32, "q16bq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_n_f64, "q16bq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_n_s16, "q16bq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_n_s32, "q16bq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_n_s64, "q16bq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_n_s8, "q16bq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_n_u16, "q16bq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_n_u32, "q16bq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_n_u64, "q16bq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_n_u8, "q16bq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_s16, "q16bq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_s32, "q16bq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_s64, "q16bq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_s8, "q16bq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_u16, "q16bq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_u32, "q16bq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_u64, "q16bq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_u8, "q16bq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_wide_n_s16, "q16bq16bq8sWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_wide_n_s32, "q16bq16bq4iWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_wide_n_s8, "q16bq16bq16ScWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_wide_n_u16, "q16bq16bq8UsUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_wide_n_u32, "q16bq16bq4UiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_wide_n_u8, "q16bq16bq16UcUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_wide_s16, "q16bq16bq8sq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_wide_s32, "q16bq16bq4iq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_wide_s8, "q16bq16bq16Scq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_wide_u16, "q16bq16bq8Usq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_wide_u32, "q16bq16bq4Uiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmple_wide_u8, "q16bq16bq16Ucq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_f16, "q16bq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_f32, "q16bq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_f64, "q16bq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_n_f16, "q16bq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_n_f32, "q16bq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_n_f64, "q16bq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_n_s16, "q16bq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_n_s32, "q16bq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_n_s64, "q16bq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_n_s8, "q16bq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_n_u16, "q16bq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_n_u32, "q16bq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_n_u64, "q16bq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_n_u8, "q16bq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_s16, "q16bq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_s32, "q16bq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_s64, "q16bq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_s8, "q16bq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_u16, "q16bq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_u32, "q16bq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_u64, "q16bq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_u8, "q16bq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_wide_n_s16, "q16bq16bq8sWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_wide_n_s32, "q16bq16bq4iWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_wide_n_s8, "q16bq16bq16ScWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_wide_n_u16, "q16bq16bq8UsUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_wide_n_u32, "q16bq16bq4UiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_wide_n_u8, "q16bq16bq16UcUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_wide_s16, "q16bq16bq8sq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_wide_s32, "q16bq16bq4iq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_wide_s8, "q16bq16bq16Scq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_wide_u16, "q16bq16bq8Usq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_wide_u32, "q16bq16bq4Uiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmplt_wide_u8, "q16bq16bq16Ucq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_f16, "q16bq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_f32, "q16bq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_f64, "q16bq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_n_f16, "q16bq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_n_f32, "q16bq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_n_f64, "q16bq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_n_s16, "q16bq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_n_s32, "q16bq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_n_s64, "q16bq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_n_s8, "q16bq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_n_u16, "q16bq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_n_u32, "q16bq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_n_u64, "q16bq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_n_u8, "q16bq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_s16, "q16bq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_s32, "q16bq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_s64, "q16bq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_s8, "q16bq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_u16, "q16bq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_u32, "q16bq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_u64, "q16bq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_u8, "q16bq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_wide_n_s16, "q16bq16bq8sWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_wide_n_s32, "q16bq16bq4iWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_wide_n_s8, "q16bq16bq16ScWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_wide_s16, "q16bq16bq8sq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_wide_s32, "q16bq16bq4iq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpne_wide_s8, "q16bq16bq16Scq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpuo_f16, "q16bq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpuo_f32, "q16bq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpuo_f64, "q16bq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpuo_n_f16, "q16bq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpuo_n_f32, "q16bq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcmpuo_n_f64, "q16bq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_s16_m, "q8sq8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_s16_x, "q8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_s16_z, "q8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_s32_m, "q4iq4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_s32_x, "q4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_s32_z, "q4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_s64_m, "q2Wiq2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_s64_x, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_s64_z, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_s8_m, "q16Scq16Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_s8_x, "q16Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_s8_z, "q16Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_u16_m, "q8Usq8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_u16_x, "q8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_u16_z, "q8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_u32_m, "q4Uiq4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_u32_x, "q4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_u32_z, "q4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_u64_m, "q2UWiq2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_u64_x, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_u64_z, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_u8_m, "q16Ucq16Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_u8_x, "q16Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnot_u8_z, "q16Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_bf16_m, "q8Usq8Usq16bq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svcnt_bf16_x, "q8Usq16bq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svcnt_bf16_z, "q8Usq16bq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svcnt_f16_m, "q8Usq8Usq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_f16_x, "q8Usq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_f16_z, "q8Usq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_f32_m, "q4Uiq4Uiq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_f32_x, "q4Uiq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_f32_z, "q4Uiq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_f64_m, "q2UWiq2UWiq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_f64_x, "q2UWiq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_f64_z, "q2UWiq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_s16_m, "q8Usq8Usq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_s16_x, "q8Usq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_s16_z, "q8Usq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_s32_m, "q4Uiq4Uiq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_s32_x, "q4Uiq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_s32_z, "q4Uiq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_s64_m, "q2UWiq2UWiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_s64_x, "q2UWiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_s64_z, "q2UWiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_s8_m, "q16Ucq16Ucq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_s8_x, "q16Ucq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_s8_z, "q16Ucq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_u16_m, "q8Usq8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_u16_x, "q8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_u16_z, "q8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_u32_m, "q4Uiq4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_u32_x, "q4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_u32_z, "q4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_u64_m, "q2UWiq2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_u64_x, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_u64_z, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_u8_m, "q16Ucq16Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_u8_x, "q16Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnt_u8_z, "q16Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcntb, "UWiv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcntb_pat, "UWiIi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcntd, "UWiv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcntd_pat, "UWiIi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnth, "UWiv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcnth_pat, "UWiIi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcntp_b16, "UWiq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcntp_b32, "UWiq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcntp_b64, "UWiq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcntp_b8, "UWiq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcntp_c16, "UWiQaIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svcntp_c32, "UWiQaIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svcntp_c64, "UWiQaIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svcntp_c8, "UWiQaIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svcntw, "UWiv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcntw_pat, "UWiIi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcompact_f32, "q4fq16bq4f", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svcompact_f64, "q2dq16bq2d", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svcompact_s32, "q4iq16bq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svcompact_s64, "q2Wiq16bq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svcompact_u32, "q4Uiq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svcompact_u64, "q2UWiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svcreate2_b, "q32bq16bq16b", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svcreate2_bf16, "q16yq8yq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svcreate2_f16, "q16hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate2_f32, "q8fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate2_f64, "q4dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate2_s16, "q16sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate2_s32, "q8iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate2_s64, "q4Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate2_s8, "q32Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate2_u16, "q16Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate2_u32, "q8Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate2_u64, "q4UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate2_u8, "q32Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate3_bf16, "q24yq8yq8yq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svcreate3_f16, "q24hq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate3_f32, "q12fq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate3_f64, "q6dq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate3_s16, "q24sq8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate3_s32, "q12iq4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate3_s64, "q6Wiq2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate3_s8, "q48Scq16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate3_u16, "q24Usq8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate3_u32, "q12Uiq4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate3_u64, "q6UWiq2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate3_u8, "q48Ucq16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate4_b, "q64bq16bq16bq16bq16b", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svcreate4_bf16, "q32yq8yq8yq8yq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svcreate4_f16, "q32hq8hq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate4_f32, "q16fq4fq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate4_f64, "q8dq2dq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate4_s16, "q32sq8sq8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate4_s32, "q16iq4iq4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate4_s64, "q8Wiq2Wiq2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate4_s8, "q64Scq16Scq16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate4_u16, "q32Usq8Usq8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate4_u32, "q16Uiq4Uiq4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate4_u64, "q8UWiq2UWiq2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcreate4_u8, "q64Ucq16Ucq16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt1_bf16_mf8_fpm, "q8yq16mUWi", "n", "(sve,sve2,fp8)|(sme,sme2,fp8)")
TARGET_BUILTIN(__builtin_sve_svcvt1_bf16_mf8_x2_fpm, "q16yq16mUWi", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svcvt1_f16_mf8_fpm, "q8hq16mUWi", "n", "(sve,sve2,fp8)|(sme,sme2,fp8)")
TARGET_BUILTIN(__builtin_sve_svcvt1_f16_mf8_x2_fpm, "q16hq16mUWi", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svcvt2_bf16_mf8_fpm, "q8yq16mUWi", "n", "(sve,sve2,fp8)|(sme,sme2,fp8)")
TARGET_BUILTIN(__builtin_sve_svcvt2_bf16_mf8_x2_fpm, "q16yq16mUWi", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svcvt2_f16_mf8_fpm, "q8hq16mUWi", "n", "(sve,sve2,fp8)|(sme,sme2,fp8)")
TARGET_BUILTIN(__builtin_sve_svcvt2_f16_mf8_x2_fpm, "q16hq16mUWi", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svcvt_bf16_f32_m, "q8yq8yq16bq4f", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svcvt_bf16_f32_x, "q8yq16bq4f", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svcvt_bf16_f32_x2, "q8yq8f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svcvt_bf16_f32_z, "q8yq16bq4f", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_f32_m, "q8hq8hq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_f32_x, "q8hq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_f32_x2, "q8hq8f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_f32_z, "q8hq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_f64_m, "q8hq8hq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_f64_x, "q8hq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_f64_z, "q8hq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_s16_m, "q8hq8hq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_s16_x, "q8hq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_s16_z, "q8hq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_s32_m, "q8hq8hq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_s32_x, "q8hq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_s32_z, "q8hq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_s64_m, "q8hq8hq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_s64_x, "q8hq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_s64_z, "q8hq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_u16_m, "q8hq8hq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_u16_x, "q8hq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_u16_z, "q8hq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_u32_m, "q8hq8hq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_u32_x, "q8hq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_u32_z, "q8hq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_u64_m, "q8hq8hq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_u64_x, "q8hq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f16_u64_z, "q8hq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_f16_m, "q4fq4fq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_f16_x, "q4fq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_f16_x2, "q8fq8h", "n", "sme,sme-f16f16")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_f16_z, "q4fq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_f64_m, "q4fq4fq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_f64_x, "q4fq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_f64_z, "q4fq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_s32_m, "q4fq4fq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_s32_x, "q4fq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_s32_x2, "q8fq8i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_s32_x4, "q16fq16i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_s32_z, "q4fq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_s64_m, "q4fq4fq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_s64_x, "q4fq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_s64_z, "q4fq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_u32_m, "q4fq4fq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_u32_x, "q4fq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_u32_x2, "q8fq8Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_u32_x4, "q16fq16Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_u32_z, "q4fq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_u64_m, "q4fq4fq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_u64_x, "q4fq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f32_u64_z, "q4fq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f64_f16_m, "q2dq2dq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f64_f16_x, "q2dq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f64_f16_z, "q2dq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f64_f32_m, "q2dq2dq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f64_f32_x, "q2dq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f64_f32_z, "q2dq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f64_s32_m, "q2dq2dq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f64_s32_x, "q2dq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f64_s32_z, "q2dq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f64_s64_m, "q2dq2dq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f64_s64_x, "q2dq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f64_s64_z, "q2dq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f64_u32_m, "q2dq2dq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f64_u32_x, "q2dq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f64_u32_z, "q2dq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f64_u64_m, "q2dq2dq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f64_u64_x, "q2dq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_f64_u64_z, "q2dq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_mf8_bf16_x2_fpm, "q16mq16yUWi", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svcvt_mf8_f16_x2_fpm, "q16mq16hUWi", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svcvt_mf8_f32_x4_fpm, "q16mq16fUWi", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svcvt_s16_f16_m, "q8sq8sq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_s16_f16_x, "q8sq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_s16_f16_z, "q8sq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_s32_f16_m, "q4iq4iq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_s32_f16_x, "q4iq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_s32_f16_z, "q4iq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_s32_f32_m, "q4iq4iq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_s32_f32_x, "q4iq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_s32_f32_x2, "q8iq8f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svcvt_s32_f32_x4, "q16iq16f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svcvt_s32_f32_z, "q4iq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_s32_f64_m, "q4iq4iq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_s32_f64_x, "q4iq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_s32_f64_z, "q4iq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_s64_f16_m, "q2Wiq2Wiq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_s64_f16_x, "q2Wiq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_s64_f16_z, "q2Wiq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_s64_f32_m, "q2Wiq2Wiq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_s64_f32_x, "q2Wiq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_s64_f32_z, "q2Wiq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_s64_f64_m, "q2Wiq2Wiq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_s64_f64_x, "q2Wiq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_s64_f64_z, "q2Wiq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u16_f16_m, "q8Usq8Usq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u16_f16_x, "q8Usq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u16_f16_z, "q8Usq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u32_f16_m, "q4Uiq4Uiq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u32_f16_x, "q4Uiq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u32_f16_z, "q4Uiq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u32_f32_m, "q4Uiq4Uiq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u32_f32_x, "q4Uiq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u32_f32_x2, "q8Uiq8f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svcvt_u32_f32_x4, "q16Uiq16f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svcvt_u32_f32_z, "q4Uiq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u32_f64_m, "q4Uiq4Uiq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u32_f64_x, "q4Uiq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u32_f64_z, "q4Uiq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u64_f16_m, "q2UWiq2UWiq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u64_f16_x, "q2UWiq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u64_f16_z, "q2UWiq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u64_f32_m, "q2UWiq2UWiq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u64_f32_x, "q2UWiq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u64_f32_z, "q2UWiq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u64_f64_m, "q2UWiq2UWiq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u64_f64_x, "q2UWiq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvt_u64_f64_z, "q2UWiq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svcvtl1_bf16_mf8_x2_fpm, "q16yq16mUWi", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svcvtl1_f16_mf8_x2_fpm, "q16hq16mUWi", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svcvtl2_bf16_mf8_x2_fpm, "q16yq16mUWi", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svcvtl2_f16_mf8_x2_fpm, "q16hq16mUWi", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svcvtl_f32_f16_x2, "q8fq8h", "n", "sme,sme-f16f16")
TARGET_BUILTIN(__builtin_sve_svcvtlt1_bf16_mf8_fpm, "q8yq16mUWi", "n", "(sve,sve2,fp8)|(sme,sme2,fp8)")
TARGET_BUILTIN(__builtin_sve_svcvtlt1_f16_mf8_fpm, "q8hq16mUWi", "n", "(sve,sve2,fp8)|(sme,sme2,fp8)")
TARGET_BUILTIN(__builtin_sve_svcvtlt2_bf16_mf8_fpm, "q8yq16mUWi", "n", "(sve,sve2,fp8)|(sme,sme2,fp8)")
TARGET_BUILTIN(__builtin_sve_svcvtlt2_f16_mf8_fpm, "q8hq16mUWi", "n", "(sve,sve2,fp8)|(sme,sme2,fp8)")
TARGET_BUILTIN(__builtin_sve_svcvtlt_f32_f16_m, "q4fq4fq16bq8h", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcvtlt_f32_f16_x, "q4fq16bq8h", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcvtlt_f64_f32_m, "q2dq2dq16bq4f", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcvtlt_f64_f32_x, "q2dq16bq4f", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcvtn_bf16_f32_x2, "q8yq8f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svcvtn_f16_f32_x2, "q8hq8f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svcvtn_mf8_bf16_x2_fpm, "q16mq16yUWi", "n", "(sve,sve2,fp8)|(sme,sme2,fp8)")
TARGET_BUILTIN(__builtin_sve_svcvtn_mf8_f16_x2_fpm, "q16mq16hUWi", "n", "(sve,sve2,fp8)|(sme,sme2,fp8)")
TARGET_BUILTIN(__builtin_sve_svcvtn_mf8_f32_x4_fpm, "q16mq16fUWi", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svcvtnb_mf8_f32_x2_fpm, "q16mq8fUWi", "n", "(sve,sve2,fp8)|(sme,sme2,fp8)")
TARGET_BUILTIN(__builtin_sve_svcvtnt_bf16_f32_m, "q8yq8yq16bq4f", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svcvtnt_f16_f32_m, "q8hq8hq16bq4f", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcvtnt_f32_f64_m, "q4fq4fq16bq2d", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcvtnt_mf8_f32_x2_fpm, "q16mq16mq8fUWi", "n", "(sve,sve2,fp8)|(sme,sme2,fp8)")
TARGET_BUILTIN(__builtin_sve_svcvtx_f32_f64_m, "q4fq4fq16bq2d", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcvtx_f32_f64_x, "q4fq16bq2d", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcvtx_f32_f64_z, "q4fq16bq2d", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svcvtxnt_f32_f64_m, "q4fq4fq16bq2d", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_f16_m, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_f16_x, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_f16_z, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_f32_m, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_f32_x, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_f32_z, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_f64_m, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_f64_x, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_f64_z, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_f16_m, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_f16_x, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_f16_z, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_f32_m, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_f32_x, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_f32_z, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_f64_m, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_f64_x, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_f64_z, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_s32_m, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_s32_x, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_s32_z, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_s64_m, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_s64_x, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_s64_z, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_u32_m, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_u32_x, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_u32_z, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_s32_m, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_s32_x, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_s32_z, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdiv_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_f16_m, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_f16_x, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_f16_z, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_f32_m, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_f32_x, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_f32_z, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_f64_m, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_f64_x, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_f64_z, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_f16_m, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_f16_x, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_f16_z, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_f32_m, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_f32_x, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_f32_z, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_f64_m, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_f64_x, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_f64_z, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_s32_m, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_s32_x, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_s32_z, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_s64_m, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_s64_x, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_s64_z, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_u32_m, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_u32_x, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_u32_z, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_s32_m, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_s32_x, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_s32_z, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdivr_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdot_f16_mf8_fpm, "q8hq8hq16mq16mUWi", "n", "(sve,sve2,fp8dot2)|(sme,ssve-fp8dot2)")
TARGET_BUILTIN(__builtin_sve_svdot_f32_f16, "q4fq4fq8hq8h", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svdot_f32_mf8_fpm, "q4fq4fq16mq16mUWi", "n", "(sve,sve2,fp8dot4)|(sme,ssve-fp8dot4)")
TARGET_BUILTIN(__builtin_sve_svdot_lane_f16_mf8_fpm, "q8hq8hq16mq16mIUWiUWi", "n", "(sve,sve2,fp8dot2)|(sme,ssve-fp8dot2)")
TARGET_BUILTIN(__builtin_sve_svdot_lane_f32_f16, "q4fq4fq8hq8hIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svdot_lane_f32_mf8_fpm, "q4fq4fq16mq16mIUWiUWi", "n", "(sve,sve2,fp8dot4)|(sme,ssve-fp8dot4)")
TARGET_BUILTIN(__builtin_sve_svdot_lane_s32, "q4iq4iq16Scq16ScIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdot_lane_s32_s16, "q4iq4iq8sq8sIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svdot_lane_s64, "q2Wiq2Wiq8sq8sIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdot_lane_u32, "q4Uiq4Uiq16Ucq16UcIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdot_lane_u32_u16, "q4Uiq4Uiq8Usq8UsIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svdot_lane_u64, "q2UWiq2UWiq8Usq8UsIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdot_n_f16_mf8_fpm, "q8hq8hq16mmUWi", "n", "(sve,sve2,fp8dot2)|(sme,ssve-fp8dot2)")
TARGET_BUILTIN(__builtin_sve_svdot_n_f32_mf8_fpm, "q4fq4fq16mmUWi", "n", "(sve,sve2,fp8dot4)|(sme,ssve-fp8dot4)")
TARGET_BUILTIN(__builtin_sve_svdot_n_s32, "q4iq4iq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdot_n_s64, "q2Wiq2Wiq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdot_n_u32, "q4Uiq4Uiq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdot_n_u64, "q2UWiq2UWiq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdot_s32, "q4iq4iq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdot_s32_s16, "q4iq4iq8sq8s", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svdot_s64, "q2Wiq2Wiq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdot_u32, "q4Uiq4Uiq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdot_u32_u16, "q4Uiq4Uiq8Usq8Us", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svdot_u64, "q2UWiq2UWiq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_lane_bf16, "q8yq8yUs", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svdup_lane_f16, "q8hq8hUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_lane_f32, "q4fq4fUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_lane_f64, "q2dq2dUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_lane_s16, "q8sq8sUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_lane_s32, "q4iq4iUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_lane_s64, "q2Wiq2WiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_lane_s8, "q16Scq16ScUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_lane_u16, "q8Usq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_lane_u32, "q4Uiq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_lane_u64, "q2UWiq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_lane_u8, "q16Ucq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_laneq_bf16, "q8yq8yIUWi", "n", "(sve,sve2p1,bf16)|(sme,sme2p1,bf16)")
TARGET_BUILTIN(__builtin_sve_svdup_laneq_f16, "q8hq8hIUWi", "n", "(sve,sve2p1)|(sme,sme2p1)")
TARGET_BUILTIN(__builtin_sve_svdup_laneq_f32, "q4fq4fIUWi", "n", "(sve,sve2p1)|(sme,sme2p1)")
TARGET_BUILTIN(__builtin_sve_svdup_laneq_f64, "q2dq2dIUWi", "n", "(sve,sve2p1)|(sme,sme2p1)")
TARGET_BUILTIN(__builtin_sve_svdup_laneq_mf8, "q16mq16mIUWi", "n", "(sve,sve2p1)|(sme,sme2p1)")
TARGET_BUILTIN(__builtin_sve_svdup_laneq_s16, "q8sq8sIUWi", "n", "(sve,sve2p1)|(sme,sme2p1)")
TARGET_BUILTIN(__builtin_sve_svdup_laneq_s32, "q4iq4iIUWi", "n", "(sve,sve2p1)|(sme,sme2p1)")
TARGET_BUILTIN(__builtin_sve_svdup_laneq_s64, "q2Wiq2WiIUWi", "n", "(sve,sve2p1)|(sme,sme2p1)")
TARGET_BUILTIN(__builtin_sve_svdup_laneq_s8, "q16Scq16ScIUWi", "n", "(sve,sve2p1)|(sme,sme2p1)")
TARGET_BUILTIN(__builtin_sve_svdup_laneq_u16, "q8Usq8UsIUWi", "n", "(sve,sve2p1)|(sme,sme2p1)")
TARGET_BUILTIN(__builtin_sve_svdup_laneq_u32, "q4Uiq4UiIUWi", "n", "(sve,sve2p1)|(sme,sme2p1)")
TARGET_BUILTIN(__builtin_sve_svdup_laneq_u64, "q2UWiq2UWiIUWi", "n", "(sve,sve2p1)|(sme,sme2p1)")
TARGET_BUILTIN(__builtin_sve_svdup_laneq_u8, "q16Ucq16UcIUWi", "n", "(sve,sve2p1)|(sme,sme2p1)")
TARGET_BUILTIN(__builtin_sve_svdup_n_b16, "q16bb", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_b32, "q16bb", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_b64, "q16bb", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_b8, "q16bb", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_bf16, "q8yy", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svdup_n_bf16_m, "q8yq8yq16by", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svdup_n_bf16_x, "q8yq16by", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svdup_n_bf16_z, "q8yq16by", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svdup_n_f16, "q8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_f16_m, "q8hq8hq16bh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_f16_x, "q8hq16bh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_f16_z, "q8hq16bh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_f32, "q4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_f32_m, "q4fq4fq16bf", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_f32_x, "q4fq16bf", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_f32_z, "q4fq16bf", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_f64, "q2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_f64_m, "q2dq2dq16bd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_f64_x, "q2dq16bd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_f64_z, "q2dq16bd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_s16, "q8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_s16_m, "q8sq8sq16bs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_s16_x, "q8sq16bs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_s16_z, "q8sq16bs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_s32, "q4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_s32_m, "q4iq4iq16bi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_s32_x, "q4iq16bi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_s32_z, "q4iq16bi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_s64, "q2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_s64_m, "q2Wiq2Wiq16bWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_s64_x, "q2Wiq16bWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_s64_z, "q2Wiq16bWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_s8, "q16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_s8_m, "q16Scq16Scq16bSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_s8_x, "q16Scq16bSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_s8_z, "q16Scq16bSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_u16, "q8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_u16_m, "q8Usq8Usq16bUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_u16_x, "q8Usq16bUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_u16_z, "q8Usq16bUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_u32, "q4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_u32_m, "q4Uiq4Uiq16bUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_u32_x, "q4Uiq16bUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_u32_z, "q4Uiq16bUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_u64, "q2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_u64_m, "q2UWiq2UWiq16bUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_u64_x, "q2UWiq16bUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_u64_z, "q2UWiq16bUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_u8, "q16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_u8_m, "q16Ucq16Ucq16bUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_u8_x, "q16Ucq16bUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdup_n_u8_z, "q16Ucq16bUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_lane_bf16, "q8yq8yUWi", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svdupq_lane_f16, "q8hq8hUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_lane_f32, "q4fq4fUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_lane_f64, "q2dq2dUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_lane_s16, "q8sq8sUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_lane_s32, "q4iq4iUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_lane_s64, "q2Wiq2WiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_lane_s8, "q16Scq16ScUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_lane_u16, "q8Usq8UsUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_lane_u32, "q4Uiq4UiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_lane_u64, "q2UWiq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_lane_u8, "q16Ucq16UcUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_n_b16, "q16bbbbbbbbb", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_n_b32, "q16bbbbb", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_n_b64, "q16bbb", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_n_b8, "q16bbbbbbbbbbbbbbbbb", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_n_bf16, "q8yyyyyyyyy", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svdupq_n_f16, "q8hhhhhhhhh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_n_f32, "q4fffff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_n_f64, "q2ddd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_n_s16, "q8sssssssss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_n_s32, "q4iiiii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_n_s64, "q2WiWiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_n_s8, "q16ScScScScScScScScScScScScScScScScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_n_u16, "q8UsUsUsUsUsUsUsUsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_n_u32, "q4UiUiUiUiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_n_u64, "q2UWiUWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svdupq_n_u8, "q16UcUcUcUcUcUcUcUcUcUcUcUcUcUcUcUcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor3_n_s16, "q8sq8sq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveor3_n_s32, "q4iq4iq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveor3_n_s64, "q2Wiq2Wiq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveor3_n_s8, "q16Scq16Scq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveor3_n_u16, "q8Usq8Usq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveor3_n_u32, "q4Uiq4Uiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveor3_n_u64, "q2UWiq2UWiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveor3_n_u8, "q16Ucq16Ucq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveor3_s16, "q8sq8sq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveor3_s32, "q4iq4iq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveor3_s64, "q2Wiq2Wiq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveor3_s8, "q16Scq16Scq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveor3_u16, "q8Usq8Usq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveor3_u32, "q4Uiq4Uiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveor3_u64, "q2UWiq2UWiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveor3_u8, "q16Ucq16Ucq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveor_b_z, "q16bq16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_s16_m, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_s16_x, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_s16_z, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_s32_m, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_s32_x, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_s32_z, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_s64_m, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_s64_x, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_s64_z, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_s8_m, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_s8_x, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_s8_z, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_u16_m, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_u16_x, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_u16_z, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_u32_m, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_u32_x, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_u32_z, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_u8_m, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_u8_x, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_n_u8_z, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_s16_m, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_s16_x, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_s16_z, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_s32_m, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_s32_x, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_s32_z, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_s8_m, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_s8_x, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_s8_z, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_u16_m, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_u16_x, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_u16_z, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveor_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveorbt_n_s16, "q8sq8sq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveorbt_n_s32, "q4iq4iq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveorbt_n_s64, "q2Wiq2Wiq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveorbt_n_s8, "q16Scq16Scq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveorbt_n_u16, "q8Usq8Usq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveorbt_n_u32, "q4Uiq4Uiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveorbt_n_u64, "q2UWiq2UWiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveorbt_n_u8, "q16Ucq16Ucq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveorbt_s16, "q8sq8sq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveorbt_s32, "q4iq4iq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveorbt_s64, "q2Wiq2Wiq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveorbt_s8, "q16Scq16Scq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveorbt_u16, "q8Usq8Usq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveorbt_u32, "q4Uiq4Uiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveorbt_u64, "q2UWiq2UWiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveorbt_u8, "q16Ucq16Ucq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveorqv_s16, "V8sq16bq8s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_sveorqv_s32, "V4iq16bq4i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_sveorqv_s64, "V2Wiq16bq2Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_sveorqv_s8, "V16Scq16bq16Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_sveorqv_u16, "V8Usq16bq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_sveorqv_u32, "V4Uiq16bq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_sveorqv_u64, "V2UWiq16bq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_sveorqv_u8, "V16Ucq16bq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_sveortb_n_s16, "q8sq8sq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveortb_n_s32, "q4iq4iq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveortb_n_s64, "q2Wiq2Wiq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveortb_n_s8, "q16Scq16Scq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveortb_n_u16, "q8Usq8Usq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveortb_n_u32, "q4Uiq4Uiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveortb_n_u64, "q2UWiq2UWiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveortb_n_u8, "q16Ucq16Ucq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveortb_s16, "q8sq8sq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveortb_s32, "q4iq4iq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveortb_s64, "q2Wiq2Wiq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveortb_s8, "q16Scq16Scq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveortb_u16, "q8Usq8Usq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveortb_u32, "q4Uiq4Uiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveortb_u64, "q2UWiq2UWiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveortb_u8, "q16Ucq16Ucq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_sveorv_s16, "sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveorv_s32, "iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveorv_s64, "Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveorv_s8, "Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveorv_u16, "Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveorv_u32, "Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveorv_u64, "UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_sveorv_u8, "Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svexpa_f16, "q8hq8Us", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svexpa_f32, "q4fq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svexpa_f64, "q2dq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svext_bf16, "q8yq8yq8yIUWi", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svext_f16, "q8hq8hq8hIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svext_f32, "q4fq4fq4fIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svext_f64, "q2dq2dq2dIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svext_s16, "q8sq8sq8sIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svext_s32, "q4iq4iq4iIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svext_s64, "q2Wiq2Wiq2WiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svext_s8, "q16Scq16Scq16ScIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svext_u16, "q8Usq8Usq8UsIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svext_u32, "q4Uiq4Uiq4UiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svext_u64, "q2UWiq2UWiq2UWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svext_u8, "q16Ucq16Ucq16UcIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextb_s16_m, "q8sq8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextb_s16_x, "q8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextb_s16_z, "q8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextb_s32_m, "q4iq4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextb_s32_x, "q4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextb_s32_z, "q4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextb_s64_m, "q2Wiq2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextb_s64_x, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextb_s64_z, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextb_u16_m, "q8Usq8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextb_u16_x, "q8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextb_u16_z, "q8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextb_u32_m, "q4Uiq4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextb_u32_x, "q4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextb_u32_z, "q4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextb_u64_m, "q2UWiq2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextb_u64_x, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextb_u64_z, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svexth_s32_m, "q4iq4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svexth_s32_x, "q4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svexth_s32_z, "q4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svexth_s64_m, "q2Wiq2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svexth_s64_x, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svexth_s64_z, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svexth_u32_m, "q4Uiq4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svexth_u32_x, "q4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svexth_u32_z, "q4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svexth_u64_m, "q2UWiq2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svexth_u64_x, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svexth_u64_z, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextq_bf16, "q8yq8yq8yi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svextq_f16, "q8hq8hq8hi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svextq_f32, "q4fq4fq4fi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svextq_f64, "q2dq2dq2di", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svextq_mf8, "q16mq16mq16mi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svextq_s16, "q8sq8sq8si", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svextq_s32, "q4iq4iq4ii", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svextq_s64, "q2Wiq2Wiq2Wii", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svextq_s8, "q16Scq16Scq16Sci", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svextq_u16, "q8Usq8Usq8Usi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svextq_u32, "q4Uiq4Uiq4Uii", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svextq_u64, "q2UWiq2UWiq2UWii", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svextq_u8, "q16Ucq16Ucq16Uci", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svextw_s64_m, "q2Wiq2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextw_s64_x, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextw_s64_z, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextw_u64_m, "q2UWiq2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextw_u64_x, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svextw_u64_z, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget2_b, "q16bq32bIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svget2_bf16, "q8yq16yIUWi", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svget2_f16, "q8hq16hIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget2_f32, "q4fq8fIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget2_f64, "q2dq4dIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget2_s16, "q8sq16sIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget2_s32, "q4iq8iIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget2_s64, "q2Wiq4WiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget2_s8, "q16Scq32ScIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget2_u16, "q8Usq16UsIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget2_u32, "q4Uiq8UiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget2_u64, "q2UWiq4UWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget2_u8, "q16Ucq32UcIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget3_bf16, "q8yq24yIUWi", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svget3_f16, "q8hq24hIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget3_f32, "q4fq12fIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget3_f64, "q2dq6dIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget3_s16, "q8sq24sIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget3_s32, "q4iq12iIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget3_s64, "q2Wiq6WiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget3_s8, "q16Scq48ScIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget3_u16, "q8Usq24UsIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget3_u32, "q4Uiq12UiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget3_u64, "q2UWiq6UWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget3_u8, "q16Ucq48UcIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget4_b, "q16bq64bIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svget4_bf16, "q8yq32yIUWi", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svget4_f16, "q8hq32hIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget4_f32, "q4fq16fIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget4_f64, "q2dq8dIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget4_s16, "q8sq32sIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget4_s32, "q4iq16iIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget4_s64, "q2Wiq8WiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget4_s8, "q16Scq64ScIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget4_u16, "q8Usq32UsIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget4_u32, "q4Uiq16UiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget4_u64, "q2UWiq8UWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svget4_u8, "q16Ucq64UcIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_s16_m, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_s16_x, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_s16_z, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_s32_m, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_s32_x, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_s32_z, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_s64_m, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_s64_x, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_s64_z, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_s8_m, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_s8_x, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_s8_z, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_u16_m, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_u16_x, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_u16_z, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_u32_m, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_u32_x, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_u32_z, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_u8_m, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_u8_x, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_n_u8_z, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_s16_m, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_s16_x, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_s16_z, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_s32_m, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_s32_x, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_s32_z, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_s8_m, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_s8_x, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_s8_z, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_u16_m, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_u16_x, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_u16_z, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhadd_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhistcnt_s32_z, "q4Uiq16bq4iq4i", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svhistcnt_s64_z, "q2UWiq16bq2Wiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svhistcnt_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svhistcnt_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svhistseg_s8, "q16Ucq16Scq16Sc", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svhistseg_u8, "q16Ucq16Ucq16Uc", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svhsub_n_s16_m, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_s16_x, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_s16_z, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_s32_m, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_s32_x, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_s32_z, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_s64_m, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_s64_x, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_s64_z, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_s8_m, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_s8_x, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_s8_z, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_u16_m, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_u16_x, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_u16_z, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_u32_m, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_u32_x, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_u32_z, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_u8_m, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_u8_x, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_n_u8_z, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_s16_m, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_s16_x, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_s16_z, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_s32_m, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_s32_x, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_s32_z, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_s8_m, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_s8_x, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_s8_z, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_u16_m, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_u16_x, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_u16_z, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsub_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_s16_m, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_s16_x, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_s16_z, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_s32_m, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_s32_x, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_s32_z, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_s64_m, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_s64_x, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_s64_z, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_s8_m, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_s8_x, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_s8_z, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_u16_m, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_u16_x, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_u16_z, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_u32_m, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_u32_x, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_u32_z, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_u8_m, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_u8_x, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_n_u8_z, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_s16_m, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_s16_x, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_s16_z, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_s32_m, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_s32_x, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_s32_z, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_s8_m, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_s8_x, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_s8_z, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_u16_m, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_u16_x, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_u16_z, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svhsubr_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svindex_s16, "q8sss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svindex_s32, "q4iii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svindex_s64, "q2WiWiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svindex_s8, "q16ScScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svindex_u16, "q8UsUsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svindex_u32, "q4UiUiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svindex_u64, "q2UWiUWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svindex_u8, "q16UcUcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svinsr_n_bf16, "q8yq8yy", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svinsr_n_f16, "q8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svinsr_n_f32, "q4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svinsr_n_f64, "q2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svinsr_n_s16, "q8sq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svinsr_n_s32, "q4iq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svinsr_n_s64, "q2Wiq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svinsr_n_s8, "q16Scq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svinsr_n_u16, "q8Usq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svinsr_n_u32, "q4Uiq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svinsr_n_u64, "q2UWiq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svinsr_n_u8, "q16Ucq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlasta_bf16, "yq16bq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svlasta_f16, "hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlasta_f32, "fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlasta_f64, "dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlasta_s16, "sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlasta_s32, "iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlasta_s64, "Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlasta_s8, "Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlasta_u16, "Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlasta_u32, "Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlasta_u64, "UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlasta_u8, "Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlastb_bf16, "yq16bq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svlastb_f16, "hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlastb_f32, "fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlastb_f64, "dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlastb_s16, "sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlastb_s32, "iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlastb_s64, "Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlastb_s8, "Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlastb_u16, "Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlastb_u32, "Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlastb_u64, "UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlastb_u8, "Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_bf16, "q8yq16byC*", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svld1_bf16_x2, "q16yQayC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_bf16_x4, "q32yQayC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_f16, "q8hq16bhC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_f16_x2, "q16hQahC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_f16_x4, "q32hQahC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_f32, "q4fq16bfC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_f32_x2, "q8fQafC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_f32_x4, "q16fQafC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_f64, "q2dq16bdC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_f64_x2, "q4dQadC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_f64_x4, "q8dQadC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_gather_s32index_f32, "q4fq16bfC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_s32index_s32, "q4iq16bSiC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_s32index_u32, "q4Uiq16bUiC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_s32offset_f32, "q4fq16bfC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_s32offset_s32, "q4iq16bSiC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_s32offset_u32, "q4Uiq16bUiC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_s64index_f64, "q2dq16bdC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_s64index_s64, "q2Wiq16bSWiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_s64index_u64, "q2UWiq16bUWiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_s64offset_f64, "q2dq16bdC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_s64offset_s64, "q2Wiq16bSWiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_s64offset_u64, "q2UWiq16bUWiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u32base_f32, "q4fq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u32base_index_f32, "q4fq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u32base_index_s32, "q4iq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u32base_index_u32, "q4Uiq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u32base_offset_f32, "q4fq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u32base_offset_s32, "q4iq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u32base_offset_u32, "q4Uiq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u32base_s32, "q4iq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u32base_u32, "q4Uiq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u32index_f32, "q4fq16bfC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u32index_s32, "q4iq16bSiC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u32index_u32, "q4Uiq16bUiC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u32offset_f32, "q4fq16bfC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u32offset_s32, "q4iq16bSiC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u32offset_u32, "q4Uiq16bUiC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u64base_f64, "q2dq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u64base_index_f64, "q2dq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u64base_index_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u64base_index_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u64base_offset_f64, "q2dq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u64index_f64, "q2dq16bdC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u64index_s64, "q2Wiq16bSWiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u64index_u64, "q2UWiq16bUWiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u64offset_f64, "q2dq16bdC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u64offset_s64, "q2Wiq16bSWiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_gather_u64offset_u64, "q2UWiq16bUWiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1_s16, "q8sq16bSsC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_s16_x2, "q16sQaSsC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_s16_x4, "q32sQaSsC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_s32, "q4iq16bSiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_s32_x2, "q8iQaSiC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_s32_x4, "q16iQaSiC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_s64, "q2Wiq16bSWiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_s64_x2, "q4WiQaSWiC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_s64_x4, "q8WiQaSWiC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_s8, "q16Scq16bScC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_s8_x2, "q32ScQaScC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_s8_x4, "q64ScQaScC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_u16, "q8Usq16bUsC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_u16_x2, "q16UsQaUsC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_u16_x4, "q32UsQaUsC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_u32, "q4Uiq16bUiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_u32_x2, "q8UiQaUiC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_u32_x4, "q16UiQaUiC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_u64, "q2UWiq16bUWiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_u64_x2, "q4UWiQaUWiC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_u64_x4, "q8UWiQaUWiC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_u8, "q16Ucq16bUcC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_u8_x2, "q32UcQaUcC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_u8_x4, "q64UcQaUcC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_bf16, "q8yq16byC*Wi", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_bf16_x2, "q16yQayC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_bf16_x4, "q32yQayC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_f16, "q8hq16bhC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_f16_x2, "q16hQahC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_f16_x4, "q32hQahC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_f32, "q4fq16bfC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_f32_x2, "q8fQafC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_f32_x4, "q16fQafC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_f64, "q2dq16bdC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_f64_x2, "q4dQadC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_f64_x4, "q8dQadC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_s16, "q8sq16bSsC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_s16_x2, "q16sQaSsC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_s16_x4, "q32sQaSsC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_s32, "q4iq16bSiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_s32_x2, "q8iQaSiC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_s32_x4, "q16iQaSiC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_s64, "q2Wiq16bSWiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_s64_x2, "q4WiQaSWiC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_s64_x4, "q8WiQaSWiC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_s8, "q16Scq16bScC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_s8_x2, "q32ScQaScC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_s8_x4, "q64ScQaScC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_u16, "q8Usq16bUsC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_u16_x2, "q16UsQaUsC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_u16_x4, "q32UsQaUsC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_u32, "q4Uiq16bUiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_u32_x2, "q8UiQaUiC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_u32_x4, "q16UiQaUiC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_u64, "q2UWiq16bUWiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_u64_x2, "q4UWiQaUWiC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_u64_x4, "q8UWiQaUWiC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_u8, "q16Ucq16bUcC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_u8_x2, "q32UcQaUcC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1_vnum_u8_x4, "q64UcQaUcC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_bf16, "q8yq16bq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_f16, "q8hq16bq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_f32, "q4fq16bq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_f64, "q2dq16bq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_index_bf16, "q8yq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_index_f16, "q8hq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_index_f32, "q4fq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_index_f64, "q2dq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_index_s16, "q8sq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_index_s32, "q4iq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_index_s64, "q2Wiq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_index_u16, "q8Usq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_index_u32, "q4Uiq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_index_u64, "q2UWiq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_offset_bf16, "q8yq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_offset_f16, "q8hq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_offset_f32, "q4fq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_offset_f64, "q2dq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_offset_s16, "q8sq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_offset_s32, "q4iq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_offset_s8, "q16Scq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_offset_u16, "q8Usq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_offset_u32, "q4Uiq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_offset_u8, "q16Ucq16bq2UWiWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_s16, "q8sq16bq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_s32, "q4iq16bq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_s8, "q16Scq16bq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_u16, "q8Usq16bq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_u32, "q4Uiq16bq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64base_u8, "q16Ucq16bq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64index_bf16, "q8yq16byC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64index_f16, "q8hq16bhC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64index_f32, "q4fq16bfC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64index_f64, "q2dq16bdC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64index_s16, "q8sq16bSsC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64index_s32, "q4iq16bSiC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64index_s64, "q2Wiq16bSWiC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64index_u16, "q8Usq16bUsC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64index_u32, "q4Uiq16bUiC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64index_u64, "q2UWiq16bUWiC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64offset_bf16, "q8yq16byC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64offset_f16, "q8hq16bhC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64offset_f32, "q4fq16bfC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64offset_f64, "q2dq16bdC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64offset_s16, "q8sq16bSsC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64offset_s32, "q4iq16bSiC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64offset_s64, "q2Wiq16bSWiC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64offset_s8, "q16Scq16bScC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64offset_u16, "q8Usq16bUsC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64offset_u32, "q4Uiq16bUiC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64offset_u64, "q2UWiq16bUWiC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1q_gather_u64offset_u8, "q16Ucq16bUcC*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1ro_bf16, "q8yq16byC*", "n", "sve,f64mm,bf16")
TARGET_BUILTIN(__builtin_sve_svld1ro_f16, "q8hq16bhC*", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svld1ro_f32, "q4fq16bfC*", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svld1ro_f64, "q2dq16bdC*", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svld1ro_s16, "q8sq16bSsC*", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svld1ro_s32, "q4iq16bSiC*", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svld1ro_s64, "q2Wiq16bSWiC*", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svld1ro_s8, "q16Scq16bScC*", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svld1ro_u16, "q8Usq16bUsC*", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svld1ro_u32, "q4Uiq16bUiC*", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svld1ro_u64, "q2UWiq16bUWiC*", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svld1ro_u8, "q16Ucq16bUcC*", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svld1rq_bf16, "q8yq16byC*", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svld1rq_f16, "q8hq16bhC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1rq_f32, "q4fq16bfC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1rq_f64, "q2dq16bdC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1rq_s16, "q8sq16bSsC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1rq_s32, "q4iq16bSiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1rq_s64, "q2Wiq16bSWiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1rq_s8, "q16Scq16bScC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1rq_u16, "q8Usq16bUsC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1rq_u32, "q4Uiq16bUiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1rq_u64, "q2UWiq16bUWiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1rq_u8, "q16Ucq16bUcC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sb_gather_s32offset_s32, "q4iq16bScC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sb_gather_s32offset_u32, "q4Uiq16bScC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sb_gather_s64offset_s64, "q2Wiq16bScC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sb_gather_s64offset_u64, "q2UWiq16bScC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sb_gather_u32base_offset_s32, "q4iq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sb_gather_u32base_offset_u32, "q4Uiq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sb_gather_u32base_s32, "q4iq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sb_gather_u32base_u32, "q4Uiq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sb_gather_u32offset_s32, "q4iq16bScC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sb_gather_u32offset_u32, "q4Uiq16bScC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sb_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sb_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sb_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sb_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sb_gather_u64offset_s64, "q2Wiq16bScC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sb_gather_u64offset_u64, "q2UWiq16bScC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sb_s16, "q8sq16bScC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sb_s32, "q4iq16bScC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sb_s64, "q2Wiq16bScC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sb_u16, "q8Usq16bScC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sb_u32, "q4Uiq16bScC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sb_u64, "q2UWiq16bScC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sb_vnum_s16, "q8sq16bScC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sb_vnum_s32, "q4iq16bScC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sb_vnum_s64, "q2Wiq16bScC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sb_vnum_u16, "q8Usq16bScC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sb_vnum_u32, "q4Uiq16bScC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sb_vnum_u64, "q2UWiq16bScC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_s32index_s32, "q4iq16bSsC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_s32index_u32, "q4Uiq16bSsC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_s32offset_s32, "q4iq16bSsC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_s32offset_u32, "q4Uiq16bSsC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_s64index_s64, "q2Wiq16bSsC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_s64index_u64, "q2UWiq16bSsC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_s64offset_s64, "q2Wiq16bSsC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_s64offset_u64, "q2UWiq16bSsC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_u32base_index_s32, "q4iq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_u32base_index_u32, "q4Uiq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_u32base_offset_s32, "q4iq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_u32base_offset_u32, "q4Uiq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_u32base_s32, "q4iq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_u32base_u32, "q4Uiq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_u32index_s32, "q4iq16bSsC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_u32index_u32, "q4Uiq16bSsC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_u32offset_s32, "q4iq16bSsC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_u32offset_u32, "q4Uiq16bSsC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_u64base_index_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_u64base_index_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_u64index_s64, "q2Wiq16bSsC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_u64index_u64, "q2UWiq16bSsC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_u64offset_s64, "q2Wiq16bSsC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_gather_u64offset_u64, "q2UWiq16bSsC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sh_s32, "q4iq16bSsC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sh_s64, "q2Wiq16bSsC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sh_u32, "q4Uiq16bSsC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sh_u64, "q2UWiq16bSsC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sh_vnum_s32, "q4iq16bSsC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sh_vnum_s64, "q2Wiq16bSsC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sh_vnum_u32, "q4Uiq16bSsC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sh_vnum_u64, "q2UWiq16bSsC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sw_gather_s64index_s64, "q2Wiq16bSiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sw_gather_s64index_u64, "q2UWiq16bSiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sw_gather_s64offset_s64, "q2Wiq16bSiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sw_gather_s64offset_u64, "q2UWiq16bSiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sw_gather_u64base_index_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sw_gather_u64base_index_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sw_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sw_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sw_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sw_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sw_gather_u64index_s64, "q2Wiq16bSiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sw_gather_u64index_u64, "q2UWiq16bSiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sw_gather_u64offset_s64, "q2Wiq16bSiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sw_gather_u64offset_u64, "q2UWiq16bSiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1sw_s64, "q2Wiq16bSiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sw_u64, "q2UWiq16bSiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sw_vnum_s64, "q2Wiq16bSiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1sw_vnum_u64, "q2UWiq16bSiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1ub_gather_s32offset_s32, "q4iq16bUcC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1ub_gather_s32offset_u32, "q4Uiq16bUcC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1ub_gather_s64offset_s64, "q2Wiq16bUcC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1ub_gather_s64offset_u64, "q2UWiq16bUcC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1ub_gather_u32base_offset_s32, "q4iq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1ub_gather_u32base_offset_u32, "q4Uiq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1ub_gather_u32base_s32, "q4iq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1ub_gather_u32base_u32, "q4Uiq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1ub_gather_u32offset_s32, "q4iq16bUcC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1ub_gather_u32offset_u32, "q4Uiq16bUcC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1ub_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1ub_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1ub_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1ub_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1ub_gather_u64offset_s64, "q2Wiq16bUcC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1ub_gather_u64offset_u64, "q2UWiq16bUcC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1ub_s16, "q8sq16bUcC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1ub_s32, "q4iq16bUcC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1ub_s64, "q2Wiq16bUcC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1ub_u16, "q8Usq16bUcC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1ub_u32, "q4Uiq16bUcC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1ub_u64, "q2UWiq16bUcC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1ub_vnum_s16, "q8sq16bUcC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1ub_vnum_s32, "q4iq16bUcC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1ub_vnum_s64, "q2Wiq16bUcC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1ub_vnum_u16, "q8Usq16bUcC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1ub_vnum_u32, "q4Uiq16bUcC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1ub_vnum_u64, "q2UWiq16bUcC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1udq_f64, "q2dq16bdC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1udq_s64, "q2Wiq16bSWiC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1udq_u64, "q2UWiq16bUWiC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1udq_vnum_f64, "q2dq16bdC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1udq_vnum_s64, "q2Wiq16bSWiC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1udq_vnum_u64, "q2UWiq16bUWiC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_s32index_s32, "q4iq16bUsC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_s32index_u32, "q4Uiq16bUsC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_s32offset_s32, "q4iq16bUsC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_s32offset_u32, "q4Uiq16bUsC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_s64index_s64, "q2Wiq16bUsC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_s64index_u64, "q2UWiq16bUsC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_s64offset_s64, "q2Wiq16bUsC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_s64offset_u64, "q2UWiq16bUsC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_u32base_index_s32, "q4iq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_u32base_index_u32, "q4Uiq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_u32base_offset_s32, "q4iq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_u32base_offset_u32, "q4Uiq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_u32base_s32, "q4iq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_u32base_u32, "q4Uiq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_u32index_s32, "q4iq16bUsC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_u32index_u32, "q4Uiq16bUsC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_u32offset_s32, "q4iq16bUsC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_u32offset_u32, "q4Uiq16bUsC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_u64base_index_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_u64base_index_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_u64index_s64, "q2Wiq16bUsC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_u64index_u64, "q2UWiq16bUsC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_u64offset_s64, "q2Wiq16bUsC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_gather_u64offset_u64, "q2UWiq16bUsC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uh_s32, "q4iq16bUsC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1uh_s64, "q2Wiq16bUsC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1uh_u32, "q4Uiq16bUsC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1uh_u64, "q2UWiq16bUsC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1uh_vnum_s32, "q4iq16bUsC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1uh_vnum_s64, "q2Wiq16bUsC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1uh_vnum_u32, "q4Uiq16bUsC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1uh_vnum_u64, "q2UWiq16bUsC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1uw_gather_s64index_s64, "q2Wiq16bUiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uw_gather_s64index_u64, "q2UWiq16bUiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uw_gather_s64offset_s64, "q2Wiq16bUiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uw_gather_s64offset_u64, "q2UWiq16bUiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uw_gather_u64base_index_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uw_gather_u64base_index_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uw_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uw_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uw_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uw_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uw_gather_u64index_s64, "q2Wiq16bUiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uw_gather_u64index_u64, "q2UWiq16bUiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uw_gather_u64offset_s64, "q2Wiq16bUiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uw_gather_u64offset_u64, "q2UWiq16bUiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svld1uw_s64, "q2Wiq16bUiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1uw_u64, "q2UWiq16bUiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1uw_vnum_s64, "q2Wiq16bUiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1uw_vnum_u64, "q2UWiq16bUiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld1uwq_f32, "q4fq16bfC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1uwq_s32, "q4iq16bSiC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1uwq_u32, "q4Uiq16bUiC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1uwq_vnum_f32, "q4fq16bfC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1uwq_vnum_s32, "q4iq16bSiC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld1uwq_vnum_u32, "q4Uiq16bUiC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2_bf16, "q16yq16byC*", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svld2_f16, "q16hq16bhC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_f32, "q8fq16bfC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_f64, "q4dq16bdC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_s16, "q16sq16bSsC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_s32, "q8iq16bSiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_s64, "q4Wiq16bSWiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_s8, "q32Scq16bScC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_u16, "q16Usq16bUsC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_u32, "q8Uiq16bUiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_u64, "q4UWiq16bUWiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_u8, "q32Ucq16bUcC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_vnum_bf16, "q16yq16byC*Wi", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svld2_vnum_f16, "q16hq16bhC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_vnum_f32, "q8fq16bfC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_vnum_f64, "q4dq16bdC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_vnum_s16, "q16sq16bSsC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_vnum_s32, "q8iq16bSiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_vnum_s64, "q4Wiq16bSWiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_vnum_s8, "q32Scq16bScC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_vnum_u16, "q16Usq16bUsC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_vnum_u32, "q8Uiq16bUiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_vnum_u64, "q4UWiq16bUWiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2_vnum_u8, "q32Ucq16bUcC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld2q_bf16, "q16yq16byC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_f16, "q16hq16bhC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_f32, "q8fq16bfC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_f64, "q4dq16bdC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_s16, "q16sq16bSsC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_s32, "q8iq16bSiC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_s64, "q4Wiq16bSWiC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_s8, "q32Scq16bScC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_u16, "q16Usq16bUsC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_u32, "q8Uiq16bUiC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_u64, "q4UWiq16bUWiC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_u8, "q32Ucq16bUcC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_vnum_bf16, "q16yq16byC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_vnum_f16, "q16hq16bhC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_vnum_f32, "q8fq16bfC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_vnum_f64, "q4dq16bdC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_vnum_s16, "q16sq16bSsC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_vnum_s32, "q8iq16bSiC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_vnum_s64, "q4Wiq16bSWiC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_vnum_s8, "q32Scq16bScC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_vnum_u16, "q16Usq16bUsC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_vnum_u32, "q8Uiq16bUiC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_vnum_u64, "q4UWiq16bUWiC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld2q_vnum_u8, "q32Ucq16bUcC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3_bf16, "q24yq16byC*", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svld3_f16, "q24hq16bhC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_f32, "q12fq16bfC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_f64, "q6dq16bdC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_s16, "q24sq16bSsC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_s32, "q12iq16bSiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_s64, "q6Wiq16bSWiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_s8, "q48Scq16bScC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_u16, "q24Usq16bUsC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_u32, "q12Uiq16bUiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_u64, "q6UWiq16bUWiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_u8, "q48Ucq16bUcC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_vnum_bf16, "q24yq16byC*Wi", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svld3_vnum_f16, "q24hq16bhC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_vnum_f32, "q12fq16bfC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_vnum_f64, "q6dq16bdC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_vnum_s16, "q24sq16bSsC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_vnum_s32, "q12iq16bSiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_vnum_s64, "q6Wiq16bSWiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_vnum_s8, "q48Scq16bScC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_vnum_u16, "q24Usq16bUsC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_vnum_u32, "q12Uiq16bUiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_vnum_u64, "q6UWiq16bUWiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3_vnum_u8, "q48Ucq16bUcC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld3q_bf16, "q24yq16byC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_f16, "q24hq16bhC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_f32, "q12fq16bfC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_f64, "q6dq16bdC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_s16, "q24sq16bSsC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_s32, "q12iq16bSiC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_s64, "q6Wiq16bSWiC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_s8, "q48Scq16bScC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_u16, "q24Usq16bUsC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_u32, "q12Uiq16bUiC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_u64, "q6UWiq16bUWiC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_u8, "q48Ucq16bUcC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_vnum_bf16, "q24yq16byC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_vnum_f16, "q24hq16bhC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_vnum_f32, "q12fq16bfC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_vnum_f64, "q6dq16bdC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_vnum_s16, "q24sq16bSsC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_vnum_s32, "q12iq16bSiC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_vnum_s64, "q6Wiq16bSWiC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_vnum_s8, "q48Scq16bScC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_vnum_u16, "q24Usq16bUsC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_vnum_u32, "q12Uiq16bUiC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_vnum_u64, "q6UWiq16bUWiC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld3q_vnum_u8, "q48Ucq16bUcC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4_bf16, "q32yq16byC*", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svld4_f16, "q32hq16bhC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_f32, "q16fq16bfC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_f64, "q8dq16bdC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_s16, "q32sq16bSsC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_s32, "q16iq16bSiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_s64, "q8Wiq16bSWiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_s8, "q64Scq16bScC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_u16, "q32Usq16bUsC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_u32, "q16Uiq16bUiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_u64, "q8UWiq16bUWiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_u8, "q64Ucq16bUcC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_vnum_bf16, "q32yq16byC*Wi", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svld4_vnum_f16, "q32hq16bhC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_vnum_f32, "q16fq16bfC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_vnum_f64, "q8dq16bdC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_vnum_s16, "q32sq16bSsC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_vnum_s32, "q16iq16bSiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_vnum_s64, "q8Wiq16bSWiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_vnum_s8, "q64Scq16bScC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_vnum_u16, "q32Usq16bUsC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_vnum_u32, "q16Uiq16bUiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_vnum_u64, "q8UWiq16bUWiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4_vnum_u8, "q64Ucq16bUcC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svld4q_bf16, "q32yq16byC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_f16, "q32hq16bhC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_f32, "q16fq16bfC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_f64, "q8dq16bdC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_s16, "q32sq16bSsC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_s32, "q16iq16bSiC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_s64, "q8Wiq16bSWiC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_s8, "q64Scq16bScC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_u16, "q32Usq16bUsC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_u32, "q16Uiq16bUiC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_u64, "q8UWiq16bUWiC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_u8, "q64Ucq16bUcC*", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_vnum_bf16, "q32yq16byC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_vnum_f16, "q32hq16bhC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_vnum_f32, "q16fq16bfC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_vnum_f64, "q8dq16bdC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_vnum_s16, "q32sq16bSsC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_vnum_s32, "q16iq16bSiC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_vnum_s64, "q8Wiq16bSWiC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_vnum_s8, "q64Scq16bScC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_vnum_u16, "q32Usq16bUsC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_vnum_u32, "q16Uiq16bUiC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_vnum_u64, "q8UWiq16bUWiC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svld4q_vnum_u8, "q64Ucq16bUcC*Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svldff1_bf16, "q8yq16byC*", "n", "sve,bf16")
TARGET_BUILTIN(__builtin_sve_svldff1_f16, "q8hq16bhC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_f32, "q4fq16bfC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_f64, "q2dq16bdC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_s32index_f32, "q4fq16bfC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_s32index_s32, "q4iq16bSiC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_s32index_u32, "q4Uiq16bUiC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_s32offset_f32, "q4fq16bfC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_s32offset_s32, "q4iq16bSiC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_s32offset_u32, "q4Uiq16bUiC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_s64index_f64, "q2dq16bdC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_s64index_s64, "q2Wiq16bSWiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_s64index_u64, "q2UWiq16bUWiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_s64offset_f64, "q2dq16bdC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_s64offset_s64, "q2Wiq16bSWiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_s64offset_u64, "q2UWiq16bUWiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u32base_f32, "q4fq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u32base_index_f32, "q4fq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u32base_index_s32, "q4iq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u32base_index_u32, "q4Uiq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u32base_offset_f32, "q4fq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u32base_offset_s32, "q4iq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u32base_offset_u32, "q4Uiq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u32base_s32, "q4iq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u32base_u32, "q4Uiq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u32index_f32, "q4fq16bfC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u32index_s32, "q4iq16bSiC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u32index_u32, "q4Uiq16bUiC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u32offset_f32, "q4fq16bfC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u32offset_s32, "q4iq16bSiC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u32offset_u32, "q4Uiq16bUiC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u64base_f64, "q2dq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u64base_index_f64, "q2dq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u64base_index_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u64base_index_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u64base_offset_f64, "q2dq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u64index_f64, "q2dq16bdC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u64index_s64, "q2Wiq16bSWiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u64index_u64, "q2UWiq16bUWiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u64offset_f64, "q2dq16bdC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u64offset_s64, "q2Wiq16bSWiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_gather_u64offset_u64, "q2UWiq16bUWiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_s16, "q8sq16bSsC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_s32, "q4iq16bSiC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_s64, "q2Wiq16bSWiC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_s8, "q16Scq16bScC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_u16, "q8Usq16bUsC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_u32, "q4Uiq16bUiC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_u64, "q2UWiq16bUWiC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_u8, "q16Ucq16bUcC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_vnum_bf16, "q8yq16byC*Wi", "n", "sve,bf16")
TARGET_BUILTIN(__builtin_sve_svldff1_vnum_f16, "q8hq16bhC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_vnum_f32, "q4fq16bfC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_vnum_f64, "q2dq16bdC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_vnum_s16, "q8sq16bSsC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_vnum_s32, "q4iq16bSiC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_vnum_s64, "q2Wiq16bSWiC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_vnum_s8, "q16Scq16bScC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_vnum_u16, "q8Usq16bUsC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_vnum_u32, "q4Uiq16bUiC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_vnum_u64, "q2UWiq16bUWiC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1_vnum_u8, "q16Ucq16bUcC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_gather_s32offset_s32, "q4iq16bScC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_gather_s32offset_u32, "q4Uiq16bScC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_gather_s64offset_s64, "q2Wiq16bScC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_gather_s64offset_u64, "q2UWiq16bScC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_gather_u32base_offset_s32, "q4iq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_gather_u32base_offset_u32, "q4Uiq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_gather_u32base_s32, "q4iq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_gather_u32base_u32, "q4Uiq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_gather_u32offset_s32, "q4iq16bScC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_gather_u32offset_u32, "q4Uiq16bScC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_gather_u64offset_s64, "q2Wiq16bScC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_gather_u64offset_u64, "q2UWiq16bScC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_s16, "q8sq16bScC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_s32, "q4iq16bScC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_s64, "q2Wiq16bScC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_u16, "q8Usq16bScC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_u32, "q4Uiq16bScC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_u64, "q2UWiq16bScC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_vnum_s16, "q8sq16bScC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_vnum_s32, "q4iq16bScC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_vnum_s64, "q2Wiq16bScC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_vnum_u16, "q8Usq16bScC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_vnum_u32, "q4Uiq16bScC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sb_vnum_u64, "q2UWiq16bScC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_s32index_s32, "q4iq16bSsC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_s32index_u32, "q4Uiq16bSsC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_s32offset_s32, "q4iq16bSsC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_s32offset_u32, "q4Uiq16bSsC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_s64index_s64, "q2Wiq16bSsC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_s64index_u64, "q2UWiq16bSsC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_s64offset_s64, "q2Wiq16bSsC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_s64offset_u64, "q2UWiq16bSsC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_u32base_index_s32, "q4iq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_u32base_index_u32, "q4Uiq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_u32base_offset_s32, "q4iq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_u32base_offset_u32, "q4Uiq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_u32base_s32, "q4iq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_u32base_u32, "q4Uiq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_u32index_s32, "q4iq16bSsC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_u32index_u32, "q4Uiq16bSsC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_u32offset_s32, "q4iq16bSsC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_u32offset_u32, "q4Uiq16bSsC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_u64base_index_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_u64base_index_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_u64index_s64, "q2Wiq16bSsC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_u64index_u64, "q2UWiq16bSsC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_u64offset_s64, "q2Wiq16bSsC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_gather_u64offset_u64, "q2UWiq16bSsC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_s32, "q4iq16bSsC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_s64, "q2Wiq16bSsC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_u32, "q4Uiq16bSsC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_u64, "q2UWiq16bSsC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_vnum_s32, "q4iq16bSsC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_vnum_s64, "q2Wiq16bSsC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_vnum_u32, "q4Uiq16bSsC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sh_vnum_u64, "q2UWiq16bSsC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sw_gather_s64index_s64, "q2Wiq16bSiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sw_gather_s64index_u64, "q2UWiq16bSiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sw_gather_s64offset_s64, "q2Wiq16bSiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sw_gather_s64offset_u64, "q2UWiq16bSiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sw_gather_u64base_index_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sw_gather_u64base_index_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sw_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sw_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sw_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sw_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sw_gather_u64index_s64, "q2Wiq16bSiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sw_gather_u64index_u64, "q2UWiq16bSiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sw_gather_u64offset_s64, "q2Wiq16bSiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sw_gather_u64offset_u64, "q2UWiq16bSiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sw_s64, "q2Wiq16bSiC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sw_u64, "q2UWiq16bSiC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sw_vnum_s64, "q2Wiq16bSiC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1sw_vnum_u64, "q2UWiq16bSiC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_gather_s32offset_s32, "q4iq16bUcC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_gather_s32offset_u32, "q4Uiq16bUcC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_gather_s64offset_s64, "q2Wiq16bUcC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_gather_s64offset_u64, "q2UWiq16bUcC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_gather_u32base_offset_s32, "q4iq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_gather_u32base_offset_u32, "q4Uiq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_gather_u32base_s32, "q4iq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_gather_u32base_u32, "q4Uiq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_gather_u32offset_s32, "q4iq16bUcC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_gather_u32offset_u32, "q4Uiq16bUcC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_gather_u64offset_s64, "q2Wiq16bUcC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_gather_u64offset_u64, "q2UWiq16bUcC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_s16, "q8sq16bUcC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_s32, "q4iq16bUcC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_s64, "q2Wiq16bUcC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_u16, "q8Usq16bUcC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_u32, "q4Uiq16bUcC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_u64, "q2UWiq16bUcC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_vnum_s16, "q8sq16bUcC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_vnum_s32, "q4iq16bUcC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_vnum_s64, "q2Wiq16bUcC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_vnum_u16, "q8Usq16bUcC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_vnum_u32, "q4Uiq16bUcC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1ub_vnum_u64, "q2UWiq16bUcC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_s32index_s32, "q4iq16bUsC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_s32index_u32, "q4Uiq16bUsC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_s32offset_s32, "q4iq16bUsC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_s32offset_u32, "q4Uiq16bUsC*q4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_s64index_s64, "q2Wiq16bUsC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_s64index_u64, "q2UWiq16bUsC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_s64offset_s64, "q2Wiq16bUsC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_s64offset_u64, "q2UWiq16bUsC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_u32base_index_s32, "q4iq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_u32base_index_u32, "q4Uiq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_u32base_offset_s32, "q4iq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_u32base_offset_u32, "q4Uiq16bq4UiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_u32base_s32, "q4iq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_u32base_u32, "q4Uiq16bq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_u32index_s32, "q4iq16bUsC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_u32index_u32, "q4Uiq16bUsC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_u32offset_s32, "q4iq16bUsC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_u32offset_u32, "q4Uiq16bUsC*q4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_u64base_index_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_u64base_index_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_u64index_s64, "q2Wiq16bUsC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_u64index_u64, "q2UWiq16bUsC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_u64offset_s64, "q2Wiq16bUsC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_gather_u64offset_u64, "q2UWiq16bUsC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_s32, "q4iq16bUsC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_s64, "q2Wiq16bUsC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_u32, "q4Uiq16bUsC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_u64, "q2UWiq16bUsC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_vnum_s32, "q4iq16bUsC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_vnum_s64, "q2Wiq16bUsC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_vnum_u32, "q4Uiq16bUsC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uh_vnum_u64, "q2UWiq16bUsC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uw_gather_s64index_s64, "q2Wiq16bUiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uw_gather_s64index_u64, "q2UWiq16bUiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uw_gather_s64offset_s64, "q2Wiq16bUiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uw_gather_s64offset_u64, "q2UWiq16bUiC*q2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uw_gather_u64base_index_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uw_gather_u64base_index_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uw_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uw_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uw_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uw_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uw_gather_u64index_s64, "q2Wiq16bUiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uw_gather_u64index_u64, "q2UWiq16bUiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uw_gather_u64offset_s64, "q2Wiq16bUiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uw_gather_u64offset_u64, "q2UWiq16bUiC*q2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uw_s64, "q2Wiq16bUiC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uw_u64, "q2UWiq16bUiC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uw_vnum_s64, "q2Wiq16bUiC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldff1uw_vnum_u64, "q2UWiq16bUiC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_bf16, "q8yq16byC*", "n", "sve,bf16")
TARGET_BUILTIN(__builtin_sve_svldnf1_f16, "q8hq16bhC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_f32, "q4fq16bfC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_f64, "q2dq16bdC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_s16, "q8sq16bSsC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_s32, "q4iq16bSiC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_s64, "q2Wiq16bSWiC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_s8, "q16Scq16bScC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_u16, "q8Usq16bUsC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_u32, "q4Uiq16bUiC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_u64, "q2UWiq16bUWiC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_u8, "q16Ucq16bUcC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_vnum_bf16, "q8yq16byC*Wi", "n", "sve,bf16")
TARGET_BUILTIN(__builtin_sve_svldnf1_vnum_f16, "q8hq16bhC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_vnum_f32, "q4fq16bfC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_vnum_f64, "q2dq16bdC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_vnum_s16, "q8sq16bSsC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_vnum_s32, "q4iq16bSiC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_vnum_s64, "q2Wiq16bSWiC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_vnum_s8, "q16Scq16bScC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_vnum_u16, "q8Usq16bUsC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_vnum_u32, "q4Uiq16bUiC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_vnum_u64, "q2UWiq16bUWiC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1_vnum_u8, "q16Ucq16bUcC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sb_s16, "q8sq16bScC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sb_s32, "q4iq16bScC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sb_s64, "q2Wiq16bScC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sb_u16, "q8Usq16bScC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sb_u32, "q4Uiq16bScC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sb_u64, "q2UWiq16bScC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sb_vnum_s16, "q8sq16bScC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sb_vnum_s32, "q4iq16bScC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sb_vnum_s64, "q2Wiq16bScC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sb_vnum_u16, "q8Usq16bScC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sb_vnum_u32, "q4Uiq16bScC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sb_vnum_u64, "q2UWiq16bScC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sh_s32, "q4iq16bSsC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sh_s64, "q2Wiq16bSsC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sh_u32, "q4Uiq16bSsC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sh_u64, "q2UWiq16bSsC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sh_vnum_s32, "q4iq16bSsC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sh_vnum_s64, "q2Wiq16bSsC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sh_vnum_u32, "q4Uiq16bSsC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sh_vnum_u64, "q2UWiq16bSsC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sw_s64, "q2Wiq16bSiC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sw_u64, "q2UWiq16bSiC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sw_vnum_s64, "q2Wiq16bSiC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1sw_vnum_u64, "q2UWiq16bSiC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1ub_s16, "q8sq16bUcC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1ub_s32, "q4iq16bUcC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1ub_s64, "q2Wiq16bUcC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1ub_u16, "q8Usq16bUcC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1ub_u32, "q4Uiq16bUcC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1ub_u64, "q2UWiq16bUcC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1ub_vnum_s16, "q8sq16bUcC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1ub_vnum_s32, "q4iq16bUcC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1ub_vnum_s64, "q2Wiq16bUcC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1ub_vnum_u16, "q8Usq16bUcC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1ub_vnum_u32, "q4Uiq16bUcC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1ub_vnum_u64, "q2UWiq16bUcC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1uh_s32, "q4iq16bUsC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1uh_s64, "q2Wiq16bUsC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1uh_u32, "q4Uiq16bUsC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1uh_u64, "q2UWiq16bUsC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1uh_vnum_s32, "q4iq16bUsC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1uh_vnum_s64, "q2Wiq16bUsC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1uh_vnum_u32, "q4Uiq16bUsC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1uh_vnum_u64, "q2UWiq16bUsC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1uw_s64, "q2Wiq16bUiC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1uw_u64, "q2UWiq16bUiC*", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1uw_vnum_s64, "q2Wiq16bUiC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnf1uw_vnum_u64, "q2UWiq16bUiC*Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svldnt1_bf16, "q8yq16byC*", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svldnt1_bf16_x2, "q16yQayC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_bf16_x4, "q32yQayC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_f16, "q8hq16bhC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_f16_x2, "q16hQahC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_f16_x4, "q32hQahC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_f32, "q4fq16bfC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_f32_x2, "q8fQafC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_f32_x4, "q16fQafC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_f64, "q2dq16bdC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_f64_x2, "q4dQadC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_f64_x4, "q8dQadC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_s64index_f64, "q2dq16bdC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_s64index_s64, "q2Wiq16bSWiC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_s64index_u64, "q2UWiq16bUWiC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_s64offset_f64, "q2dq16bdC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_s64offset_s64, "q2Wiq16bSWiC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_s64offset_u64, "q2UWiq16bUWiC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u32base_f32, "q4fq16bq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u32base_index_f32, "q4fq16bq4UiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u32base_index_s32, "q4iq16bq4UiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u32base_index_u32, "q4Uiq16bq4UiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u32base_offset_f32, "q4fq16bq4UiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u32base_offset_s32, "q4iq16bq4UiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u32base_offset_u32, "q4Uiq16bq4UiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u32base_s32, "q4iq16bq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u32base_u32, "q4Uiq16bq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u32offset_f32, "q4fq16bfC*q4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u32offset_s32, "q4iq16bSiC*q4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u32offset_u32, "q4Uiq16bUiC*q4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u64base_f64, "q2dq16bq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u64base_index_f64, "q2dq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u64base_index_s64, "q2Wiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u64base_index_u64, "q2UWiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u64base_offset_f64, "q2dq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u64index_f64, "q2dq16bdC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u64index_s64, "q2Wiq16bSWiC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u64index_u64, "q2UWiq16bUWiC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u64offset_f64, "q2dq16bdC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u64offset_s64, "q2Wiq16bSWiC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_gather_u64offset_u64, "q2UWiq16bUWiC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1_s16, "q8sq16bSsC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_s16_x2, "q16sQaSsC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_s16_x4, "q32sQaSsC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_s32, "q4iq16bSiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_s32_x2, "q8iQaSiC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_s32_x4, "q16iQaSiC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_s64, "q2Wiq16bSWiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_s64_x2, "q4WiQaSWiC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_s64_x4, "q8WiQaSWiC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_s8, "q16Scq16bScC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_s8_x2, "q32ScQaScC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_s8_x4, "q64ScQaScC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_u16, "q8Usq16bUsC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_u16_x2, "q16UsQaUsC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_u16_x4, "q32UsQaUsC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_u32, "q4Uiq16bUiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_u32_x2, "q8UiQaUiC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_u32_x4, "q16UiQaUiC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_u64, "q2UWiq16bUWiC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_u64_x2, "q4UWiQaUWiC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_u64_x4, "q8UWiQaUWiC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_u8, "q16Ucq16bUcC*", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_u8_x2, "q32UcQaUcC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_u8_x4, "q64UcQaUcC*", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_bf16, "q8yq16byC*Wi", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_bf16_x2, "q16yQayC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_bf16_x4, "q32yQayC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_f16, "q8hq16bhC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_f16_x2, "q16hQahC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_f16_x4, "q32hQahC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_f32, "q4fq16bfC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_f32_x2, "q8fQafC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_f32_x4, "q16fQafC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_f64, "q2dq16bdC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_f64_x2, "q4dQadC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_f64_x4, "q8dQadC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_s16, "q8sq16bSsC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_s16_x2, "q16sQaSsC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_s16_x4, "q32sQaSsC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_s32, "q4iq16bSiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_s32_x2, "q8iQaSiC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_s32_x4, "q16iQaSiC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_s64, "q2Wiq16bSWiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_s64_x2, "q4WiQaSWiC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_s64_x4, "q8WiQaSWiC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_s8, "q16Scq16bScC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_s8_x2, "q32ScQaScC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_s8_x4, "q64ScQaScC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_u16, "q8Usq16bUsC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_u16_x2, "q16UsQaUsC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_u16_x4, "q32UsQaUsC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_u32, "q4Uiq16bUiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_u32_x2, "q8UiQaUiC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_u32_x4, "q16UiQaUiC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_u64, "q2UWiq16bUWiC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_u64_x2, "q4UWiQaUWiC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_u64_x4, "q8UWiQaUWiC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_u8, "q16Ucq16bUcC*Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_u8_x2, "q32UcQaUcC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1_vnum_u8_x4, "q64UcQaUcC*Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svldnt1sb_gather_s64offset_s64, "q2Wiq16bScC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sb_gather_s64offset_u64, "q2UWiq16bScC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sb_gather_u32base_offset_s32, "q4iq16bq4UiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sb_gather_u32base_offset_u32, "q4Uiq16bq4UiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sb_gather_u32base_s32, "q4iq16bq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sb_gather_u32base_u32, "q4Uiq16bq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sb_gather_u32offset_s32, "q4iq16bScC*q4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sb_gather_u32offset_u32, "q4Uiq16bScC*q4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sb_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sb_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sb_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sb_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sb_gather_u64offset_s64, "q2Wiq16bScC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sb_gather_u64offset_u64, "q2UWiq16bScC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_s64index_s64, "q2Wiq16bSsC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_s64index_u64, "q2UWiq16bSsC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_s64offset_s64, "q2Wiq16bSsC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_s64offset_u64, "q2UWiq16bSsC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_u32base_index_s32, "q4iq16bq4UiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_u32base_index_u32, "q4Uiq16bq4UiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_u32base_offset_s32, "q4iq16bq4UiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_u32base_offset_u32, "q4Uiq16bq4UiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_u32base_s32, "q4iq16bq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_u32base_u32, "q4Uiq16bq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_u32offset_s32, "q4iq16bSsC*q4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_u32offset_u32, "q4Uiq16bSsC*q4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_u64base_index_s64, "q2Wiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_u64base_index_u64, "q2UWiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_u64index_s64, "q2Wiq16bSsC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_u64index_u64, "q2UWiq16bSsC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_u64offset_s64, "q2Wiq16bSsC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sh_gather_u64offset_u64, "q2UWiq16bSsC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sw_gather_s64index_s64, "q2Wiq16bSiC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sw_gather_s64index_u64, "q2UWiq16bSiC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sw_gather_s64offset_s64, "q2Wiq16bSiC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sw_gather_s64offset_u64, "q2UWiq16bSiC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sw_gather_u64base_index_s64, "q2Wiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sw_gather_u64base_index_u64, "q2UWiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sw_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sw_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sw_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sw_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sw_gather_u64index_s64, "q2Wiq16bSiC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sw_gather_u64index_u64, "q2UWiq16bSiC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sw_gather_u64offset_s64, "q2Wiq16bSiC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1sw_gather_u64offset_u64, "q2UWiq16bSiC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1ub_gather_s64offset_s64, "q2Wiq16bUcC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1ub_gather_s64offset_u64, "q2UWiq16bUcC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1ub_gather_u32base_offset_s32, "q4iq16bq4UiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1ub_gather_u32base_offset_u32, "q4Uiq16bq4UiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1ub_gather_u32base_s32, "q4iq16bq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1ub_gather_u32base_u32, "q4Uiq16bq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1ub_gather_u32offset_s32, "q4iq16bUcC*q4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1ub_gather_u32offset_u32, "q4Uiq16bUcC*q4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1ub_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1ub_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1ub_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1ub_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1ub_gather_u64offset_s64, "q2Wiq16bUcC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1ub_gather_u64offset_u64, "q2UWiq16bUcC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_s64index_s64, "q2Wiq16bUsC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_s64index_u64, "q2UWiq16bUsC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_s64offset_s64, "q2Wiq16bUsC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_s64offset_u64, "q2UWiq16bUsC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_u32base_index_s32, "q4iq16bq4UiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_u32base_index_u32, "q4Uiq16bq4UiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_u32base_offset_s32, "q4iq16bq4UiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_u32base_offset_u32, "q4Uiq16bq4UiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_u32base_s32, "q4iq16bq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_u32base_u32, "q4Uiq16bq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_u32offset_s32, "q4iq16bUsC*q4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_u32offset_u32, "q4Uiq16bUsC*q4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_u64base_index_s64, "q2Wiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_u64base_index_u64, "q2UWiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_u64index_s64, "q2Wiq16bUsC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_u64index_u64, "q2UWiq16bUsC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_u64offset_s64, "q2Wiq16bUsC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uh_gather_u64offset_u64, "q2UWiq16bUsC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uw_gather_s64index_s64, "q2Wiq16bUiC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uw_gather_s64index_u64, "q2UWiq16bUiC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uw_gather_s64offset_s64, "q2Wiq16bUiC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uw_gather_s64offset_u64, "q2UWiq16bUiC*q2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uw_gather_u64base_index_s64, "q2Wiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uw_gather_u64base_index_u64, "q2UWiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uw_gather_u64base_offset_s64, "q2Wiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uw_gather_u64base_offset_u64, "q2UWiq16bq2UWiWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uw_gather_u64base_s64, "q2Wiq16bq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uw_gather_u64base_u64, "q2UWiq16bq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uw_gather_u64index_s64, "q2Wiq16bUiC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uw_gather_u64index_u64, "q2UWiq16bUiC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uw_gather_u64offset_s64, "q2Wiq16bUiC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svldnt1uw_gather_u64offset_u64, "q2UWiq16bUiC*q2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svlen_bf16, "UWiq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svlen_f16, "UWiq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlen_f32, "UWiq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlen_f64, "UWiq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlen_s16, "UWiq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlen_s32, "UWiq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlen_s64, "UWiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlen_s8, "UWiq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlen_u16, "UWiq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlen_u32, "UWiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlen_u64, "UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlen_u8, "UWiq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlogb_f16_m, "q8sq8sq16bq8h", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svlogb_f16_x, "q8sq16bq8h", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svlogb_f16_z, "q8sq16bq8h", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svlogb_f32_m, "q4iq4iq16bq4f", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svlogb_f32_x, "q4iq16bq4f", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svlogb_f32_z, "q4iq16bq4f", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svlogb_f64_m, "q2Wiq2Wiq16bq2d", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svlogb_f64_x, "q2Wiq16bq2d", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svlogb_f64_z, "q2Wiq16bq2d", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_s16_m, "q8sq16bq8sUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_s16_x, "q8sq16bq8sUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_s16_z, "q8sq16bq8sUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_s32_m, "q4iq16bq4iUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_s32_x, "q4iq16bq4iUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_s32_z, "q4iq16bq4iUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_s64_m, "q2Wiq16bq2WiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_s64_x, "q2Wiq16bq2WiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_s64_z, "q2Wiq16bq2WiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_s8_m, "q16Scq16bq16ScUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_s8_x, "q16Scq16bq16ScUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_s8_z, "q16Scq16bq16ScUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_u16_m, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_u16_x, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_u16_z, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_u32_m, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_u32_x, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_u32_z, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_u8_m, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_u8_x, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_n_u8_z, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_s16_m, "q8sq16bq8sq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_s16_x, "q8sq16bq8sq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_s16_z, "q8sq16bq8sq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_s32_m, "q4iq16bq4iq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_s32_x, "q4iq16bq4iq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_s32_z, "q4iq16bq4iq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_s64_m, "q2Wiq16bq2Wiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_s64_x, "q2Wiq16bq2Wiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_s64_z, "q2Wiq16bq2Wiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_s8_m, "q16Scq16bq16Scq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_s8_x, "q16Scq16bq16Scq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_s8_z, "q16Scq16bq16Scq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_u16_m, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_u16_x, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_u16_z, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_n_s16_m, "q8sq16bq8sUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_n_s16_x, "q8sq16bq8sUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_n_s16_z, "q8sq16bq8sUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_n_s32_m, "q4iq16bq4iUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_n_s32_x, "q4iq16bq4iUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_n_s32_z, "q4iq16bq4iUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_n_s8_m, "q16Scq16bq16ScUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_n_s8_x, "q16Scq16bq16ScUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_n_s8_z, "q16Scq16bq16ScUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_n_u16_m, "q8Usq16bq8UsUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_n_u16_x, "q8Usq16bq8UsUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_n_u16_z, "q8Usq16bq8UsUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_n_u32_m, "q4Uiq16bq4UiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_n_u32_x, "q4Uiq16bq4UiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_n_u32_z, "q4Uiq16bq4UiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_n_u8_m, "q16Ucq16bq16UcUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_n_u8_x, "q16Ucq16bq16UcUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_n_u8_z, "q16Ucq16bq16UcUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_s16_m, "q8sq16bq8sq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_s16_x, "q8sq16bq8sq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_s16_z, "q8sq16bq8sq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_s32_m, "q4iq16bq4iq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_s32_x, "q4iq16bq4iq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_s32_z, "q4iq16bq4iq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_s8_m, "q16Scq16bq16Scq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_s8_x, "q16Scq16bq16Scq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_s8_z, "q16Scq16bq16Scq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_u16_m, "q8Usq16bq8Usq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_u16_x, "q8Usq16bq8Usq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_u16_z, "q8Usq16bq8Usq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_u32_m, "q4Uiq16bq4Uiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_u32_x, "q4Uiq16bq4Uiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_u32_z, "q4Uiq16bq4Uiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_u8_m, "q16Ucq16bq16Ucq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_u8_x, "q16Ucq16bq16Ucq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsl_wide_u8_z, "q16Ucq16bq16Ucq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_n_u16_m, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_n_u16_x, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_n_u16_z, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_n_u32_m, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_n_u32_x, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_n_u32_z, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_n_u8_m, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_n_u8_x, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_n_u8_z, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_u16_m, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_u16_x, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_u16_z, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_wide_n_u16_m, "q8Usq16bq8UsUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_wide_n_u16_x, "q8Usq16bq8UsUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_wide_n_u16_z, "q8Usq16bq8UsUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_wide_n_u32_m, "q4Uiq16bq4UiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_wide_n_u32_x, "q4Uiq16bq4UiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_wide_n_u32_z, "q4Uiq16bq4UiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_wide_n_u8_m, "q16Ucq16bq16UcUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_wide_n_u8_x, "q16Ucq16bq16UcUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_wide_n_u8_z, "q16Ucq16bq16UcUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_wide_u16_m, "q8Usq16bq8Usq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_wide_u16_x, "q8Usq16bq8Usq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_wide_u16_z, "q8Usq16bq8Usq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_wide_u32_m, "q4Uiq16bq4Uiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_wide_u32_x, "q4Uiq16bq4Uiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_wide_u32_z, "q4Uiq16bq4Uiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_wide_u8_m, "q16Ucq16bq16Ucq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_wide_u8_x, "q16Ucq16bq16Ucq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svlsr_wide_u8_z, "q16Ucq16bq16Ucq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svluti2_lane_bf16, "q8yq8yq16UcIUWi", "n", "(sve,sve2,lut,bf16)|(sme,sme2,lut,bf16)")
TARGET_BUILTIN(__builtin_sve_svluti2_lane_f16, "q8hq8hq16UcIUWi", "n", "(sve,sve2,lut)|(sme,sme2,lut)")
TARGET_BUILTIN(__builtin_sve_svluti2_lane_s16, "q8sq8sq16UcIUWi", "n", "(sve,sve2,lut)|(sme,sme2,lut)")
TARGET_BUILTIN(__builtin_sve_svluti2_lane_s8, "q16Scq16Scq16UcIUWi", "n", "(sve,sve2,lut)|(sme,sme2,lut)")
TARGET_BUILTIN(__builtin_sve_svluti2_lane_u16, "q8Usq8Usq16UcIUWi", "n", "(sve,sve2,lut)|(sme,sme2,lut)")
TARGET_BUILTIN(__builtin_sve_svluti2_lane_u8, "q16Ucq16Ucq16UcIUWi", "n", "(sve,sve2,lut)|(sme,sme2,lut)")
TARGET_BUILTIN(__builtin_sve_svluti4_lane_bf16, "q8yq8yq16UcIUWi", "n", "(sve,sve2,lut,bf16)|(sme,sme2,lut,bf16)")
TARGET_BUILTIN(__builtin_sve_svluti4_lane_bf16_x2, "q8yq16yq16UcIUWi", "n", "(sve,sve2,lut,bf16)|(sme,sme2,lut,bf16)")
TARGET_BUILTIN(__builtin_sve_svluti4_lane_f16, "q8hq8hq16UcIUWi", "n", "(sve,sve2,lut)|(sme,sme2,lut)")
TARGET_BUILTIN(__builtin_sve_svluti4_lane_f16_x2, "q8hq16hq16UcIUWi", "n", "(sve,sve2,lut)|(sme,sme2,lut)")
TARGET_BUILTIN(__builtin_sve_svluti4_lane_s16, "q8sq8sq16UcIUWi", "n", "(sve,sve2,lut)|(sme,sme2,lut)")
TARGET_BUILTIN(__builtin_sve_svluti4_lane_s16_x2, "q8sq16sq16UcIUWi", "n", "(sve,sve2,lut)|(sme,sme2,lut)")
TARGET_BUILTIN(__builtin_sve_svluti4_lane_s8, "q16Scq16Scq16UcIUWi", "n", "(sve,sve2,lut)|(sme,sme2,lut)")
TARGET_BUILTIN(__builtin_sve_svluti4_lane_u16, "q8Usq8Usq16UcIUWi", "n", "(sve,sve2,lut)|(sme,sme2,lut)")
TARGET_BUILTIN(__builtin_sve_svluti4_lane_u16_x2, "q8Usq16Usq16UcIUWi", "n", "(sve,sve2,lut)|(sme,sme2,lut)")
TARGET_BUILTIN(__builtin_sve_svluti4_lane_u8, "q16Ucq16Ucq16UcIUWi", "n", "(sve,sve2,lut)|(sme,sme2,lut)")
TARGET_BUILTIN(__builtin_sve_svmad_f16_m, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_f16_x, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_f16_z, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_f32_m, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_f32_x, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_f32_z, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_f64_m, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_f64_x, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_f64_z, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_f16_m, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_f16_x, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_f16_z, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_f32_m, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_f32_x, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_f32_z, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_f64_m, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_f64_x, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_f64_z, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_s16_m, "q8sq16bq8sq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_s16_x, "q8sq16bq8sq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_s16_z, "q8sq16bq8sq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_s32_m, "q4iq16bq4iq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_s32_x, "q4iq16bq4iq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_s32_z, "q4iq16bq4iq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_s64_m, "q2Wiq16bq2Wiq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_s64_x, "q2Wiq16bq2Wiq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_s64_z, "q2Wiq16bq2Wiq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_s8_m, "q16Scq16bq16Scq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_s8_x, "q16Scq16bq16Scq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_s8_z, "q16Scq16bq16Scq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_u16_m, "q8Usq16bq8Usq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_u16_x, "q8Usq16bq8Usq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_u16_z, "q8Usq16bq8Usq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_u32_m, "q4Uiq16bq4Uiq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_u32_x, "q4Uiq16bq4Uiq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_u32_z, "q4Uiq16bq4Uiq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_u64_m, "q2UWiq16bq2UWiq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_u64_x, "q2UWiq16bq2UWiq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_u64_z, "q2UWiq16bq2UWiq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_u8_m, "q16Ucq16bq16Ucq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_u8_x, "q16Ucq16bq16Ucq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_n_u8_z, "q16Ucq16bq16Ucq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_s16_m, "q8sq16bq8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_s16_x, "q8sq16bq8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_s16_z, "q8sq16bq8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_s32_m, "q4iq16bq4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_s32_x, "q4iq16bq4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_s32_z, "q4iq16bq4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_s64_m, "q2Wiq16bq2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_s64_x, "q2Wiq16bq2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_s64_z, "q2Wiq16bq2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_s8_m, "q16Scq16bq16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_s8_x, "q16Scq16bq16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_s8_z, "q16Scq16bq16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_u16_m, "q8Usq16bq8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_u16_x, "q8Usq16bq8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_u16_z, "q8Usq16bq8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_u32_m, "q4Uiq16bq4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_u32_x, "q4Uiq16bq4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_u32_z, "q4Uiq16bq4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_u64_m, "q2UWiq16bq2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_u64_x, "q2UWiq16bq2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_u64_z, "q2UWiq16bq2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_u8_m, "q16Ucq16bq16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_u8_x, "q16Ucq16bq16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmad_u8_z, "q16Ucq16bq16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmatch_s16, "q16bq16bq8sq8s", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svmatch_s8, "q16bq16bq16Scq16Sc", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svmatch_u16, "q16bq16bq8Usq8Us", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svmatch_u8, "q16bq16bq16Ucq16Uc", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svmax_bf16_m, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmax_bf16_x, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmax_bf16_x2, "q16yq16yq16y", "n", "sme,sme2,sve-b16b16")
TARGET_BUILTIN(__builtin_sve_svmax_bf16_x4, "q32yq32yq32y", "n", "sme,sme2,sve-b16b16")
TARGET_BUILTIN(__builtin_sve_svmax_bf16_z, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmax_f16_m, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_f16_x, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_f16_x2, "q16hq16hq16h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_f16_x4, "q32hq32hq32h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_f16_z, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_f32_m, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_f32_x, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_f32_x2, "q8fq8fq8f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_f32_x4, "q16fq16fq16f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_f32_z, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_f64_m, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_f64_x, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_f64_x2, "q4dq4dq4d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_f64_x4, "q8dq8dq8d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_f64_z, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_bf16_m, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmax_n_bf16_x, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmax_n_bf16_z, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmax_n_f16_m, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_f16_x, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_f16_z, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_f32_m, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_f32_x, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_f32_z, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_f64_m, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_f64_x, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_f64_z, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_s16_m, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_s16_x, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_s16_z, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_s32_m, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_s32_x, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_s32_z, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_s64_m, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_s64_x, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_s64_z, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_s8_m, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_s8_x, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_s8_z, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_u16_m, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_u16_x, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_u16_z, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_u32_m, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_u32_x, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_u32_z, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_u8_m, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_u8_x, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_n_u8_z, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_s16_m, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_s16_x, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_s16_x2, "q16sq16sq16s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_s16_x4, "q32sq32sq32s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_s16_z, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_s32_m, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_s32_x, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_s32_x2, "q8iq8iq8i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_s32_x4, "q16iq16iq16i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_s32_z, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_s64_x2, "q4Wiq4Wiq4Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_s64_x4, "q8Wiq8Wiq8Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_s8_m, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_s8_x, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_s8_x2, "q32Scq32Scq32Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_s8_x4, "q64Scq64Scq64Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_s8_z, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_single_bf16_x2, "q16yq16yq8y", "n", "sme,sme2,sve-b16b16")
TARGET_BUILTIN(__builtin_sve_svmax_single_bf16_x4, "q32yq32yq8y", "n", "sme,sme2,sve-b16b16")
TARGET_BUILTIN(__builtin_sve_svmax_single_f16_x2, "q16hq16hq8h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_f16_x4, "q32hq32hq8h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_f32_x2, "q8fq8fq4f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_f32_x4, "q16fq16fq4f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_f64_x2, "q4dq4dq2d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_f64_x4, "q8dq8dq2d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_s16_x2, "q16sq16sq8s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_s16_x4, "q32sq32sq8s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_s32_x2, "q8iq8iq4i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_s32_x4, "q16iq16iq4i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_s64_x2, "q4Wiq4Wiq2Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_s64_x4, "q8Wiq8Wiq2Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_s8_x2, "q32Scq32Scq16Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_s8_x4, "q64Scq64Scq16Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_u16_x2, "q16Usq16Usq8Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_u16_x4, "q32Usq32Usq8Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_u32_x2, "q8Uiq8Uiq4Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_u32_x4, "q16Uiq16Uiq4Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_u64_x2, "q4UWiq4UWiq2UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_u64_x4, "q8UWiq8UWiq2UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_u8_x2, "q32Ucq32Ucq16Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_single_u8_x4, "q64Ucq64Ucq16Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_u16_m, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_u16_x, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_u16_x2, "q16Usq16Usq16Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_u16_x4, "q32Usq32Usq32Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_u16_z, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_u32_x2, "q8Uiq8Uiq8Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_u32_x4, "q16Uiq16Uiq16Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_u64_x2, "q4UWiq4UWiq4UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_u64_x4, "q8UWiq8UWiq8UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmax_u8_x2, "q32Ucq32Ucq32Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_u8_x4, "q64Ucq64Ucq64Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmax_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnm_bf16_m, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmaxnm_bf16_x, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmaxnm_bf16_x2, "q16yq16yq16y", "n", "sme,sme2,sve-b16b16")
TARGET_BUILTIN(__builtin_sve_svmaxnm_bf16_x4, "q32yq32yq32y", "n", "sme,sme2,sve-b16b16")
TARGET_BUILTIN(__builtin_sve_svmaxnm_bf16_z, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmaxnm_f16_m, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnm_f16_x, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnm_f16_x2, "q16hq16hq16h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmaxnm_f16_x4, "q32hq32hq32h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmaxnm_f16_z, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnm_f32_m, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnm_f32_x, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnm_f32_x2, "q8fq8fq8f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmaxnm_f32_x4, "q16fq16fq16f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmaxnm_f32_z, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnm_f64_m, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnm_f64_x, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnm_f64_x2, "q4dq4dq4d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmaxnm_f64_x4, "q8dq8dq8d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmaxnm_f64_z, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnm_n_bf16_m, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmaxnm_n_bf16_x, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmaxnm_n_bf16_z, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmaxnm_n_f16_m, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnm_n_f16_x, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnm_n_f16_z, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnm_n_f32_m, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnm_n_f32_x, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnm_n_f32_z, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnm_n_f64_m, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnm_n_f64_x, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnm_n_f64_z, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnm_single_bf16_x2, "q16yq16yq8y", "n", "sme,sme2,sve-b16b16")
TARGET_BUILTIN(__builtin_sve_svmaxnm_single_bf16_x4, "q32yq32yq8y", "n", "sme,sme2,sve-b16b16")
TARGET_BUILTIN(__builtin_sve_svmaxnm_single_f16_x2, "q16hq16hq8h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmaxnm_single_f16_x4, "q32hq32hq8h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmaxnm_single_f32_x2, "q8fq8fq4f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmaxnm_single_f32_x4, "q16fq16fq4f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmaxnm_single_f64_x2, "q4dq4dq2d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmaxnm_single_f64_x4, "q8dq8dq2d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmaxnmp_f16_m, "q8hq16bq8hq8h", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnmp_f16_x, "q8hq16bq8hq8h", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnmp_f32_m, "q4fq16bq4fq4f", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnmp_f32_x, "q4fq16bq4fq4f", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnmp_f64_m, "q2dq16bq2dq2d", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnmp_f64_x, "q2dq16bq2dq2d", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnmqv_f16, "V8hq16bq8h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svmaxnmqv_f32, "V4fq16bq4f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svmaxnmqv_f64, "V2dq16bq2d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svmaxnmv_f16, "hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnmv_f32, "fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxnmv_f64, "dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_f16_m, "q8hq16bq8hq8h", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_f16_x, "q8hq16bq8hq8h", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_f32_m, "q4fq16bq4fq4f", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_f32_x, "q4fq16bq4fq4f", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_f64_m, "q2dq16bq2dq2d", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_f64_x, "q2dq16bq2dq2d", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_s16_m, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_s16_x, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_s32_m, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_s32_x, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_s8_m, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_s8_x, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_u16_m, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_u16_x, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxp_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmaxqv_f16, "V8hq16bq8h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svmaxqv_f32, "V4fq16bq4f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svmaxqv_f64, "V2dq16bq2d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svmaxqv_s16, "V8sq16bq8s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svmaxqv_s32, "V4iq16bq4i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svmaxqv_s64, "V2Wiq16bq2Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svmaxqv_s8, "V16Scq16bq16Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svmaxqv_u16, "V8Usq16bq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svmaxqv_u32, "V4Uiq16bq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svmaxqv_u64, "V2UWiq16bq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svmaxqv_u8, "V16Ucq16bq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svmaxv_f16, "hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxv_f32, "fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxv_f64, "dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxv_s16, "sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxv_s32, "iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxv_s64, "Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxv_s8, "Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxv_u16, "Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxv_u32, "Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxv_u64, "UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmaxv_u8, "Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_bf16_m, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmin_bf16_x, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmin_bf16_x2, "q16yq16yq16y", "n", "sme,sme2,sve-b16b16")
TARGET_BUILTIN(__builtin_sve_svmin_bf16_x4, "q32yq32yq32y", "n", "sme,sme2,sve-b16b16")
TARGET_BUILTIN(__builtin_sve_svmin_bf16_z, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmin_f16_m, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_f16_x, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_f16_x2, "q16hq16hq16h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_f16_x4, "q32hq32hq32h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_f16_z, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_f32_m, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_f32_x, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_f32_x2, "q8fq8fq8f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_f32_x4, "q16fq16fq16f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_f32_z, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_f64_m, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_f64_x, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_f64_x2, "q4dq4dq4d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_f64_x4, "q8dq8dq8d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_f64_z, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_bf16_m, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmin_n_bf16_x, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmin_n_bf16_z, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmin_n_f16_m, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_f16_x, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_f16_z, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_f32_m, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_f32_x, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_f32_z, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_f64_m, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_f64_x, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_f64_z, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_s16_m, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_s16_x, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_s16_z, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_s32_m, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_s32_x, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_s32_z, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_s64_m, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_s64_x, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_s64_z, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_s8_m, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_s8_x, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_s8_z, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_u16_m, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_u16_x, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_u16_z, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_u32_m, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_u32_x, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_u32_z, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_u8_m, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_u8_x, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_n_u8_z, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_s16_m, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_s16_x, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_s16_x2, "q16sq16sq16s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_s16_x4, "q32sq32sq32s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_s16_z, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_s32_m, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_s32_x, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_s32_x2, "q8iq8iq8i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_s32_x4, "q16iq16iq16i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_s32_z, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_s64_x2, "q4Wiq4Wiq4Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_s64_x4, "q8Wiq8Wiq8Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_s8_m, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_s8_x, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_s8_x2, "q32Scq32Scq32Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_s8_x4, "q64Scq64Scq64Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_s8_z, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_single_bf16_x2, "q16yq16yq8y", "n", "sme,sme2,sve-b16b16")
TARGET_BUILTIN(__builtin_sve_svmin_single_bf16_x4, "q32yq32yq8y", "n", "sme,sme2,sve-b16b16")
TARGET_BUILTIN(__builtin_sve_svmin_single_f16_x2, "q16hq16hq8h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_f16_x4, "q32hq32hq8h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_f32_x2, "q8fq8fq4f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_f32_x4, "q16fq16fq4f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_f64_x2, "q4dq4dq2d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_f64_x4, "q8dq8dq2d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_s16_x2, "q16sq16sq8s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_s16_x4, "q32sq32sq8s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_s32_x2, "q8iq8iq4i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_s32_x4, "q16iq16iq4i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_s64_x2, "q4Wiq4Wiq2Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_s64_x4, "q8Wiq8Wiq2Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_s8_x2, "q32Scq32Scq16Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_s8_x4, "q64Scq64Scq16Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_u16_x2, "q16Usq16Usq8Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_u16_x4, "q32Usq32Usq8Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_u32_x2, "q8Uiq8Uiq4Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_u32_x4, "q16Uiq16Uiq4Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_u64_x2, "q4UWiq4UWiq2UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_u64_x4, "q8UWiq8UWiq2UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_u8_x2, "q32Ucq32Ucq16Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_single_u8_x4, "q64Ucq64Ucq16Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_u16_m, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_u16_x, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_u16_x2, "q16Usq16Usq16Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_u16_x4, "q32Usq32Usq32Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_u16_z, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_u32_x2, "q8Uiq8Uiq8Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_u32_x4, "q16Uiq16Uiq16Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_u64_x2, "q4UWiq4UWiq4UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_u64_x4, "q8UWiq8UWiq8UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmin_u8_x2, "q32Ucq32Ucq32Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_u8_x4, "q64Ucq64Ucq64Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svmin_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnm_bf16_m, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svminnm_bf16_x, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svminnm_bf16_x2, "q16yq16yq16y", "n", "sme,sme2,sve-b16b16")
TARGET_BUILTIN(__builtin_sve_svminnm_bf16_x4, "q32yq32yq32y", "n", "sme,sme2,sve-b16b16")
TARGET_BUILTIN(__builtin_sve_svminnm_bf16_z, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svminnm_f16_m, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnm_f16_x, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnm_f16_x2, "q16hq16hq16h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svminnm_f16_x4, "q32hq32hq32h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svminnm_f16_z, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnm_f32_m, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnm_f32_x, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnm_f32_x2, "q8fq8fq8f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svminnm_f32_x4, "q16fq16fq16f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svminnm_f32_z, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnm_f64_m, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnm_f64_x, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnm_f64_x2, "q4dq4dq4d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svminnm_f64_x4, "q8dq8dq8d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svminnm_f64_z, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnm_n_bf16_m, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svminnm_n_bf16_x, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svminnm_n_bf16_z, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svminnm_n_f16_m, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnm_n_f16_x, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnm_n_f16_z, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnm_n_f32_m, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnm_n_f32_x, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnm_n_f32_z, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnm_n_f64_m, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnm_n_f64_x, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnm_n_f64_z, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnm_single_bf16_x2, "q16yq16yq8y", "n", "sme,sme2,sve-b16b16")
TARGET_BUILTIN(__builtin_sve_svminnm_single_bf16_x4, "q32yq32yq8y", "n", "sme,sme2,sve-b16b16")
TARGET_BUILTIN(__builtin_sve_svminnm_single_f16_x2, "q16hq16hq8h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svminnm_single_f16_x4, "q32hq32hq8h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svminnm_single_f32_x2, "q8fq8fq4f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svminnm_single_f32_x4, "q16fq16fq4f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svminnm_single_f64_x2, "q4dq4dq2d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svminnm_single_f64_x4, "q8dq8dq2d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svminnmp_f16_m, "q8hq16bq8hq8h", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminnmp_f16_x, "q8hq16bq8hq8h", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminnmp_f32_m, "q4fq16bq4fq4f", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminnmp_f32_x, "q4fq16bq4fq4f", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminnmp_f64_m, "q2dq16bq2dq2d", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminnmp_f64_x, "q2dq16bq2dq2d", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminnmqv_f16, "V8hq16bq8h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svminnmqv_f32, "V4fq16bq4f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svminnmqv_f64, "V2dq16bq2d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svminnmv_f16, "hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnmv_f32, "fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminnmv_f64, "dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminp_f16_m, "q8hq16bq8hq8h", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_f16_x, "q8hq16bq8hq8h", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_f32_m, "q4fq16bq4fq4f", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_f32_x, "q4fq16bq4fq4f", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_f64_m, "q2dq16bq2dq2d", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_f64_x, "q2dq16bq2dq2d", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_s16_m, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_s16_x, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_s32_m, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_s32_x, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_s8_m, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_s8_x, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_u16_m, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_u16_x, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminp_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svminqv_f16, "V8hq16bq8h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svminqv_f32, "V4fq16bq4f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svminqv_f64, "V2dq16bq2d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svminqv_s16, "V8sq16bq8s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svminqv_s32, "V4iq16bq4i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svminqv_s64, "V2Wiq16bq2Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svminqv_s8, "V16Scq16bq16Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svminqv_u16, "V8Usq16bq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svminqv_u32, "V4Uiq16bq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svminqv_u64, "V2UWiq16bq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svminqv_u8, "V16Ucq16bq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svminv_f16, "hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminv_f32, "fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminv_f64, "dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminv_s16, "sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminv_s32, "iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminv_s64, "Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminv_s8, "Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminv_u16, "Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminv_u32, "Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminv_u64, "UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svminv_u8, "Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_bf16_m, "q8yq16bq8yq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmla_bf16_x, "q8yq16bq8yq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmla_bf16_z, "q8yq16bq8yq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmla_f16_m, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_f16_x, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_f16_z, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_f32_m, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_f32_x, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_f32_z, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_f64_m, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_f64_x, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_f64_z, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_lane_bf16, "q8yq8yq8yq8yIUWi", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmla_lane_f16, "q8hq8hq8hq8hIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_lane_f32, "q4fq4fq4fq4fIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_lane_f64, "q2dq2dq2dq2dIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_lane_s16, "q8sq8sq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmla_lane_s32, "q4iq4iq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmla_lane_s64, "q2Wiq2Wiq2Wiq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmla_lane_u16, "q8Usq8Usq8Usq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmla_lane_u32, "q4Uiq4Uiq4Uiq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmla_lane_u64, "q2UWiq2UWiq2UWiq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_bf16_m, "q8yq16bq8yq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmla_n_bf16_x, "q8yq16bq8yq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmla_n_bf16_z, "q8yq16bq8yq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmla_n_f16_m, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_f16_x, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_f16_z, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_f32_m, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_f32_x, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_f32_z, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_f64_m, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_f64_x, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_f64_z, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_s16_m, "q8sq16bq8sq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_s16_x, "q8sq16bq8sq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_s16_z, "q8sq16bq8sq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_s32_m, "q4iq16bq4iq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_s32_x, "q4iq16bq4iq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_s32_z, "q4iq16bq4iq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_s64_m, "q2Wiq16bq2Wiq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_s64_x, "q2Wiq16bq2Wiq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_s64_z, "q2Wiq16bq2Wiq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_s8_m, "q16Scq16bq16Scq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_s8_x, "q16Scq16bq16Scq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_s8_z, "q16Scq16bq16Scq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_u16_m, "q8Usq16bq8Usq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_u16_x, "q8Usq16bq8Usq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_u16_z, "q8Usq16bq8Usq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_u32_m, "q4Uiq16bq4Uiq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_u32_x, "q4Uiq16bq4Uiq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_u32_z, "q4Uiq16bq4Uiq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_u64_m, "q2UWiq16bq2UWiq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_u64_x, "q2UWiq16bq2UWiq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_u64_z, "q2UWiq16bq2UWiq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_u8_m, "q16Ucq16bq16Ucq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_u8_x, "q16Ucq16bq16Ucq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_n_u8_z, "q16Ucq16bq16Ucq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_s16_m, "q8sq16bq8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_s16_x, "q8sq16bq8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_s16_z, "q8sq16bq8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_s32_m, "q4iq16bq4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_s32_x, "q4iq16bq4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_s32_z, "q4iq16bq4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_s64_m, "q2Wiq16bq2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_s64_x, "q2Wiq16bq2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_s64_z, "q2Wiq16bq2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_s8_m, "q16Scq16bq16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_s8_x, "q16Scq16bq16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_s8_z, "q16Scq16bq16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_u16_m, "q8Usq16bq8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_u16_x, "q8Usq16bq8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_u16_z, "q8Usq16bq8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_u32_m, "q4Uiq16bq4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_u32_x, "q4Uiq16bq4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_u32_z, "q4Uiq16bq4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_u64_m, "q2UWiq16bq2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_u64_x, "q2UWiq16bq2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_u64_z, "q2UWiq16bq2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_u8_m, "q16Ucq16bq16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_u8_x, "q16Ucq16bq16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmla_u8_z, "q16Ucq16bq16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmlalb_f16_mf8_fpm, "q8hq8hq16mq16mUWi", "n", "(sve,sve2,fp8fma)|(sme,ssve-fp8fma)")
TARGET_BUILTIN(__builtin_sve_svmlalb_f32, "q4fq4fq8hq8h", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalb_lane_f16_mf8_fpm, "q8hq8hq16mq16mIUWiUWi", "n", "(sve,sve2,fp8fma)|(sme,ssve-fp8fma)")
TARGET_BUILTIN(__builtin_sve_svmlalb_lane_f32, "q4fq4fq8hq8hIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalb_lane_s32, "q4iq4iq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalb_lane_s64, "q2Wiq2Wiq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalb_lane_u32, "q4Uiq4Uiq8Usq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalb_lane_u64, "q2UWiq2UWiq4Uiq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalb_n_f16_mf8_fpm, "q8hq8hq16mmUWi", "n", "(sve,sve2,fp8fma)|(sme,ssve-fp8fma)")
TARGET_BUILTIN(__builtin_sve_svmlalb_n_f32, "q4fq4fq8hh", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalb_n_s16, "q8sq8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalb_n_s32, "q4iq4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalb_n_s64, "q2Wiq2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalb_n_u16, "q8Usq8Usq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalb_n_u32, "q4Uiq4Uiq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalb_n_u64, "q2UWiq2UWiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalb_s16, "q8sq8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalb_s32, "q4iq4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalb_s64, "q2Wiq2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalb_u16, "q8Usq8Usq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalb_u32, "q4Uiq4Uiq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalb_u64, "q2UWiq2UWiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlallbb_f32_mf8_fpm, "q4fq4fq16mq16mUWi", "n", "(sve,sve2,fp8fma)|(sme,ssve-fp8fma)")
TARGET_BUILTIN(__builtin_sve_svmlallbb_lane_f32_mf8_fpm, "q4fq4fq16mq16mIUWiUWi", "n", "(sve,sve2,fp8fma)|(sme,ssve-fp8fma)")
TARGET_BUILTIN(__builtin_sve_svmlallbb_n_f32_mf8_fpm, "q4fq4fq16mmUWi", "n", "(sve,sve2,fp8fma)|(sme,ssve-fp8fma)")
TARGET_BUILTIN(__builtin_sve_svmlallbt_f32_mf8_fpm, "q4fq4fq16mq16mUWi", "n", "(sve,sve2,fp8fma)|(sme,ssve-fp8fma)")
TARGET_BUILTIN(__builtin_sve_svmlallbt_lane_f32_mf8_fpm, "q4fq4fq16mq16mIUWiUWi", "n", "(sve,sve2,fp8fma)|(sme,ssve-fp8fma)")
TARGET_BUILTIN(__builtin_sve_svmlallbt_n_f32_mf8_fpm, "q4fq4fq16mmUWi", "n", "(sve,sve2,fp8fma)|(sme,ssve-fp8fma)")
TARGET_BUILTIN(__builtin_sve_svmlalltb_f32_mf8_fpm, "q4fq4fq16mq16mUWi", "n", "(sve,sve2,fp8fma)|(sme,ssve-fp8fma)")
TARGET_BUILTIN(__builtin_sve_svmlalltb_lane_f32_mf8_fpm, "q4fq4fq16mq16mIUWiUWi", "n", "(sve,sve2,fp8fma)|(sme,ssve-fp8fma)")
TARGET_BUILTIN(__builtin_sve_svmlalltb_n_f32_mf8_fpm, "q4fq4fq16mmUWi", "n", "(sve,sve2,fp8fma)|(sme,ssve-fp8fma)")
TARGET_BUILTIN(__builtin_sve_svmlalltt_f32_mf8_fpm, "q4fq4fq16mq16mUWi", "n", "(sve,sve2,fp8fma)|(sme,ssve-fp8fma)")
TARGET_BUILTIN(__builtin_sve_svmlalltt_lane_f32_mf8_fpm, "q4fq4fq16mq16mIUWiUWi", "n", "(sve,sve2,fp8fma)|(sme,ssve-fp8fma)")
TARGET_BUILTIN(__builtin_sve_svmlalltt_n_f32_mf8_fpm, "q4fq4fq16mmUWi", "n", "(sve,sve2,fp8fma)|(sme,ssve-fp8fma)")
TARGET_BUILTIN(__builtin_sve_svmlalt_f16_mf8_fpm, "q8hq8hq16mq16mUWi", "n", "(sve,sve2,fp8fma)|(sme,ssve-fp8fma)")
TARGET_BUILTIN(__builtin_sve_svmlalt_f32, "q4fq4fq8hq8h", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalt_lane_f16_mf8_fpm, "q8hq8hq16mq16mIUWiUWi", "n", "(sve,sve2,fp8fma)|(sme,ssve-fp8fma)")
TARGET_BUILTIN(__builtin_sve_svmlalt_lane_f32, "q4fq4fq8hq8hIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalt_lane_s32, "q4iq4iq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalt_lane_s64, "q2Wiq2Wiq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalt_lane_u32, "q4Uiq4Uiq8Usq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalt_lane_u64, "q2UWiq2UWiq4Uiq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalt_n_f16_mf8_fpm, "q8hq8hq16mmUWi", "n", "(sve,sve2,fp8fma)|(sme,ssve-fp8fma)")
TARGET_BUILTIN(__builtin_sve_svmlalt_n_f32, "q4fq4fq8hh", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalt_n_s16, "q8sq8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalt_n_s32, "q4iq4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalt_n_s64, "q2Wiq2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalt_n_u16, "q8Usq8Usq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalt_n_u32, "q4Uiq4Uiq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalt_n_u64, "q2UWiq2UWiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalt_s16, "q8sq8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalt_s32, "q4iq4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalt_s64, "q2Wiq2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalt_u16, "q8Usq8Usq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalt_u32, "q4Uiq4Uiq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlalt_u64, "q2UWiq2UWiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmls_bf16_m, "q8yq16bq8yq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmls_bf16_x, "q8yq16bq8yq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmls_bf16_z, "q8yq16bq8yq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmls_f16_m, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_f16_x, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_f16_z, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_f32_m, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_f32_x, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_f32_z, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_f64_m, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_f64_x, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_f64_z, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_lane_bf16, "q8yq8yq8yq8yIUWi", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmls_lane_f16, "q8hq8hq8hq8hIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_lane_f32, "q4fq4fq4fq4fIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_lane_f64, "q2dq2dq2dq2dIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_lane_s16, "q8sq8sq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmls_lane_s32, "q4iq4iq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmls_lane_s64, "q2Wiq2Wiq2Wiq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmls_lane_u16, "q8Usq8Usq8Usq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmls_lane_u32, "q4Uiq4Uiq4Uiq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmls_lane_u64, "q2UWiq2UWiq2UWiq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_bf16_m, "q8yq16bq8yq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmls_n_bf16_x, "q8yq16bq8yq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmls_n_bf16_z, "q8yq16bq8yq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmls_n_f16_m, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_f16_x, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_f16_z, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_f32_m, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_f32_x, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_f32_z, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_f64_m, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_f64_x, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_f64_z, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_s16_m, "q8sq16bq8sq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_s16_x, "q8sq16bq8sq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_s16_z, "q8sq16bq8sq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_s32_m, "q4iq16bq4iq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_s32_x, "q4iq16bq4iq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_s32_z, "q4iq16bq4iq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_s64_m, "q2Wiq16bq2Wiq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_s64_x, "q2Wiq16bq2Wiq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_s64_z, "q2Wiq16bq2Wiq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_s8_m, "q16Scq16bq16Scq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_s8_x, "q16Scq16bq16Scq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_s8_z, "q16Scq16bq16Scq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_u16_m, "q8Usq16bq8Usq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_u16_x, "q8Usq16bq8Usq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_u16_z, "q8Usq16bq8Usq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_u32_m, "q4Uiq16bq4Uiq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_u32_x, "q4Uiq16bq4Uiq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_u32_z, "q4Uiq16bq4Uiq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_u64_m, "q2UWiq16bq2UWiq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_u64_x, "q2UWiq16bq2UWiq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_u64_z, "q2UWiq16bq2UWiq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_u8_m, "q16Ucq16bq16Ucq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_u8_x, "q16Ucq16bq16Ucq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_n_u8_z, "q16Ucq16bq16Ucq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_s16_m, "q8sq16bq8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_s16_x, "q8sq16bq8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_s16_z, "q8sq16bq8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_s32_m, "q4iq16bq4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_s32_x, "q4iq16bq4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_s32_z, "q4iq16bq4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_s64_m, "q2Wiq16bq2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_s64_x, "q2Wiq16bq2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_s64_z, "q2Wiq16bq2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_s8_m, "q16Scq16bq16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_s8_x, "q16Scq16bq16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_s8_z, "q16Scq16bq16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_u16_m, "q8Usq16bq8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_u16_x, "q8Usq16bq8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_u16_z, "q8Usq16bq8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_u32_m, "q4Uiq16bq4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_u32_x, "q4Uiq16bq4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_u32_z, "q4Uiq16bq4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_u64_m, "q2UWiq16bq2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_u64_x, "q2UWiq16bq2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_u64_z, "q2UWiq16bq2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_u8_m, "q16Ucq16bq16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_u8_x, "q16Ucq16bq16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmls_u8_z, "q16Ucq16bq16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmlslb_f32, "q4fq4fq8hq8h", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslb_lane_f32, "q4fq4fq8hq8hIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslb_lane_s32, "q4iq4iq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslb_lane_s64, "q2Wiq2Wiq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslb_lane_u32, "q4Uiq4Uiq8Usq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslb_lane_u64, "q2UWiq2UWiq4Uiq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslb_n_f32, "q4fq4fq8hh", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslb_n_s16, "q8sq8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslb_n_s32, "q4iq4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslb_n_s64, "q2Wiq2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslb_n_u16, "q8Usq8Usq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslb_n_u32, "q4Uiq4Uiq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslb_n_u64, "q2UWiq2UWiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslb_s16, "q8sq8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslb_s32, "q4iq4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslb_s64, "q2Wiq2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslb_u16, "q8Usq8Usq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslb_u32, "q4Uiq4Uiq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslb_u64, "q2UWiq2UWiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslt_f32, "q4fq4fq8hq8h", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslt_lane_f32, "q4fq4fq8hq8hIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslt_lane_s32, "q4iq4iq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslt_lane_s64, "q2Wiq2Wiq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslt_lane_u32, "q4Uiq4Uiq8Usq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslt_lane_u64, "q2UWiq2UWiq4Uiq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslt_n_f32, "q4fq4fq8hh", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslt_n_s16, "q8sq8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslt_n_s32, "q4iq4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslt_n_s64, "q2Wiq2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslt_n_u16, "q8Usq8Usq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslt_n_u32, "q4Uiq4Uiq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslt_n_u64, "q2UWiq2UWiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslt_s16, "q8sq8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslt_s32, "q4iq4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslt_s64, "q2Wiq2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslt_u16, "q8Usq8Usq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslt_u32, "q4Uiq4Uiq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmlslt_u64, "q2UWiq2UWiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmmla_f32, "q4fq4fq4fq4f", "n", "sve,f32mm")
TARGET_BUILTIN(__builtin_sve_svmmla_f64, "q2dq2dq2dq2d", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svmmla_s32, "q4iq4iq16Scq16Sc", "n", "sve,i8mm")
TARGET_BUILTIN(__builtin_sve_svmmla_u32, "q4Uiq4Uiq16Ucq16Uc", "n", "sve,i8mm")
TARGET_BUILTIN(__builtin_sve_svmov_b_z, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmovlb_s16, "q8sq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmovlb_s32, "q4iq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmovlb_s64, "q2Wiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmovlb_u16, "q8Usq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmovlb_u32, "q4Uiq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmovlb_u64, "q2UWiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmovlt_s16, "q8sq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmovlt_s32, "q4iq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmovlt_s64, "q2Wiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmovlt_u16, "q8Usq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmovlt_u32, "q4Uiq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmovlt_u64, "q2UWiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_f16_m, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_f16_x, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_f16_z, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_f32_m, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_f32_x, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_f32_z, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_f64_m, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_f64_x, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_f64_z, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_f16_m, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_f16_x, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_f16_z, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_f32_m, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_f32_x, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_f32_z, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_f64_m, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_f64_x, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_f64_z, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_s16_m, "q8sq16bq8sq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_s16_x, "q8sq16bq8sq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_s16_z, "q8sq16bq8sq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_s32_m, "q4iq16bq4iq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_s32_x, "q4iq16bq4iq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_s32_z, "q4iq16bq4iq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_s64_m, "q2Wiq16bq2Wiq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_s64_x, "q2Wiq16bq2Wiq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_s64_z, "q2Wiq16bq2Wiq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_s8_m, "q16Scq16bq16Scq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_s8_x, "q16Scq16bq16Scq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_s8_z, "q16Scq16bq16Scq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_u16_m, "q8Usq16bq8Usq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_u16_x, "q8Usq16bq8Usq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_u16_z, "q8Usq16bq8Usq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_u32_m, "q4Uiq16bq4Uiq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_u32_x, "q4Uiq16bq4Uiq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_u32_z, "q4Uiq16bq4Uiq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_u64_m, "q2UWiq16bq2UWiq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_u64_x, "q2UWiq16bq2UWiq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_u64_z, "q2UWiq16bq2UWiq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_u8_m, "q16Ucq16bq16Ucq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_u8_x, "q16Ucq16bq16Ucq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_n_u8_z, "q16Ucq16bq16Ucq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_s16_m, "q8sq16bq8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_s16_x, "q8sq16bq8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_s16_z, "q8sq16bq8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_s32_m, "q4iq16bq4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_s32_x, "q4iq16bq4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_s32_z, "q4iq16bq4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_s64_m, "q2Wiq16bq2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_s64_x, "q2Wiq16bq2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_s64_z, "q2Wiq16bq2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_s8_m, "q16Scq16bq16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_s8_x, "q16Scq16bq16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_s8_z, "q16Scq16bq16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_u16_m, "q8Usq16bq8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_u16_x, "q8Usq16bq8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_u16_z, "q8Usq16bq8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_u32_m, "q4Uiq16bq4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_u32_x, "q4Uiq16bq4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_u32_z, "q4Uiq16bq4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_u64_m, "q2UWiq16bq2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_u64_x, "q2UWiq16bq2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_u64_z, "q2UWiq16bq2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_u8_m, "q16Ucq16bq16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_u8_x, "q16Ucq16bq16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmsb_u8_z, "q16Ucq16bq16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_bf16_m, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmul_bf16_x, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmul_bf16_z, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmul_f16_m, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_f16_x, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_f16_z, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_f32_m, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_f32_x, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_f32_z, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_f64_m, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_f64_x, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_f64_z, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_lane_bf16, "q8yq8yq8yIUWi", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmul_lane_f16, "q8hq8hq8hIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_lane_f32, "q4fq4fq4fIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_lane_f64, "q2dq2dq2dIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_lane_s16, "q8sq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmul_lane_s32, "q4iq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmul_lane_s64, "q2Wiq2Wiq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmul_lane_u16, "q8Usq8Usq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmul_lane_u32, "q4Uiq4Uiq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmul_lane_u64, "q2UWiq2UWiq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_bf16_m, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmul_n_bf16_x, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmul_n_bf16_z, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svmul_n_f16_m, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_f16_x, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_f16_z, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_f32_m, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_f32_x, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_f32_z, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_f64_m, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_f64_x, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_f64_z, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_s16_m, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_s16_x, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_s16_z, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_s32_m, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_s32_x, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_s32_z, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_s64_m, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_s64_x, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_s64_z, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_s8_m, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_s8_x, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_s8_z, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_u16_m, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_u16_x, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_u16_z, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_u32_m, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_u32_x, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_u32_z, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_u8_m, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_u8_x, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_n_u8_z, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_s16_m, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_s16_x, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_s16_z, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_s32_m, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_s32_x, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_s32_z, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_s8_m, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_s8_x, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_s8_z, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_u16_m, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_u16_x, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_u16_z, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmul_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_s16_m, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_s16_x, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_s16_z, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_s32_m, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_s32_x, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_s32_z, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_s64_m, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_s64_x, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_s64_z, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_s8_m, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_s8_x, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_s8_z, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_u16_m, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_u16_x, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_u16_z, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_u32_m, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_u32_x, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_u32_z, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_u8_m, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_u8_x, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_n_u8_z, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_s16_m, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_s16_x, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_s16_z, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_s32_m, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_s32_x, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_s32_z, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_s8_m, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_s8_x, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_s8_z, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_u16_m, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_u16_x, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_u16_z, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulh_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmullb_lane_s32, "q4iq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullb_lane_s64, "q2Wiq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullb_lane_u32, "q4Uiq8Usq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullb_lane_u64, "q2UWiq4Uiq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullb_n_s16, "q8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullb_n_s32, "q4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullb_n_s64, "q2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullb_n_u16, "q8Usq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullb_n_u32, "q4Uiq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullb_n_u64, "q2UWiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullb_s16, "q8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullb_s32, "q4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullb_s64, "q2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullb_u16, "q8Usq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullb_u32, "q4Uiq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullb_u64, "q2UWiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullt_lane_s32, "q4iq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullt_lane_s64, "q2Wiq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullt_lane_u32, "q4Uiq8Usq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullt_lane_u64, "q2UWiq4Uiq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullt_n_s16, "q8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullt_n_s32, "q4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullt_n_s64, "q2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullt_n_u16, "q8Usq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullt_n_u32, "q4Uiq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullt_n_u64, "q2UWiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullt_s16, "q8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullt_s32, "q4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullt_s64, "q2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullt_u16, "q8Usq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullt_u32, "q4Uiq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmullt_u64, "q2UWiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svmulx_f16_m, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulx_f16_x, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulx_f16_z, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulx_f32_m, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulx_f32_x, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulx_f32_z, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulx_f64_m, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulx_f64_x, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulx_f64_z, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulx_n_f16_m, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulx_n_f16_x, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulx_n_f16_z, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulx_n_f32_m, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulx_n_f32_x, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulx_n_f32_z, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulx_n_f64_m, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulx_n_f64_x, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svmulx_n_f64_z, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnand_b_z, "q16bq16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnbsl_n_s16, "q8sq8sq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svnbsl_n_s32, "q4iq4iq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svnbsl_n_s64, "q2Wiq2Wiq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svnbsl_n_s8, "q16Scq16Scq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svnbsl_n_u16, "q8Usq8Usq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svnbsl_n_u32, "q4Uiq4Uiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svnbsl_n_u64, "q2UWiq2UWiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svnbsl_n_u8, "q16Ucq16Ucq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svnbsl_s16, "q8sq8sq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svnbsl_s32, "q4iq4iq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svnbsl_s64, "q2Wiq2Wiq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svnbsl_s8, "q16Scq16Scq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svnbsl_u16, "q8Usq8Usq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svnbsl_u32, "q4Uiq4Uiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svnbsl_u64, "q2UWiq2UWiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svnbsl_u8, "q16Ucq16Ucq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svneg_f16_m, "q8hq8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svneg_f16_x, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svneg_f16_z, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svneg_f32_m, "q4fq4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svneg_f32_x, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svneg_f32_z, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svneg_f64_m, "q2dq2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svneg_f64_x, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svneg_f64_z, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svneg_s16_m, "q8sq8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svneg_s16_x, "q8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svneg_s16_z, "q8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svneg_s32_m, "q4iq4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svneg_s32_x, "q4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svneg_s32_z, "q4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svneg_s64_m, "q2Wiq2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svneg_s64_x, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svneg_s64_z, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svneg_s8_m, "q16Scq16Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svneg_s8_x, "q16Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svneg_s8_z, "q16Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmad_f16_m, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmad_f16_x, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmad_f16_z, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmad_f32_m, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmad_f32_x, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmad_f32_z, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmad_f64_m, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmad_f64_x, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmad_f64_z, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmad_n_f16_m, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmad_n_f16_x, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmad_n_f16_z, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmad_n_f32_m, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmad_n_f32_x, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmad_n_f32_z, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmad_n_f64_m, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmad_n_f64_x, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmad_n_f64_z, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmatch_s16, "q16bq16bq8sq8s", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svnmatch_s8, "q16bq16bq16Scq16Sc", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svnmatch_u16, "q16bq16bq8Usq8Us", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svnmatch_u8, "q16bq16bq16Ucq16Uc", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svnmla_f16_m, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmla_f16_x, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmla_f16_z, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmla_f32_m, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmla_f32_x, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmla_f32_z, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmla_f64_m, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmla_f64_x, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmla_f64_z, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmla_n_f16_m, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmla_n_f16_x, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmla_n_f16_z, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmla_n_f32_m, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmla_n_f32_x, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmla_n_f32_z, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmla_n_f64_m, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmla_n_f64_x, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmla_n_f64_z, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmls_f16_m, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmls_f16_x, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmls_f16_z, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmls_f32_m, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmls_f32_x, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmls_f32_z, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmls_f64_m, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmls_f64_x, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmls_f64_z, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmls_n_f16_m, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmls_n_f16_x, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmls_n_f16_z, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmls_n_f32_m, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmls_n_f32_x, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmls_n_f32_z, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmls_n_f64_m, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmls_n_f64_x, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmls_n_f64_z, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmsb_f16_m, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmsb_f16_x, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmsb_f16_z, "q8hq16bq8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmsb_f32_m, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmsb_f32_x, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmsb_f32_z, "q4fq16bq4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmsb_f64_m, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmsb_f64_x, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmsb_f64_z, "q2dq16bq2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmsb_n_f16_m, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmsb_n_f16_x, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmsb_n_f16_z, "q8hq16bq8hq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmsb_n_f32_m, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmsb_n_f32_x, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmsb_n_f32_z, "q4fq16bq4fq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmsb_n_f64_m, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmsb_n_f64_x, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnmsb_n_f64_z, "q2dq16bq2dq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnor_b_z, "q16bq16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_b_z, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_s16_m, "q8sq8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_s16_x, "q8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_s16_z, "q8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_s32_m, "q4iq4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_s32_x, "q4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_s32_z, "q4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_s64_m, "q2Wiq2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_s64_x, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_s64_z, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_s8_m, "q16Scq16Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_s8_x, "q16Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_s8_z, "q16Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_u16_m, "q8Usq8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_u16_x, "q8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_u16_z, "q8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_u32_m, "q4Uiq4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_u32_x, "q4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_u32_z, "q4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_u64_m, "q2UWiq2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_u64_x, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_u64_z, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_u8_m, "q16Ucq16Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_u8_x, "q16Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svnot_u8_z, "q16Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorn_b_z, "q16bq16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorqv_s16, "V8sq16bq8s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svorqv_s32, "V4iq16bq4i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svorqv_s64, "V2Wiq16bq2Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svorqv_s8, "V16Scq16bq16Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svorqv_u16, "V8Usq16bq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svorqv_u32, "V4Uiq16bq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svorqv_u64, "V2UWiq16bq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svorqv_u8, "V16Ucq16bq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svorr_b_z, "q16bq16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_s16_m, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_s16_x, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_s16_z, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_s32_m, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_s32_x, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_s32_z, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_s64_m, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_s64_x, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_s64_z, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_s8_m, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_s8_x, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_s8_z, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_u16_m, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_u16_x, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_u16_z, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_u32_m, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_u32_x, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_u32_z, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_u8_m, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_u8_x, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_n_u8_z, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_s16_m, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_s16_x, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_s16_z, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_s32_m, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_s32_x, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_s32_z, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_s8_m, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_s8_x, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_s8_z, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_u16_m, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_u16_x, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_u16_z, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorr_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorv_s16, "sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorv_s32, "iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorv_s64, "Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorv_s8, "Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorv_u16, "Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorv_u32, "Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorv_u64, "UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svorv_u8, "Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svpext_lane_c16, "q16bQaIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svpext_lane_c16_x2, "q32bQaIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svpext_lane_c32, "q16bQaIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svpext_lane_c32_x2, "q32bQaIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svpext_lane_c64, "q16bQaIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svpext_lane_c64_x2, "q32bQaIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svpext_lane_c8, "q16bQaIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svpext_lane_c8_x2, "q32bQaIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svpfalse_b, "q16bv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svpfalse_c, "Qav", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svpfirst_b, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svpmov_lane_s16, "q16bq8sIUWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_lane_s16_m, "q8sq8sq16bIUWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_lane_s32, "q16bq4iIUWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_lane_s32_m, "q4iq4iq16bIUWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_lane_s64, "q16bq2WiIUWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_lane_s64_m, "q2Wiq2Wiq16bIUWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_lane_s8, "q16bq16ScIUWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_lane_u16, "q16bq8UsIUWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_lane_u16_m, "q8Usq8Usq16bIUWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_lane_u32, "q16bq4UiIUWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_lane_u32_m, "q4Uiq4Uiq16bIUWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_lane_u64, "q16bq2UWiIUWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_lane_u64_m, "q2UWiq2UWiq16bIUWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_lane_u8, "q16bq16UcIUWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_s16, "q16bq8s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_s16_z, "q8sq16b", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_s32, "q16bq4i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_s32_z, "q4iq16b", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_s64, "q16bq2Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_s64_z, "q2Wiq16b", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_s8, "q16bq16Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_s8_z, "q16Scq16b", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_u16, "q16bq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_u16_z, "q8Usq16b", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_u32, "q16bq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_u32_z, "q4Uiq16b", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_u64, "q16bq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_u64_z, "q2UWiq16b", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_u8, "q16bq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmov_u8_z, "q16Ucq16b", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svpmul_n_u8, "q16Ucq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svpmul_u8, "q16Ucq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svpmullb_n_u16, "q8Usq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svpmullb_n_u64, "q2UWiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svpmullb_pair_n_u32, "q4Uiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svpmullb_pair_n_u64, "q2UWiq2UWiUWi", "n", "sve,sve2,sve-aes")
TARGET_BUILTIN(__builtin_sve_svpmullb_pair_n_u8, "q16Ucq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svpmullb_pair_u32, "q4Uiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svpmullb_pair_u64, "q2UWiq2UWiq2UWi", "n", "sve,sve2,sve-aes")
TARGET_BUILTIN(__builtin_sve_svpmullb_pair_u8, "q16Ucq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svpmullb_u16, "q8Usq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svpmullb_u64, "q2UWiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svpmullt_n_u16, "q8Usq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svpmullt_n_u64, "q2UWiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svpmullt_pair_n_u32, "q4Uiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svpmullt_pair_n_u64, "q2UWiq2UWiUWi", "n", "sve,sve2,sve-aes")
TARGET_BUILTIN(__builtin_sve_svpmullt_pair_n_u8, "q16Ucq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svpmullt_pair_u32, "q4Uiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svpmullt_pair_u64, "q2UWiq2UWiq2UWi", "n", "sve,sve2,sve-aes")
TARGET_BUILTIN(__builtin_sve_svpmullt_pair_u8, "q16Ucq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svpmullt_u16, "q8Usq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svpmullt_u64, "q2UWiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svpnext_b16, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svpnext_b32, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svpnext_b64, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svpnext_b8, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svprfb, "vq16bvC*Ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svprfb_gather_s32offset, "vq16bvC*q4iIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfb_gather_s64offset, "vq16bvC*q2WiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfb_gather_u32base, "vq16bq4UiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfb_gather_u32base_offset, "vq16bq4UiWiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfb_gather_u32offset, "vq16bvC*q4UiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfb_gather_u64base, "vq16bq2UWiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfb_gather_u64base_offset, "vq16bq2UWiWiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfb_gather_u64offset, "vq16bvC*q2UWiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfb_vnum, "vq16bvC*WiIi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svprfd, "vq16bvC*Ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svprfd_gather_s32index, "vq16bvC*q4iIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfd_gather_s64index, "vq16bvC*q2WiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfd_gather_u32base, "vq16bq4UiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfd_gather_u32base_index, "vq16bq4UiWiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfd_gather_u32index, "vq16bvC*q4UiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfd_gather_u64base, "vq16bq2UWiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfd_gather_u64base_index, "vq16bq2UWiWiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfd_gather_u64index, "vq16bvC*q2UWiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfd_vnum, "vq16bvC*WiIi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svprfh, "vq16bvC*Ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svprfh_gather_s32index, "vq16bvC*q4iIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfh_gather_s64index, "vq16bvC*q2WiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfh_gather_u32base, "vq16bq4UiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfh_gather_u32base_index, "vq16bq4UiWiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfh_gather_u32index, "vq16bvC*q4UiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfh_gather_u64base, "vq16bq2UWiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfh_gather_u64base_index, "vq16bq2UWiWiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfh_gather_u64index, "vq16bvC*q2UWiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfh_vnum, "vq16bvC*WiIi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svprfw, "vq16bvC*Ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svprfw_gather_s32index, "vq16bvC*q4iIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfw_gather_s64index, "vq16bvC*q2WiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfw_gather_u32base, "vq16bq4UiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfw_gather_u32base_index, "vq16bq4UiWiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfw_gather_u32index, "vq16bvC*q4UiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfw_gather_u64base, "vq16bq2UWiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfw_gather_u64base_index, "vq16bq2UWiWiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfw_gather_u64index, "vq16bvC*q2UWiIi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svprfw_vnum, "vq16bvC*WiIi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svpsel_lane_b16, "q16bq16bq16bUi", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svpsel_lane_b32, "q16bq16bq16bUi", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svpsel_lane_b64, "q16bq16bq16bUi", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svpsel_lane_b8, "q16bq16bq16bUi", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svpsel_lane_c16, "QaQaq16bUi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svpsel_lane_c32, "QaQaq16bUi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svpsel_lane_c64, "QaQaq16bUi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svpsel_lane_c8, "QaQaq16bUi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svptest_any, "bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svptest_first, "bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svptest_last, "bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svptrue_b16, "q16bv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svptrue_b32, "q16bv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svptrue_b64, "q16bv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svptrue_b8, "q16bv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svptrue_c16, "Qav", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svptrue_c32, "Qav", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svptrue_c64, "Qav", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svptrue_c8, "Qav", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svptrue_pat_b16, "q16bIi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svptrue_pat_b32, "q16bIi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svptrue_pat_b64, "q16bIi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svptrue_pat_b8, "q16bIi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqabs_s16_m, "q8sq8sq16bq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqabs_s16_x, "q8sq16bq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqabs_s16_z, "q8sq16bq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqabs_s32_m, "q4iq4iq16bq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqabs_s32_x, "q4iq16bq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqabs_s32_z, "q4iq16bq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqabs_s64_m, "q2Wiq2Wiq16bq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqabs_s64_x, "q2Wiq16bq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqabs_s64_z, "q2Wiq16bq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqabs_s8_m, "q16Scq16Scq16bq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqabs_s8_x, "q16Scq16bq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqabs_s8_z, "q16Scq16bq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_s16, "q8sq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_s16_m, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_s16_x, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_s16_z, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_s32, "q4iq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_s32_m, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_s32_x, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_s32_z, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_s64, "q2Wiq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_s64_m, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_s64_x, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_s64_z, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_s8, "q16Scq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_s8_m, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_s8_x, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_s8_z, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_u16, "q8Usq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_u16_m, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_u16_x, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_u16_z, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_u32, "q4Uiq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_u32_m, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_u32_x, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_u32_z, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_u64, "q2UWiq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_u8, "q16Ucq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_u8_m, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_u8_x, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_n_u8_z, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_s16, "q8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_s16_m, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_s16_x, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_s16_z, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_s32, "q4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_s32_m, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_s32_x, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_s32_z, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_s64, "q2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_s8, "q16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_s8_m, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_s8_x, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_s8_z, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_u16, "q8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_u16_m, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_u16_x, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_u16_z, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_u32, "q4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_u64, "q2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_u8, "q16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqadd_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqcadd_s16, "q8sq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqcadd_s32, "q4iq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqcadd_s64, "q2Wiq2Wiq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqcadd_s8, "q16Scq16Scq16ScIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqcvt_s16_s32_x2, "q8sq8i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqcvt_s16_s64_x4, "q8sq8Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqcvt_s8_s32_x4, "q16Scq16i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqcvt_u16_s32_x2, "q8Usq8i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqcvt_u16_s64_x4, "q8Usq8Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqcvt_u16_u32_x2, "q8Usq8Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqcvt_u16_u64_x4, "q8Usq8UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqcvt_u8_s32_x4, "q16Ucq16i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqcvt_u8_u32_x4, "q16Ucq16Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqcvtn_s16_s32_x2, "q8sq8i", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svqcvtn_s16_s64_x4, "q8sq8Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqcvtn_s8_s32_x4, "q16Scq16i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqcvtn_u16_s32_x2, "q8Usq8i", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svqcvtn_u16_s64_x4, "q8Usq8Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqcvtn_u16_u32_x2, "q8Usq8Ui", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svqcvtn_u16_u64_x4, "q8Usq8UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqcvtn_u8_s32_x4, "q16Ucq16i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqcvtn_u8_u32_x4, "q16Ucq16Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqdecb_n_s32, "iiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecb_n_s64, "WiWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecb_n_u32, "UiUiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecb_n_u64, "UWiUWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecb_pat_n_s32, "iiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecb_pat_n_s64, "WiWiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecb_pat_n_u32, "UiUiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecb_pat_n_u64, "UWiUWiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecd_n_s32, "iiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecd_n_s64, "WiWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecd_n_u32, "UiUiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecd_n_u64, "UWiUWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecd_pat_n_s32, "iiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecd_pat_n_s64, "WiWiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecd_pat_n_u32, "UiUiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecd_pat_n_u64, "UWiUWiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecd_pat_s64, "q2Wiq2WiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecd_pat_u64, "q2UWiq2UWiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecd_s64, "q2Wiq2WiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecd_u64, "q2UWiq2UWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdech_n_s32, "iiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdech_n_s64, "WiWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdech_n_u32, "UiUiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdech_n_u64, "UWiUWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdech_pat_n_s32, "iiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdech_pat_n_s64, "WiWiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdech_pat_n_u32, "UiUiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdech_pat_n_u64, "UWiUWiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdech_pat_s16, "q8sq8sIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdech_pat_u16, "q8Usq8UsIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdech_s16, "q8sq8sIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdech_u16, "q8Usq8UsIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_n_s32_b16, "iiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_n_s32_b32, "iiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_n_s32_b64, "iiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_n_s32_b8, "iiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_n_s64_b16, "WiWiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_n_s64_b32, "WiWiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_n_s64_b64, "WiWiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_n_s64_b8, "WiWiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_n_u32_b16, "UiUiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_n_u32_b32, "UiUiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_n_u32_b64, "UiUiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_n_u32_b8, "UiUiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_n_u64_b16, "UWiUWiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_n_u64_b32, "UWiUWiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_n_u64_b64, "UWiUWiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_n_u64_b8, "UWiUWiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_s16, "q8sq8sq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_s32, "q4iq4iq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_s64, "q2Wiq2Wiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_u16, "q8Usq8Usq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_u32, "q4Uiq4Uiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecp_u64, "q2UWiq2UWiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecw_n_s32, "iiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecw_n_s64, "WiWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecw_n_u32, "UiUiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecw_n_u64, "UWiUWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecw_pat_n_s32, "iiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecw_pat_n_s64, "WiWiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecw_pat_n_u32, "UiUiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecw_pat_n_u64, "UWiUWiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecw_pat_s32, "q4iq4iIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecw_pat_u32, "q4Uiq4UiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecw_s32, "q4iq4iIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdecw_u32, "q4Uiq4UiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalb_lane_s32, "q4iq4iq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalb_lane_s64, "q2Wiq2Wiq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalb_n_s16, "q8sq8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalb_n_s32, "q4iq4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalb_n_s64, "q2Wiq2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalb_s16, "q8sq8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalb_s32, "q4iq4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalb_s64, "q2Wiq2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalbt_n_s16, "q8sq8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalbt_n_s32, "q4iq4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalbt_n_s64, "q2Wiq2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalbt_s16, "q8sq8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalbt_s32, "q4iq4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalbt_s64, "q2Wiq2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalt_lane_s32, "q4iq4iq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalt_lane_s64, "q2Wiq2Wiq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalt_n_s16, "q8sq8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalt_n_s32, "q4iq4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalt_n_s64, "q2Wiq2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalt_s16, "q8sq8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalt_s32, "q4iq4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlalt_s64, "q2Wiq2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslb_lane_s32, "q4iq4iq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslb_lane_s64, "q2Wiq2Wiq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslb_n_s16, "q8sq8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslb_n_s32, "q4iq4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslb_n_s64, "q2Wiq2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslb_s16, "q8sq8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslb_s32, "q4iq4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslb_s64, "q2Wiq2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslbt_n_s16, "q8sq8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslbt_n_s32, "q4iq4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslbt_n_s64, "q2Wiq2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslbt_s16, "q8sq8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslbt_s32, "q4iq4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslbt_s64, "q2Wiq2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslt_lane_s32, "q4iq4iq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslt_lane_s64, "q2Wiq2Wiq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslt_n_s16, "q8sq8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslt_n_s32, "q4iq4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslt_n_s64, "q2Wiq2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslt_s16, "q8sq8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslt_s32, "q4iq4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmlslt_s64, "q2Wiq2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmulh_lane_s16, "q8sq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmulh_lane_s32, "q4iq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmulh_lane_s64, "q2Wiq2Wiq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmulh_n_s16, "q8sq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmulh_n_s32, "q4iq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmulh_n_s64, "q2Wiq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmulh_n_s8, "q16Scq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmulh_s16, "q8sq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmulh_s16_x2, "q16sq16sq16s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqdmulh_s16_x4, "q32sq32sq32s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqdmulh_s32, "q4iq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmulh_s32_x2, "q8iq8iq8i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqdmulh_s32_x4, "q16iq16iq16i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqdmulh_s64, "q2Wiq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmulh_s64_x2, "q4Wiq4Wiq4Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqdmulh_s64_x4, "q8Wiq8Wiq8Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqdmulh_s8, "q16Scq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmulh_s8_x2, "q32Scq32Scq32Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqdmulh_s8_x4, "q64Scq64Scq64Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqdmulh_single_s16_x2, "q16sq16sq8s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqdmulh_single_s16_x4, "q32sq32sq8s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqdmulh_single_s32_x2, "q8iq8iq4i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqdmulh_single_s32_x4, "q16iq16iq4i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqdmulh_single_s64_x2, "q4Wiq4Wiq2Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqdmulh_single_s64_x4, "q8Wiq8Wiq2Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqdmulh_single_s8_x2, "q32Scq32Scq16Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqdmulh_single_s8_x4, "q64Scq64Scq16Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqdmullb_lane_s32, "q4iq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmullb_lane_s64, "q2Wiq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmullb_n_s16, "q8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmullb_n_s32, "q4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmullb_n_s64, "q2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmullb_s16, "q8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmullb_s32, "q4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmullb_s64, "q2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmullt_lane_s32, "q4iq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmullt_lane_s64, "q2Wiq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmullt_n_s16, "q8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmullt_n_s32, "q4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmullt_n_s64, "q2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmullt_s16, "q8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmullt_s32, "q4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqdmullt_s64, "q2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqincb_n_s32, "iiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincb_n_s64, "WiWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincb_n_u32, "UiUiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincb_n_u64, "UWiUWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincb_pat_n_s32, "iiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincb_pat_n_s64, "WiWiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincb_pat_n_u32, "UiUiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincb_pat_n_u64, "UWiUWiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincd_n_s32, "iiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincd_n_s64, "WiWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincd_n_u32, "UiUiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincd_n_u64, "UWiUWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincd_pat_n_s32, "iiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincd_pat_n_s64, "WiWiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincd_pat_n_u32, "UiUiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincd_pat_n_u64, "UWiUWiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincd_pat_s64, "q2Wiq2WiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincd_pat_u64, "q2UWiq2UWiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincd_s64, "q2Wiq2WiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincd_u64, "q2UWiq2UWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqinch_n_s32, "iiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqinch_n_s64, "WiWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqinch_n_u32, "UiUiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqinch_n_u64, "UWiUWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqinch_pat_n_s32, "iiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqinch_pat_n_s64, "WiWiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqinch_pat_n_u32, "UiUiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqinch_pat_n_u64, "UWiUWiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqinch_pat_s16, "q8sq8sIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqinch_pat_u16, "q8Usq8UsIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqinch_s16, "q8sq8sIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqinch_u16, "q8Usq8UsIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_n_s32_b16, "iiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_n_s32_b32, "iiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_n_s32_b64, "iiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_n_s32_b8, "iiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_n_s64_b16, "WiWiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_n_s64_b32, "WiWiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_n_s64_b64, "WiWiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_n_s64_b8, "WiWiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_n_u32_b16, "UiUiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_n_u32_b32, "UiUiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_n_u32_b64, "UiUiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_n_u32_b8, "UiUiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_n_u64_b16, "UWiUWiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_n_u64_b32, "UWiUWiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_n_u64_b64, "UWiUWiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_n_u64_b8, "UWiUWiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_s16, "q8sq8sq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_s32, "q4iq4iq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_s64, "q2Wiq2Wiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_u16, "q8Usq8Usq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_u32, "q4Uiq4Uiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincp_u64, "q2UWiq2UWiq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincw_n_s32, "iiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincw_n_s64, "WiWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincw_n_u32, "UiUiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincw_n_u64, "UWiUWiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincw_pat_n_s32, "iiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincw_pat_n_s64, "WiWiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincw_pat_n_u32, "UiUiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincw_pat_n_u64, "UWiUWiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincw_pat_s32, "q4iq4iIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincw_pat_u32, "q4Uiq4UiIiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincw_s32, "q4iq4iIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqincw_u32, "q4Uiq4UiIUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqneg_s16_m, "q8sq8sq16bq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqneg_s16_x, "q8sq16bq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqneg_s16_z, "q8sq16bq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqneg_s32_m, "q4iq4iq16bq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqneg_s32_x, "q4iq16bq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqneg_s32_z, "q4iq16bq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqneg_s64_m, "q2Wiq2Wiq16bq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqneg_s64_x, "q2Wiq16bq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqneg_s64_z, "q2Wiq16bq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqneg_s8_m, "q16Scq16Scq16bq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqneg_s8_x, "q16Scq16bq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqneg_s8_z, "q16Scq16bq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdcmlah_lane_s16, "q8sq8sq8sq8sIUWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdcmlah_lane_s32, "q4iq4iq4iq4iIUWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdcmlah_s16, "q8sq8sq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdcmlah_s32, "q4iq4iq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdcmlah_s64, "q2Wiq2Wiq2Wiq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdcmlah_s8, "q16Scq16Scq16Scq16ScIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlah_lane_s16, "q8sq8sq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlah_lane_s32, "q4iq4iq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlah_lane_s64, "q2Wiq2Wiq2Wiq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlah_n_s16, "q8sq8sq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlah_n_s32, "q4iq4iq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlah_n_s64, "q2Wiq2Wiq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlah_n_s8, "q16Scq16Scq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlah_s16, "q8sq8sq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlah_s32, "q4iq4iq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlah_s64, "q2Wiq2Wiq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlah_s8, "q16Scq16Scq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlsh_lane_s16, "q8sq8sq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlsh_lane_s32, "q4iq4iq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlsh_lane_s64, "q2Wiq2Wiq2Wiq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlsh_n_s16, "q8sq8sq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlsh_n_s32, "q4iq4iq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlsh_n_s64, "q2Wiq2Wiq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlsh_n_s8, "q16Scq16Scq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlsh_s16, "q8sq8sq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlsh_s32, "q4iq4iq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlsh_s64, "q2Wiq2Wiq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmlsh_s8, "q16Scq16Scq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmulh_lane_s16, "q8sq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmulh_lane_s32, "q4iq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmulh_lane_s64, "q2Wiq2Wiq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmulh_n_s16, "q8sq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmulh_n_s32, "q4iq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmulh_n_s64, "q2Wiq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmulh_n_s8, "q16Scq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmulh_s16, "q8sq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmulh_s32, "q4iq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmulh_s64, "q2Wiq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrdmulh_s8, "q16Scq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_s16_m, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_s16_x, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_s16_z, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_s32_m, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_s32_x, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_s32_z, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_s64_m, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_s64_x, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_s64_z, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_s8_m, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_s8_x, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_s8_z, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_u16_m, "q8Usq16bq8Uss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_u16_x, "q8Usq16bq8Uss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_u16_z, "q8Usq16bq8Uss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_u32_m, "q4Uiq16bq4Uii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_u32_x, "q4Uiq16bq4Uii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_u32_z, "q4Uiq16bq4Uii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_u64_m, "q2UWiq16bq2UWiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_u64_x, "q2UWiq16bq2UWiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_u64_z, "q2UWiq16bq2UWiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_u8_m, "q16Ucq16bq16UcSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_u8_x, "q16Ucq16bq16UcSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_n_u8_z, "q16Ucq16bq16UcSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_s16_m, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_s16_x, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_s16_z, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_s32_m, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_s32_x, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_s32_z, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_s8_m, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_s8_x, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_s8_z, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_u16_m, "q8Usq16bq8Usq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_u16_x, "q8Usq16bq8Usq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_u16_z, "q8Usq16bq8Usq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_u32_m, "q4Uiq16bq4Uiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_u32_x, "q4Uiq16bq4Uiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_u32_z, "q4Uiq16bq4Uiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_u64_m, "q2UWiq16bq2UWiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_u64_x, "q2UWiq16bq2UWiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_u64_z, "q2UWiq16bq2UWiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_u8_m, "q16Ucq16bq16Ucq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_u8_x, "q16Ucq16bq16Ucq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshl_u8_z, "q16Ucq16bq16Ucq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshr_n_s16_s32_x2, "q8sq8iIUWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqrshr_n_s16_s64_x4, "q8sq8WiIUWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqrshr_n_s8_s32_x4, "q16Scq16iIUWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqrshr_n_u16_u32_x2, "q8Usq8UiIUWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqrshr_n_u16_u64_x4, "q8Usq8UWiIUWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqrshr_n_u8_u32_x4, "q16Ucq16UiIUWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqrshrn_n_s16_s32_x2, "q8sq8iIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svqrshrn_n_s16_s64_x4, "q8sq8WiIUWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqrshrn_n_s8_s32_x4, "q16Scq16iIUWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqrshrn_n_u16_u32_x2, "q8Usq8UiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svqrshrn_n_u16_u64_x4, "q8Usq8UWiIUWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqrshrn_n_u8_u32_x4, "q16Ucq16UiIUWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqrshrnb_n_s16, "q16Scq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshrnb_n_s32, "q8sq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshrnb_n_s64, "q4iq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshrnb_n_u16, "q16Ucq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshrnb_n_u32, "q8Usq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshrnb_n_u64, "q4Uiq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshrnt_n_s16, "q16Scq16Scq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshrnt_n_s32, "q8sq8sq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshrnt_n_s64, "q4iq4iq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshrnt_n_u16, "q16Ucq16Ucq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshrnt_n_u32, "q8Usq8Usq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshrnt_n_u64, "q4Uiq4Uiq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshru_n_u16_s32_x2, "q8Usq8iIUWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqrshru_n_u16_s64_x4, "q8Usq8WiIUWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqrshru_n_u8_s32_x4, "q16Ucq16iIUWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqrshrun_n_u16_s32_x2, "q8Usq8iIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svqrshrun_n_u16_s64_x4, "q8Usq8WiIUWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqrshrun_n_u8_s32_x4, "q16Ucq16iIUWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svqrshrunb_n_s16, "q16Ucq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshrunb_n_s32, "q8Usq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshrunb_n_s64, "q4Uiq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshrunt_n_s16, "q16Ucq16Ucq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshrunt_n_s32, "q8Usq8Usq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqrshrunt_n_s64, "q4Uiq4Uiq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_s16_m, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_s16_x, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_s16_z, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_s32_m, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_s32_x, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_s32_z, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_s64_m, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_s64_x, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_s64_z, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_s8_m, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_s8_x, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_s8_z, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_u16_m, "q8Usq16bq8Uss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_u16_x, "q8Usq16bq8Uss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_u16_z, "q8Usq16bq8Uss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_u32_m, "q4Uiq16bq4Uii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_u32_x, "q4Uiq16bq4Uii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_u32_z, "q4Uiq16bq4Uii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_u64_m, "q2UWiq16bq2UWiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_u64_x, "q2UWiq16bq2UWiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_u64_z, "q2UWiq16bq2UWiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_u8_m, "q16Ucq16bq16UcSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_u8_x, "q16Ucq16bq16UcSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_n_u8_z, "q16Ucq16bq16UcSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_s16_m, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_s16_x, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_s16_z, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_s32_m, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_s32_x, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_s32_z, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_s8_m, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_s8_x, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_s8_z, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_u16_m, "q8Usq16bq8Usq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_u16_x, "q8Usq16bq8Usq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_u16_z, "q8Usq16bq8Usq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_u32_m, "q4Uiq16bq4Uiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_u32_x, "q4Uiq16bq4Uiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_u32_z, "q4Uiq16bq4Uiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_u64_m, "q2UWiq16bq2UWiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_u64_x, "q2UWiq16bq2UWiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_u64_z, "q2UWiq16bq2UWiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_u8_m, "q16Ucq16bq16Ucq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_u8_x, "q16Ucq16bq16Ucq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshl_u8_z, "q16Ucq16bq16Ucq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshlu_n_s16_m, "q8Usq16bq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshlu_n_s16_x, "q8Usq16bq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshlu_n_s16_z, "q8Usq16bq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshlu_n_s32_m, "q4Uiq16bq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshlu_n_s32_x, "q4Uiq16bq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshlu_n_s32_z, "q4Uiq16bq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshlu_n_s64_m, "q2UWiq16bq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshlu_n_s64_x, "q2UWiq16bq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshlu_n_s64_z, "q2UWiq16bq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshlu_n_s8_m, "q16Ucq16bq16ScIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshlu_n_s8_x, "q16Ucq16bq16ScIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshlu_n_s8_z, "q16Ucq16bq16ScIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshrnb_n_s16, "q16Scq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshrnb_n_s32, "q8sq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshrnb_n_s64, "q4iq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshrnb_n_u16, "q16Ucq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshrnb_n_u32, "q8Usq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshrnb_n_u64, "q4Uiq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshrnt_n_s16, "q16Scq16Scq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshrnt_n_s32, "q8sq8sq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshrnt_n_s64, "q4iq4iq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshrnt_n_u16, "q16Ucq16Ucq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshrnt_n_u32, "q8Usq8Usq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshrnt_n_u64, "q4Uiq4Uiq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshrunb_n_s16, "q16Ucq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshrunb_n_s32, "q8Usq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshrunb_n_s64, "q4Uiq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshrunt_n_s16, "q16Ucq16Ucq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshrunt_n_s32, "q8Usq8Usq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqshrunt_n_s64, "q4Uiq4Uiq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_s16, "q8sq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_s16_m, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_s16_x, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_s16_z, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_s32, "q4iq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_s32_m, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_s32_x, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_s32_z, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_s64, "q2Wiq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_s64_m, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_s64_x, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_s64_z, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_s8, "q16Scq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_s8_m, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_s8_x, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_s8_z, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_u16, "q8Usq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_u16_m, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_u16_x, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_u16_z, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_u32, "q4Uiq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_u32_m, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_u32_x, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_u32_z, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_u64, "q2UWiq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_u8, "q16Ucq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_u8_m, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_u8_x, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_n_u8_z, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_s16, "q8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_s16_m, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_s16_x, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_s16_z, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_s32, "q4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_s32_m, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_s32_x, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_s32_z, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_s64, "q2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_s8, "q16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_s8_m, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_s8_x, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_s8_z, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_u16, "q8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_u16_m, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_u16_x, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_u16_z, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_u32, "q4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_u64, "q2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_u8, "q16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsub_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_s16_m, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_s16_x, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_s16_z, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_s32_m, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_s32_x, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_s32_z, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_s64_m, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_s64_x, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_s64_z, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_s8_m, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_s8_x, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_s8_z, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_u16_m, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_u16_x, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_u16_z, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_u32_m, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_u32_x, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_u32_z, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_u8_m, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_u8_x, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_n_u8_z, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_s16_m, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_s16_x, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_s16_z, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_s32_m, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_s32_x, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_s32_z, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_s8_m, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_s8_x, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_s8_z, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_u16_m, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_u16_x, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_u16_z, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqsubr_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqxtnb_s16, "q16Scq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqxtnb_s32, "q8sq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqxtnb_s64, "q4iq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqxtnb_u16, "q16Ucq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqxtnb_u32, "q8Usq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqxtnb_u64, "q4Uiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqxtnt_s16, "q16Scq16Scq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqxtnt_s32, "q8sq8sq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqxtnt_s64, "q4iq4iq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqxtnt_u16, "q16Ucq16Ucq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqxtnt_u32, "q8Usq8Usq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqxtnt_u64, "q4Uiq4Uiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqxtunb_s16, "q16Ucq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqxtunb_s32, "q8Usq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqxtunb_s64, "q4Uiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqxtunt_s16, "q16Ucq16Ucq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqxtunt_s32, "q8Usq8Usq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svqxtunt_s64, "q4Uiq4Uiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnb_n_s16, "q16Scq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnb_n_s32, "q8sq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnb_n_s64, "q4iq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnb_n_u16, "q16Ucq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnb_n_u32, "q8Usq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnb_n_u64, "q4Uiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnb_s16, "q16Scq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnb_s32, "q8sq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnb_s64, "q4iq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnb_u16, "q16Ucq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnb_u32, "q8Usq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnb_u64, "q4Uiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnt_n_s16, "q16Scq16Scq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnt_n_s32, "q8sq8sq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnt_n_s64, "q4iq4iq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnt_n_u16, "q16Ucq16Ucq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnt_n_u32, "q8Usq8Usq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnt_n_u64, "q4Uiq4Uiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnt_s16, "q16Scq16Scq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnt_s32, "q8sq8sq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnt_s64, "q4iq4iq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnt_u16, "q16Ucq16Ucq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnt_u32, "q8Usq8Usq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svraddhnt_u64, "q4Uiq4Uiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrax1_s64, "q2Wiq2Wiq2Wi", "n", "sve,sve2-sha3")
TARGET_BUILTIN(__builtin_sve_svrax1_u64, "q2UWiq2UWiq2UWi", "n", "sve,sve2-sha3")
TARGET_BUILTIN(__builtin_sve_svrbit_s16_m, "q8sq8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_s16_x, "q8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_s16_z, "q8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_s32_m, "q4iq4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_s32_x, "q4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_s32_z, "q4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_s64_m, "q2Wiq2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_s64_x, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_s64_z, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_s8_m, "q16Scq16Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_s8_x, "q16Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_s8_z, "q16Scq16bq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_u16_m, "q8Usq8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_u16_x, "q8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_u16_z, "q8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_u32_m, "q4Uiq4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_u32_x, "q4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_u32_z, "q4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_u64_m, "q2UWiq2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_u64_x, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_u64_z, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_u8_m, "q16Ucq16Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_u8_x, "q16Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrbit_u8_z, "q16Ucq16bq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrdffr, "q16bv", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svrdffr_z, "q16bq16b", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svrecpe_f16, "q8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrecpe_f32, "q4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrecpe_f64, "q2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrecpe_u32_m, "q4Uiq4Uiq16bq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrecpe_u32_x, "q4Uiq16bq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrecpe_u32_z, "q4Uiq16bq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrecps_f16, "q8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrecps_f32, "q4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrecps_f64, "q2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrecpx_f16_m, "q8hq8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrecpx_f16_x, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrecpx_f16_z, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrecpx_f32_m, "q4fq4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrecpx_f32_x, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrecpx_f32_z, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrecpx_f64_m, "q2dq2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrecpx_f64_x, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrecpx_f64_z, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svreinterpret_b, "q16bQa", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svreinterpret_c, "Qaq16b", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svrev_b16, "q16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrev_b32, "q16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrev_b64, "q16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrev_b8, "q16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrev_bf16, "q8yq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svrev_f16, "q8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrev_f32, "q4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrev_f64, "q2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrev_s16, "q8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrev_s32, "q4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrev_s64, "q2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrev_s8, "q16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrev_u16, "q8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrev_u32, "q4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrev_u64, "q2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrev_u8, "q16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevb_s16_m, "q8sq8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevb_s16_x, "q8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevb_s16_z, "q8sq16bq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevb_s32_m, "q4iq4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevb_s32_x, "q4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevb_s32_z, "q4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevb_s64_m, "q2Wiq2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevb_s64_x, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevb_s64_z, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevb_u16_m, "q8Usq8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevb_u16_x, "q8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevb_u16_z, "q8Usq16bq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevb_u32_m, "q4Uiq4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevb_u32_x, "q4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevb_u32_z, "q4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevb_u64_m, "q2UWiq2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevb_u64_x, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevb_u64_z, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_bf16_m, "q8yq8yq16bq8y", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_bf16_x, "q8yq16bq8y", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_bf16_z, "q8yq16bq8y", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_f16_m, "q8hq8hq16bq8h", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_f16_x, "q8hq16bq8h", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_f16_z, "q8hq16bq8h", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_f32_m, "q4fq4fq16bq4f", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_f32_x, "q4fq16bq4f", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_f32_z, "q4fq16bq4f", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_f64_m, "q2dq2dq16bq2d", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_f64_x, "q2dq16bq2d", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_f64_z, "q2dq16bq2d", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_s16_m, "q8sq8sq16bq8s", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_s16_x, "q8sq16bq8s", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_s16_z, "q8sq16bq8s", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_s32_m, "q4iq4iq16bq4i", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_s32_x, "q4iq16bq4i", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_s32_z, "q4iq16bq4i", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_s64_m, "q2Wiq2Wiq16bq2Wi", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_s64_x, "q2Wiq16bq2Wi", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_s64_z, "q2Wiq16bq2Wi", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_s8_m, "q16Scq16Scq16bq16Sc", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_s8_x, "q16Scq16bq16Sc", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_s8_z, "q16Scq16bq16Sc", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_u16_m, "q8Usq8Usq16bq8Us", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_u16_x, "q8Usq16bq8Us", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_u16_z, "q8Usq16bq8Us", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_u32_m, "q4Uiq4Uiq16bq4Ui", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_u32_x, "q4Uiq16bq4Ui", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_u32_z, "q4Uiq16bq4Ui", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_u64_m, "q2UWiq2UWiq16bq2UWi", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_u64_x, "q2UWiq16bq2UWi", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_u64_z, "q2UWiq16bq2UWi", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_u8_m, "q16Ucq16Ucq16bq16Uc", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_u8_x, "q16Ucq16bq16Uc", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevd_u8_z, "q16Ucq16bq16Uc", "n", "(sve,sve2p1)|sme")
TARGET_BUILTIN(__builtin_sve_svrevh_s32_m, "q4iq4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevh_s32_x, "q4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevh_s32_z, "q4iq16bq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevh_s64_m, "q2Wiq2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevh_s64_x, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevh_s64_z, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevh_u32_m, "q4Uiq4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevh_u32_x, "q4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevh_u32_z, "q4Uiq16bq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevh_u64_m, "q2UWiq2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevh_u64_x, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevh_u64_z, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevw_s64_m, "q2Wiq2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevw_s64_x, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevw_s64_z, "q2Wiq16bq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevw_u64_m, "q2UWiq2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevw_u64_x, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrevw_u64_z, "q2UWiq16bq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_s16_m, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_s16_x, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_s16_z, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_s32_m, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_s32_x, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_s32_z, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_s64_m, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_s64_x, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_s64_z, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_s8_m, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_s8_x, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_s8_z, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_u16_m, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_u16_x, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_u16_z, "q8Usq16bq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_u32_m, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_u32_x, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_u32_z, "q4Uiq16bq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_u8_m, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_u8_x, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_n_u8_z, "q16Ucq16bq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_s16_m, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_s16_x, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_s16_z, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_s32_m, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_s32_x, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_s32_z, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_s8_m, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_s8_x, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_s8_z, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_u16_m, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_u16_x, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_u16_z, "q8Usq16bq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrhadd_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrinta_f16_m, "q8hq8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrinta_f16_x, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrinta_f16_z, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrinta_f32_m, "q4fq4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrinta_f32_x, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrinta_f32_x2, "q8fq8f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrinta_f32_x4, "q16fq16f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrinta_f32_z, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrinta_f64_m, "q2dq2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrinta_f64_x, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrinta_f64_z, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrinti_f16_m, "q8hq8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrinti_f16_x, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrinti_f16_z, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrinti_f32_m, "q4fq4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrinti_f32_x, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrinti_f32_z, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrinti_f64_m, "q2dq2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrinti_f64_x, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrinti_f64_z, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintm_f16_m, "q8hq8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintm_f16_x, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintm_f16_z, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintm_f32_m, "q4fq4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintm_f32_x, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintm_f32_x2, "q8fq8f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrintm_f32_x4, "q16fq16f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrintm_f32_z, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintm_f64_m, "q2dq2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintm_f64_x, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintm_f64_z, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintn_f16_m, "q8hq8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintn_f16_x, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintn_f16_z, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintn_f32_m, "q4fq4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintn_f32_x, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintn_f32_x2, "q8fq8f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrintn_f32_x4, "q16fq16f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrintn_f32_z, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintn_f64_m, "q2dq2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintn_f64_x, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintn_f64_z, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintp_f16_m, "q8hq8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintp_f16_x, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintp_f16_z, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintp_f32_m, "q4fq4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintp_f32_x, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintp_f32_x2, "q8fq8f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrintp_f32_x4, "q16fq16f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrintp_f32_z, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintp_f64_m, "q2dq2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintp_f64_x, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintp_f64_z, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintx_f16_m, "q8hq8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintx_f16_x, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintx_f16_z, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintx_f32_m, "q4fq4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintx_f32_x, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintx_f32_z, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintx_f64_m, "q2dq2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintx_f64_x, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintx_f64_z, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintz_f16_m, "q8hq8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintz_f16_x, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintz_f16_z, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintz_f32_m, "q4fq4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintz_f32_x, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintz_f32_z, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintz_f64_m, "q2dq2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintz_f64_x, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrintz_f64_z, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_s16_m, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_s16_x, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_s16_z, "q8sq16bq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_s32_m, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_s32_x, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_s32_z, "q4iq16bq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_s64_m, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_s64_x, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_s64_z, "q2Wiq16bq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_s8_m, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_s8_x, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_s8_z, "q16Scq16bq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_u16_m, "q8Usq16bq8Uss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_u16_x, "q8Usq16bq8Uss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_u16_z, "q8Usq16bq8Uss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_u32_m, "q4Uiq16bq4Uii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_u32_x, "q4Uiq16bq4Uii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_u32_z, "q4Uiq16bq4Uii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_u64_m, "q2UWiq16bq2UWiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_u64_x, "q2UWiq16bq2UWiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_u64_z, "q2UWiq16bq2UWiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_u8_m, "q16Ucq16bq16UcSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_u8_x, "q16Ucq16bq16UcSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_n_u8_z, "q16Ucq16bq16UcSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_s16_m, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_s16_x, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_s16_x2, "q16sq16sq16s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_s16_x4, "q32sq32sq32s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_s16_z, "q8sq16bq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_s32_m, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_s32_x, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_s32_x2, "q8iq8iq8i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_s32_x4, "q16iq16iq16i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_s32_z, "q4iq16bq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_s64_x2, "q4Wiq4Wiq4Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_s64_x4, "q8Wiq8Wiq8Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_s8_m, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_s8_x, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_s8_x2, "q32Scq32Scq32Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_s8_x4, "q64Scq64Scq64Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_s8_z, "q16Scq16bq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_single_s16_x2, "q16sq16sq8s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_single_s16_x4, "q32sq32sq8s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_single_s32_x2, "q8iq8iq4i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_single_s32_x4, "q16iq16iq4i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_single_s64_x2, "q4Wiq4Wiq2Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_single_s64_x4, "q8Wiq8Wiq2Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_single_s8_x2, "q32Scq32Scq16Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_single_s8_x4, "q64Scq64Scq16Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_single_u16_x2, "q16Usq16Usq8Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_single_u16_x4, "q32Usq32Usq8Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_single_u32_x2, "q8Uiq8Uiq4Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_single_u32_x4, "q16Uiq16Uiq4Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_single_u64_x2, "q4UWiq4UWiq2UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_single_u64_x4, "q8UWiq8UWiq2UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_single_u8_x2, "q32Ucq32Ucq16Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_single_u8_x4, "q64Ucq64Ucq16Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_u16_m, "q8Usq16bq8Usq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_u16_x, "q8Usq16bq8Usq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_u16_x2, "q16Usq16Usq16Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_u16_x4, "q32Usq32Usq32Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_u16_z, "q8Usq16bq8Usq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_u32_m, "q4Uiq16bq4Uiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_u32_x, "q4Uiq16bq4Uiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_u32_x2, "q8Uiq8Uiq8Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_u32_x4, "q16Uiq16Uiq16Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_u32_z, "q4Uiq16bq4Uiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_u64_m, "q2UWiq16bq2UWiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_u64_x, "q2UWiq16bq2UWiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_u64_x2, "q4UWiq4UWiq4UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_u64_x4, "q8UWiq8UWiq8UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_u64_z, "q2UWiq16bq2UWiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_u8_m, "q16Ucq16bq16Ucq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_u8_x, "q16Ucq16bq16Ucq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshl_u8_x2, "q32Ucq32Ucq32Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_u8_x4, "q64Ucq64Ucq64Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svrshl_u8_z, "q16Ucq16bq16Ucq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_s16_m, "q8sq16bq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_s16_x, "q8sq16bq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_s16_z, "q8sq16bq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_s32_m, "q4iq16bq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_s32_x, "q4iq16bq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_s32_z, "q4iq16bq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_s64_m, "q2Wiq16bq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_s64_x, "q2Wiq16bq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_s64_z, "q2Wiq16bq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_s8_m, "q16Scq16bq16ScIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_s8_x, "q16Scq16bq16ScIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_s8_z, "q16Scq16bq16ScIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_u16_m, "q8Usq16bq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_u16_x, "q8Usq16bq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_u16_z, "q8Usq16bq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_u32_m, "q4Uiq16bq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_u32_x, "q4Uiq16bq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_u32_z, "q4Uiq16bq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_u64_m, "q2UWiq16bq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_u64_x, "q2UWiq16bq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_u64_z, "q2UWiq16bq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_u8_m, "q16Ucq16bq16UcIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_u8_x, "q16Ucq16bq16UcIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshr_n_u8_z, "q16Ucq16bq16UcIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshrnb_n_s16, "q16Scq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshrnb_n_s32, "q8sq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshrnb_n_s64, "q4iq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshrnb_n_u16, "q16Ucq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshrnb_n_u32, "q8Usq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshrnb_n_u64, "q4Uiq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshrnt_n_s16, "q16Scq16Scq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshrnt_n_s32, "q8sq8sq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshrnt_n_s64, "q4iq4iq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshrnt_n_u16, "q16Ucq16Ucq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshrnt_n_u32, "q8Usq8Usq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrshrnt_n_u64, "q4Uiq4Uiq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsqrte_f16, "q8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrsqrte_f32, "q4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrsqrte_f64, "q2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrsqrte_u32_m, "q4Uiq4Uiq16bq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsqrte_u32_x, "q4Uiq16bq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsqrte_u32_z, "q4Uiq16bq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsqrts_f16, "q8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrsqrts_f32, "q4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrsqrts_f64, "q2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svrsra_n_s16, "q8sq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsra_n_s32, "q4iq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsra_n_s64, "q2Wiq2Wiq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsra_n_s8, "q16Scq16Scq16ScIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsra_n_u16, "q8Usq8Usq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsra_n_u32, "q4Uiq4Uiq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsra_n_u64, "q2UWiq2UWiq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsra_n_u8, "q16Ucq16Ucq16UcIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnb_n_s16, "q16Scq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnb_n_s32, "q8sq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnb_n_s64, "q4iq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnb_n_u16, "q16Ucq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnb_n_u32, "q8Usq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnb_n_u64, "q4Uiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnb_s16, "q16Scq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnb_s32, "q8sq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnb_s64, "q4iq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnb_u16, "q16Ucq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnb_u32, "q8Usq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnb_u64, "q4Uiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnt_n_s16, "q16Scq16Scq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnt_n_s32, "q8sq8sq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnt_n_s64, "q4iq4iq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnt_n_u16, "q16Ucq16Ucq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnt_n_u32, "q8Usq8Usq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnt_n_u64, "q4Uiq4Uiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnt_s16, "q16Scq16Scq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnt_s32, "q8sq8sq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnt_s64, "q4iq4iq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnt_u16, "q16Ucq16Ucq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnt_u32, "q8Usq8Usq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svrsubhnt_u64, "q4Uiq4Uiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsbclb_n_u32, "q4Uiq4Uiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsbclb_n_u64, "q2UWiq2UWiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsbclb_u32, "q4Uiq4Uiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsbclb_u64, "q2UWiq2UWiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsbclt_n_u32, "q4Uiq4Uiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsbclt_n_u64, "q2UWiq2UWiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsbclt_u32, "q4Uiq4Uiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsbclt_u64, "q2UWiq2UWiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svscale_f16_m, "q8hq16bq8hq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svscale_f16_x, "q8hq16bq8hq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svscale_f16_x2, "q16hq16hq16s", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svscale_f16_x4, "q32hq32hq32s", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svscale_f16_z, "q8hq16bq8hq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svscale_f32_m, "q4fq16bq4fq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svscale_f32_x, "q4fq16bq4fq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svscale_f32_x2, "q8fq8fq8i", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svscale_f32_x4, "q16fq16fq16i", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svscale_f32_z, "q4fq16bq4fq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svscale_f64_m, "q2dq16bq2dq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svscale_f64_x, "q2dq16bq2dq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svscale_f64_x2, "q4dq4dq4Wi", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svscale_f64_x4, "q8dq8dq8Wi", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svscale_f64_z, "q2dq16bq2dq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svscale_n_f16_m, "q8hq16bq8hs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svscale_n_f16_x, "q8hq16bq8hs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svscale_n_f16_z, "q8hq16bq8hs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svscale_n_f32_m, "q4fq16bq4fi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svscale_n_f32_x, "q4fq16bq4fi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svscale_n_f32_z, "q4fq16bq4fi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svscale_n_f64_m, "q2dq16bq2dWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svscale_n_f64_x, "q2dq16bq2dWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svscale_n_f64_z, "q2dq16bq2dWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svscale_single_f16_x2, "q16hq16hq8s", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svscale_single_f16_x4, "q32hq32hq8s", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svscale_single_f32_x2, "q8fq8fq4i", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svscale_single_f32_x4, "q16fq16fq4i", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svscale_single_f64_x2, "q4dq4dq2Wi", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svscale_single_f64_x4, "q8dq8dq2Wi", "n", "sme,sme2,fp8")
TARGET_BUILTIN(__builtin_sve_svsel_b, "q16bq16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsel_bf16, "q8yq16bq8yq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svsel_bf16_x2, "q16yQaq16yq16y", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_bf16_x4, "q32yQaq32yq32y", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_f16, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsel_f16_x2, "q16hQaq16hq16h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_f16_x4, "q32hQaq32hq32h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_f32, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsel_f32_x2, "q8fQaq8fq8f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_f32_x4, "q16fQaq16fq16f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_f64, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsel_f64_x2, "q4dQaq4dq4d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_f64_x4, "q8dQaq8dq8d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_s16, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsel_s16_x2, "q16sQaq16sq16s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_s16_x4, "q32sQaq32sq32s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_s32, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsel_s32_x2, "q8iQaq8iq8i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_s32_x4, "q16iQaq16iq16i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_s64, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsel_s64_x2, "q4WiQaq4Wiq4Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_s64_x4, "q8WiQaq8Wiq8Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_s8, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsel_s8_x2, "q32ScQaq32Scq32Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_s8_x4, "q64ScQaq64Scq64Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_u16, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsel_u16_x2, "q16UsQaq16Usq16Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_u16_x4, "q32UsQaq32Usq32Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_u32, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsel_u32_x2, "q8UiQaq8Uiq8Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_u32_x4, "q16UiQaq16Uiq16Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_u64, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsel_u64_x2, "q4UWiQaq4UWiq4UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_u64_x4, "q8UWiQaq8UWiq8UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_u8, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsel_u8_x2, "q32UcQaq32Ucq32Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svsel_u8_x4, "q64UcQaq64Ucq64Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svset2_b, "q32bq32bIUWiq16b", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svset2_bf16, "q16yq16yIUWiq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svset2_f16, "q16hq16hIUWiq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset2_f32, "q8fq8fIUWiq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset2_f64, "q4dq4dIUWiq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset2_s16, "q16sq16sIUWiq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset2_s32, "q8iq8iIUWiq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset2_s64, "q4Wiq4WiIUWiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset2_s8, "q32Scq32ScIUWiq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset2_u16, "q16Usq16UsIUWiq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset2_u32, "q8Uiq8UiIUWiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset2_u64, "q4UWiq4UWiIUWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset2_u8, "q32Ucq32UcIUWiq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset3_bf16, "q24yq24yIUWiq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svset3_f16, "q24hq24hIUWiq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset3_f32, "q12fq12fIUWiq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset3_f64, "q6dq6dIUWiq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset3_s16, "q24sq24sIUWiq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset3_s32, "q12iq12iIUWiq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset3_s64, "q6Wiq6WiIUWiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset3_s8, "q48Scq48ScIUWiq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset3_u16, "q24Usq24UsIUWiq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset3_u32, "q12Uiq12UiIUWiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset3_u64, "q6UWiq6UWiIUWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset3_u8, "q48Ucq48UcIUWiq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset4_b, "q64bq64bIUWiq16b", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svset4_bf16, "q32yq32yIUWiq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svset4_f16, "q32hq32hIUWiq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset4_f32, "q16fq16fIUWiq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset4_f64, "q8dq8dIUWiq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset4_s16, "q32sq32sIUWiq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset4_s32, "q16iq16iIUWiq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset4_s64, "q8Wiq8WiIUWiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset4_s8, "q64Scq64ScIUWiq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset4_u16, "q32Usq32UsIUWiq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset4_u32, "q16Uiq16UiIUWiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset4_u64, "q8UWiq8UWiIUWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svset4_u8, "q64Ucq64UcIUWiq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsetffr, "vv", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svshllb_n_s16, "q8sq16ScIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshllb_n_s32, "q4iq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshllb_n_s64, "q2Wiq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshllb_n_u16, "q8Usq16UcIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshllb_n_u32, "q4Uiq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshllb_n_u64, "q2UWiq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshllt_n_s16, "q8sq16ScIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshllt_n_s32, "q4iq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshllt_n_s64, "q2Wiq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshllt_n_u16, "q8Usq16UcIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshllt_n_u32, "q4Uiq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshllt_n_u64, "q2UWiq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshrnb_n_s16, "q16Scq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshrnb_n_s32, "q8sq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshrnb_n_s64, "q4iq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshrnb_n_u16, "q16Ucq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshrnb_n_u32, "q8Usq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshrnb_n_u64, "q4Uiq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshrnt_n_s16, "q16Scq16Scq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshrnt_n_s32, "q8sq8sq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshrnt_n_s64, "q4iq4iq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshrnt_n_u16, "q16Ucq16Ucq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshrnt_n_u32, "q8Usq8Usq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svshrnt_n_u64, "q4Uiq4Uiq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsli_n_s16, "q8sq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsli_n_s32, "q4iq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsli_n_s64, "q2Wiq2Wiq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsli_n_s8, "q16Scq16Scq16ScIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsli_n_u16, "q8Usq8Usq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsli_n_u32, "q4Uiq4Uiq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsli_n_u64, "q2UWiq2UWiq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsli_n_u8, "q16Ucq16Ucq16UcIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsm4e_u32, "q4Uiq4Uiq4Ui", "n", "sve,sve2-sm4")
TARGET_BUILTIN(__builtin_sve_svsm4ekey_u32, "q4Uiq4Uiq4Ui", "n", "sve,sve2-sm4")
TARGET_BUILTIN(__builtin_sve_svsplice_bf16, "q8yq16bq8yq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svsplice_f16, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsplice_f32, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsplice_f64, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsplice_s16, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsplice_s32, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsplice_s64, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsplice_s8, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsplice_u16, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsplice_u32, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsplice_u64, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsplice_u8, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_n_u16_m, "q8Usq16bq8Uss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_n_u16_x, "q8Usq16bq8Uss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_n_u16_z, "q8Usq16bq8Uss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_n_u32_m, "q4Uiq16bq4Uii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_n_u32_x, "q4Uiq16bq4Uii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_n_u32_z, "q4Uiq16bq4Uii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_n_u64_m, "q2UWiq16bq2UWiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_n_u64_x, "q2UWiq16bq2UWiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_n_u64_z, "q2UWiq16bq2UWiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_n_u8_m, "q16Ucq16bq16UcSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_n_u8_x, "q16Ucq16bq16UcSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_n_u8_z, "q16Ucq16bq16UcSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_u16_m, "q8Usq16bq8Usq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_u16_x, "q8Usq16bq8Usq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_u16_z, "q8Usq16bq8Usq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_u32_m, "q4Uiq16bq4Uiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_u32_x, "q4Uiq16bq4Uiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_u32_z, "q4Uiq16bq4Uiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_u64_m, "q2UWiq16bq2UWiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_u64_x, "q2UWiq16bq2UWiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_u64_z, "q2UWiq16bq2UWiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_u8_m, "q16Ucq16bq16Ucq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_u8_x, "q16Ucq16bq16Ucq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqadd_u8_z, "q16Ucq16bq16Ucq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsqrt_f16_m, "q8hq8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsqrt_f16_x, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsqrt_f16_z, "q8hq16bq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsqrt_f32_m, "q4fq4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsqrt_f32_x, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsqrt_f32_z, "q4fq16bq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsqrt_f64_m, "q2dq2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsqrt_f64_x, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsqrt_f64_z, "q2dq16bq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsra_n_s16, "q8sq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsra_n_s32, "q4iq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsra_n_s64, "q2Wiq2Wiq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsra_n_s8, "q16Scq16Scq16ScIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsra_n_u16, "q8Usq8Usq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsra_n_u32, "q4Uiq4Uiq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsra_n_u64, "q2UWiq2UWiq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsra_n_u8, "q16Ucq16Ucq16UcIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsri_n_s16, "q8sq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsri_n_s32, "q4iq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsri_n_s64, "q2Wiq2Wiq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsri_n_s8, "q16Scq16Scq16ScIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsri_n_u16, "q8Usq8Usq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsri_n_u32, "q4Uiq4Uiq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsri_n_u64, "q2UWiq2UWiq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsri_n_u8, "q16Ucq16Ucq16UcIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svst1_bf16, "vq16by*q8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svst1_bf16_x2, "vQay*q16y", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_bf16_x4, "vQay*q32y", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_f16, "vq16bh*q8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_f16_x2, "vQah*q16h", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_f16_x4, "vQah*q32h", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_f32, "vq16bf*q4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_f32_x2, "vQaf*q8f", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_f32_x4, "vQaf*q16f", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_f64, "vq16bd*q2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_f64_x2, "vQad*q4d", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_f64_x4, "vQad*q8d", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_s16, "vq16bSs*q8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_s16_x2, "vQaSs*q16s", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_s16_x4, "vQaSs*q32s", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_s32, "vq16bSi*q4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_s32_x2, "vQaSi*q8i", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_s32_x4, "vQaSi*q16i", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_s64, "vq16bSWi*q2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_s64_x2, "vQaSWi*q4Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_s64_x4, "vQaSWi*q8Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_s8, "vq16bSc*q16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_s8_x2, "vQaSc*q32Sc", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_s8_x4, "vQaSc*q64Sc", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_s32index_f32, "vq16bf*q4iq4f", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_s32index_s32, "vq16bSi*q4iq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_s32index_u32, "vq16bUi*q4iq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_s32offset_f32, "vq16bf*q4iq4f", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_s32offset_s32, "vq16bSi*q4iq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_s32offset_u32, "vq16bUi*q4iq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_s64index_f64, "vq16bd*q2Wiq2d", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_s64index_s64, "vq16bSWi*q2Wiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_s64index_u64, "vq16bUWi*q2Wiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_s64offset_f64, "vq16bd*q2Wiq2d", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_s64offset_s64, "vq16bSWi*q2Wiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_s64offset_u64, "vq16bUWi*q2Wiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u32base_f32, "vq16bq4Uiq4f", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u32base_index_f32, "vq16bq4UiWiq4f", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u32base_index_s32, "vq16bq4UiWiq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u32base_index_u32, "vq16bq4UiWiq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u32base_offset_f32, "vq16bq4UiWiq4f", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u32base_offset_s32, "vq16bq4UiWiq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u32base_offset_u32, "vq16bq4UiWiq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u32base_s32, "vq16bq4Uiq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u32base_u32, "vq16bq4Uiq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u32index_f32, "vq16bf*q4Uiq4f", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u32index_s32, "vq16bSi*q4Uiq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u32index_u32, "vq16bUi*q4Uiq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u32offset_f32, "vq16bf*q4Uiq4f", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u32offset_s32, "vq16bSi*q4Uiq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u32offset_u32, "vq16bUi*q4Uiq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u64base_f64, "vq16bq2UWiq2d", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u64base_index_f64, "vq16bq2UWiWiq2d", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u64base_index_s64, "vq16bq2UWiWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u64base_index_u64, "vq16bq2UWiWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u64base_offset_f64, "vq16bq2UWiWiq2d", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u64base_offset_s64, "vq16bq2UWiWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u64base_offset_u64, "vq16bq2UWiWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u64base_s64, "vq16bq2UWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u64base_u64, "vq16bq2UWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u64index_f64, "vq16bd*q2UWiq2d", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u64index_s64, "vq16bSWi*q2UWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u64index_u64, "vq16bUWi*q2UWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u64offset_f64, "vq16bd*q2UWiq2d", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u64offset_s64, "vq16bSWi*q2UWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_scatter_u64offset_u64, "vq16bUWi*q2UWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1_u16, "vq16bUs*q8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_u16_x2, "vQaUs*q16Us", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_u16_x4, "vQaUs*q32Us", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_u32, "vq16bUi*q4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_u32_x2, "vQaUi*q8Ui", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_u32_x4, "vQaUi*q16Ui", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_u64, "vq16bUWi*q2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_u64_x2, "vQaUWi*q4UWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_u64_x4, "vQaUWi*q8UWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_u8, "vq16bUc*q16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_u8_x2, "vQaUc*q32Uc", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_u8_x4, "vQaUc*q64Uc", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_bf16, "vq16by*Wiq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_bf16_x2, "vQay*Wiq16y", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_bf16_x4, "vQay*Wiq32y", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_f16, "vq16bh*Wiq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_f16_x2, "vQah*Wiq16h", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_f16_x4, "vQah*Wiq32h", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_f32, "vq16bf*Wiq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_f32_x2, "vQaf*Wiq8f", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_f32_x4, "vQaf*Wiq16f", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_f64, "vq16bd*Wiq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_f64_x2, "vQad*Wiq4d", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_f64_x4, "vQad*Wiq8d", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_s16, "vq16bSs*Wiq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_s16_x2, "vQaSs*Wiq16s", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_s16_x4, "vQaSs*Wiq32s", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_s32, "vq16bSi*Wiq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_s32_x2, "vQaSi*Wiq8i", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_s32_x4, "vQaSi*Wiq16i", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_s64, "vq16bSWi*Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_s64_x2, "vQaSWi*Wiq4Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_s64_x4, "vQaSWi*Wiq8Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_s8, "vq16bSc*Wiq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_s8_x2, "vQaSc*Wiq32Sc", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_s8_x4, "vQaSc*Wiq64Sc", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_u16, "vq16bUs*Wiq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_u16_x2, "vQaUs*Wiq16Us", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_u16_x4, "vQaUs*Wiq32Us", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_u32, "vq16bUi*Wiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_u32_x2, "vQaUi*Wiq8Ui", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_u32_x4, "vQaUi*Wiq16Ui", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_u64, "vq16bUWi*Wiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_u64_x2, "vQaUWi*Wiq4UWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_u64_x4, "vQaUWi*Wiq8UWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_u8, "vq16bUc*Wiq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_u8_x2, "vQaUc*Wiq32Uc", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1_vnum_u8_x4, "vQaUc*Wiq64Uc", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svst1b_s16, "vq16bSc*q8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1b_s32, "vq16bSc*q4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1b_s64, "vq16bSc*q2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1b_scatter_s32offset_s32, "vq16bSc*q4iq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1b_scatter_s32offset_u32, "vq16bUc*q4iq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1b_scatter_s64offset_s64, "vq16bSc*q2Wiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1b_scatter_s64offset_u64, "vq16bUc*q2Wiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1b_scatter_u32base_offset_s32, "vq16bq4UiWiq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1b_scatter_u32base_offset_u32, "vq16bq4UiWiq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1b_scatter_u32base_s32, "vq16bq4Uiq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1b_scatter_u32base_u32, "vq16bq4Uiq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1b_scatter_u32offset_s32, "vq16bSc*q4Uiq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1b_scatter_u32offset_u32, "vq16bUc*q4Uiq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1b_scatter_u64base_offset_s64, "vq16bq2UWiWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1b_scatter_u64base_offset_u64, "vq16bq2UWiWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1b_scatter_u64base_s64, "vq16bq2UWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1b_scatter_u64base_u64, "vq16bq2UWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1b_scatter_u64offset_s64, "vq16bSc*q2UWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1b_scatter_u64offset_u64, "vq16bUc*q2UWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1b_u16, "vq16bUc*q8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1b_u32, "vq16bUc*q4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1b_u64, "vq16bUc*q2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1b_vnum_s16, "vq16bSc*Wiq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1b_vnum_s32, "vq16bSc*Wiq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1b_vnum_s64, "vq16bSc*Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1b_vnum_u16, "vq16bUc*Wiq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1b_vnum_u32, "vq16bUc*Wiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1b_vnum_u64, "vq16bUc*Wiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1dq_f64, "vq16bd*q2d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1dq_s64, "vq16bSWi*q2Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1dq_u64, "vq16bUWi*q2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1dq_vnum_f64, "vq16bd*Wiq2d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1dq_vnum_s64, "vq16bSWi*Wiq2Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1dq_vnum_u64, "vq16bUWi*Wiq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1h_s32, "vq16bSs*q4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1h_s64, "vq16bSs*q2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_s32index_s32, "vq16bSs*q4iq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_s32index_u32, "vq16bUs*q4iq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_s32offset_s32, "vq16bSs*q4iq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_s32offset_u32, "vq16bUs*q4iq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_s64index_s64, "vq16bSs*q2Wiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_s64index_u64, "vq16bUs*q2Wiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_s64offset_s64, "vq16bSs*q2Wiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_s64offset_u64, "vq16bUs*q2Wiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_u32base_index_s32, "vq16bq4UiWiq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_u32base_index_u32, "vq16bq4UiWiq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_u32base_offset_s32, "vq16bq4UiWiq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_u32base_offset_u32, "vq16bq4UiWiq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_u32base_s32, "vq16bq4Uiq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_u32base_u32, "vq16bq4Uiq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_u32index_s32, "vq16bSs*q4Uiq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_u32index_u32, "vq16bUs*q4Uiq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_u32offset_s32, "vq16bSs*q4Uiq4i", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_u32offset_u32, "vq16bUs*q4Uiq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_u64base_index_s64, "vq16bq2UWiWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_u64base_index_u64, "vq16bq2UWiWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_u64base_offset_s64, "vq16bq2UWiWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_u64base_offset_u64, "vq16bq2UWiWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_u64base_s64, "vq16bq2UWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_u64base_u64, "vq16bq2UWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_u64index_s64, "vq16bSs*q2UWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_u64index_u64, "vq16bUs*q2UWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_u64offset_s64, "vq16bSs*q2UWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_scatter_u64offset_u64, "vq16bUs*q2UWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1h_u32, "vq16bUs*q4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1h_u64, "vq16bUs*q2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1h_vnum_s32, "vq16bSs*Wiq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1h_vnum_s64, "vq16bSs*Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1h_vnum_u32, "vq16bUs*Wiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1h_vnum_u64, "vq16bUs*Wiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64index_bf16, "vq16by*q2Wiq8y", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64index_f16, "vq16bh*q2Wiq8h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64index_f32, "vq16bf*q2Wiq4f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64index_f64, "vq16bd*q2Wiq2d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64index_s16, "vq16bSs*q2Wiq8s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64index_s32, "vq16bSi*q2Wiq4i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64index_s64, "vq16bSWi*q2Wiq2Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64index_u16, "vq16bUs*q2Wiq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64index_u32, "vq16bUi*q2Wiq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64index_u64, "vq16bUWi*q2Wiq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64offset_bf16, "vq16by*q2Wiq8y", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64offset_f16, "vq16bh*q2Wiq8h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64offset_f32, "vq16bf*q2Wiq4f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64offset_f64, "vq16bd*q2Wiq2d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64offset_s16, "vq16bSs*q2Wiq8s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64offset_s32, "vq16bSi*q2Wiq4i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64offset_s64, "vq16bSWi*q2Wiq2Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64offset_s8, "vq16bSc*q2Wiq16Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64offset_u16, "vq16bUs*q2Wiq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64offset_u32, "vq16bUi*q2Wiq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64offset_u64, "vq16bUWi*q2Wiq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_s64offset_u8, "vq16bUc*q2Wiq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_bf16, "vq16bq2UWiq8y", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_f16, "vq16bq2UWiq8h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_f32, "vq16bq2UWiq4f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_f64, "vq16bq2UWiq2d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_index_bf16, "vq16bq2UWiWiq8y", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_index_f16, "vq16bq2UWiWiq8h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_index_f32, "vq16bq2UWiWiq4f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_index_f64, "vq16bq2UWiWiq2d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_index_s16, "vq16bq2UWiWiq8s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_index_s32, "vq16bq2UWiWiq4i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_index_s64, "vq16bq2UWiWiq2Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_index_u16, "vq16bq2UWiWiq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_index_u32, "vq16bq2UWiWiq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_index_u64, "vq16bq2UWiWiq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_offset_bf16, "vq16bq2UWiWiq8y", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_offset_f16, "vq16bq2UWiWiq8h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_offset_f32, "vq16bq2UWiWiq4f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_offset_f64, "vq16bq2UWiWiq2d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_offset_s16, "vq16bq2UWiWiq8s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_offset_s32, "vq16bq2UWiWiq4i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_offset_s64, "vq16bq2UWiWiq2Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_offset_s8, "vq16bq2UWiWiq16Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_offset_u16, "vq16bq2UWiWiq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_offset_u32, "vq16bq2UWiWiq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_offset_u64, "vq16bq2UWiWiq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_offset_u8, "vq16bq2UWiWiq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_s16, "vq16bq2UWiq8s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_s32, "vq16bq2UWiq4i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_s64, "vq16bq2UWiq2Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_s8, "vq16bq2UWiq16Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_u16, "vq16bq2UWiq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_u32, "vq16bq2UWiq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_u64, "vq16bq2UWiq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64base_u8, "vq16bq2UWiq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64index_bf16, "vq16by*q2UWiq8y", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64index_f16, "vq16bh*q2UWiq8h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64index_f32, "vq16bf*q2UWiq4f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64index_f64, "vq16bd*q2UWiq2d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64index_s16, "vq16bSs*q2UWiq8s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64index_s32, "vq16bSi*q2UWiq4i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64index_s64, "vq16bSWi*q2UWiq2Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64index_u16, "vq16bUs*q2UWiq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64index_u32, "vq16bUi*q2UWiq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64index_u64, "vq16bUWi*q2UWiq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64offset_bf16, "vq16by*q2UWiq8y", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64offset_f16, "vq16bh*q2UWiq8h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64offset_f32, "vq16bf*q2UWiq4f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64offset_f64, "vq16bd*q2UWiq2d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64offset_s16, "vq16bSs*q2UWiq8s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64offset_s32, "vq16bSi*q2UWiq4i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64offset_s64, "vq16bSWi*q2UWiq2Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64offset_s8, "vq16bSc*q2UWiq16Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64offset_u16, "vq16bUs*q2UWiq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64offset_u32, "vq16bUi*q2UWiq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64offset_u64, "vq16bUWi*q2UWiq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1q_scatter_u64offset_u8, "vq16bUc*q2UWiq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1w_s64, "vq16bSi*q2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1w_scatter_s64index_s64, "vq16bSi*q2Wiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1w_scatter_s64index_u64, "vq16bUi*q2Wiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1w_scatter_s64offset_s64, "vq16bSi*q2Wiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1w_scatter_s64offset_u64, "vq16bUi*q2Wiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1w_scatter_u64base_index_s64, "vq16bq2UWiWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1w_scatter_u64base_index_u64, "vq16bq2UWiWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1w_scatter_u64base_offset_s64, "vq16bq2UWiWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1w_scatter_u64base_offset_u64, "vq16bq2UWiWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1w_scatter_u64base_s64, "vq16bq2UWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1w_scatter_u64base_u64, "vq16bq2UWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1w_scatter_u64index_s64, "vq16bSi*q2UWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1w_scatter_u64index_u64, "vq16bUi*q2UWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1w_scatter_u64offset_s64, "vq16bSi*q2UWiq2Wi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1w_scatter_u64offset_u64, "vq16bUi*q2UWiq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svst1w_u64, "vq16bUi*q2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1w_vnum_s64, "vq16bSi*Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1w_vnum_u64, "vq16bUi*Wiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst1wq_f32, "vq16bf*q4f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1wq_s32, "vq16bSi*q4i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1wq_u32, "vq16bUi*q4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1wq_vnum_f32, "vq16bf*Wiq4f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1wq_vnum_s32, "vq16bSi*Wiq4i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst1wq_vnum_u32, "vq16bUi*Wiq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2_bf16, "vq16by*q16y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svst2_f16, "vq16bh*q16h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_f32, "vq16bf*q8f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_f64, "vq16bd*q4d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_s16, "vq16bSs*q16s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_s32, "vq16bSi*q8i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_s64, "vq16bSWi*q4Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_s8, "vq16bSc*q32Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_u16, "vq16bUs*q16Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_u32, "vq16bUi*q8Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_u64, "vq16bUWi*q4UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_u8, "vq16bUc*q32Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_vnum_bf16, "vq16by*Wiq16y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svst2_vnum_f16, "vq16bh*Wiq16h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_vnum_f32, "vq16bf*Wiq8f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_vnum_f64, "vq16bd*Wiq4d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_vnum_s16, "vq16bSs*Wiq16s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_vnum_s32, "vq16bSi*Wiq8i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_vnum_s64, "vq16bSWi*Wiq4Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_vnum_s8, "vq16bSc*Wiq32Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_vnum_u16, "vq16bUs*Wiq16Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_vnum_u32, "vq16bUi*Wiq8Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_vnum_u64, "vq16bUWi*Wiq4UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2_vnum_u8, "vq16bUc*Wiq32Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst2q_bf16, "vq16byC*q16y", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_f16, "vq16bhC*q16h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_f32, "vq16bfC*q8f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_f64, "vq16bdC*q4d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_s16, "vq16bSsC*q16s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_s32, "vq16bSiC*q8i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_s64, "vq16bSWiC*q4Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_s8, "vq16bScC*q32Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_u16, "vq16bUsC*q16Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_u32, "vq16bUiC*q8Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_u64, "vq16bUWiC*q4UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_u8, "vq16bUcC*q32Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_vnum_bf16, "vq16byC*Wiq16y", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_vnum_f16, "vq16bhC*Wiq16h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_vnum_f32, "vq16bfC*Wiq8f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_vnum_f64, "vq16bdC*Wiq4d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_vnum_s16, "vq16bSsC*Wiq16s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_vnum_s32, "vq16bSiC*Wiq8i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_vnum_s64, "vq16bSWiC*Wiq4Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_vnum_s8, "vq16bScC*Wiq32Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_vnum_u16, "vq16bUsC*Wiq16Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_vnum_u32, "vq16bUiC*Wiq8Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_vnum_u64, "vq16bUWiC*Wiq4UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst2q_vnum_u8, "vq16bUcC*Wiq32Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3_bf16, "vq16by*q24y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svst3_f16, "vq16bh*q24h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_f32, "vq16bf*q12f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_f64, "vq16bd*q6d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_s16, "vq16bSs*q24s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_s32, "vq16bSi*q12i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_s64, "vq16bSWi*q6Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_s8, "vq16bSc*q48Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_u16, "vq16bUs*q24Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_u32, "vq16bUi*q12Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_u64, "vq16bUWi*q6UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_u8, "vq16bUc*q48Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_vnum_bf16, "vq16by*Wiq24y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svst3_vnum_f16, "vq16bh*Wiq24h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_vnum_f32, "vq16bf*Wiq12f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_vnum_f64, "vq16bd*Wiq6d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_vnum_s16, "vq16bSs*Wiq24s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_vnum_s32, "vq16bSi*Wiq12i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_vnum_s64, "vq16bSWi*Wiq6Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_vnum_s8, "vq16bSc*Wiq48Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_vnum_u16, "vq16bUs*Wiq24Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_vnum_u32, "vq16bUi*Wiq12Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_vnum_u64, "vq16bUWi*Wiq6UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3_vnum_u8, "vq16bUc*Wiq48Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst3q_bf16, "vq16byC*q24y", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_f16, "vq16bhC*q24h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_f32, "vq16bfC*q12f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_f64, "vq16bdC*q6d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_s16, "vq16bSsC*q24s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_s32, "vq16bSiC*q12i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_s64, "vq16bSWiC*q6Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_s8, "vq16bScC*q48Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_u16, "vq16bUsC*q24Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_u32, "vq16bUiC*q12Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_u64, "vq16bUWiC*q6UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_u8, "vq16bUcC*q48Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_vnum_bf16, "vq16byC*Wiq24y", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_vnum_f16, "vq16bhC*Wiq24h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_vnum_f32, "vq16bfC*Wiq12f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_vnum_f64, "vq16bdC*Wiq6d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_vnum_s16, "vq16bSsC*Wiq24s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_vnum_s32, "vq16bSiC*Wiq12i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_vnum_s64, "vq16bSWiC*Wiq6Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_vnum_s8, "vq16bScC*Wiq48Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_vnum_u16, "vq16bUsC*Wiq24Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_vnum_u32, "vq16bUiC*Wiq12Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_vnum_u64, "vq16bUWiC*Wiq6UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst3q_vnum_u8, "vq16bUcC*Wiq48Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4_bf16, "vq16by*q32y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svst4_f16, "vq16bh*q32h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_f32, "vq16bf*q16f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_f64, "vq16bd*q8d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_s16, "vq16bSs*q32s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_s32, "vq16bSi*q16i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_s64, "vq16bSWi*q8Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_s8, "vq16bSc*q64Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_u16, "vq16bUs*q32Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_u32, "vq16bUi*q16Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_u64, "vq16bUWi*q8UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_u8, "vq16bUc*q64Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_vnum_bf16, "vq16by*Wiq32y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svst4_vnum_f16, "vq16bh*Wiq32h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_vnum_f32, "vq16bf*Wiq16f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_vnum_f64, "vq16bd*Wiq8d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_vnum_s16, "vq16bSs*Wiq32s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_vnum_s32, "vq16bSi*Wiq16i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_vnum_s64, "vq16bSWi*Wiq8Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_vnum_s8, "vq16bSc*Wiq64Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_vnum_u16, "vq16bUs*Wiq32Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_vnum_u32, "vq16bUi*Wiq16Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_vnum_u64, "vq16bUWi*Wiq8UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4_vnum_u8, "vq16bUc*Wiq64Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svst4q_bf16, "vq16byC*q32y", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_f16, "vq16bhC*q32h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_f32, "vq16bfC*q16f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_f64, "vq16bdC*q8d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_s16, "vq16bSsC*q32s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_s32, "vq16bSiC*q16i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_s64, "vq16bSWiC*q8Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_s8, "vq16bScC*q64Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_u16, "vq16bUsC*q32Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_u32, "vq16bUiC*q16Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_u64, "vq16bUWiC*q8UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_u8, "vq16bUcC*q64Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_vnum_bf16, "vq16byC*Wiq32y", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_vnum_f16, "vq16bhC*Wiq32h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_vnum_f32, "vq16bfC*Wiq16f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_vnum_f64, "vq16bdC*Wiq8d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_vnum_s16, "vq16bSsC*Wiq32s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_vnum_s32, "vq16bSiC*Wiq16i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_vnum_s64, "vq16bSWiC*Wiq8Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_vnum_s8, "vq16bScC*Wiq64Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_vnum_u16, "vq16bUsC*Wiq32Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_vnum_u32, "vq16bUiC*Wiq16Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_vnum_u64, "vq16bUWiC*Wiq8UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svst4q_vnum_u8, "vq16bUcC*Wiq64Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svstnt1_bf16, "vq16by*q8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svstnt1_bf16_x2, "vQay*q16y", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_bf16_x4, "vQay*q32y", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_f16, "vq16bh*q8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_f16_x2, "vQah*q16h", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_f16_x4, "vQah*q32h", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_f32, "vq16bf*q4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_f32_x2, "vQaf*q8f", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_f32_x4, "vQaf*q16f", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_f64, "vq16bd*q2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_f64_x2, "vQad*q4d", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_f64_x4, "vQad*q8d", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_s16, "vq16bSs*q8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_s16_x2, "vQaSs*q16s", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_s16_x4, "vQaSs*q32s", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_s32, "vq16bSi*q4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_s32_x2, "vQaSi*q8i", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_s32_x4, "vQaSi*q16i", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_s64, "vq16bSWi*q2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_s64_x2, "vQaSWi*q4Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_s64_x4, "vQaSWi*q8Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_s8, "vq16bSc*q16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_s8_x2, "vQaSc*q32Sc", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_s8_x4, "vQaSc*q64Sc", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_s64index_f64, "vq16bd*q2Wiq2d", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_s64index_s64, "vq16bSWi*q2Wiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_s64index_u64, "vq16bUWi*q2Wiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_s64offset_f64, "vq16bd*q2Wiq2d", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_s64offset_s64, "vq16bSWi*q2Wiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_s64offset_u64, "vq16bUWi*q2Wiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u32base_f32, "vq16bq4Uiq4f", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u32base_index_f32, "vq16bq4UiWiq4f", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u32base_index_s32, "vq16bq4UiWiq4i", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u32base_index_u32, "vq16bq4UiWiq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u32base_offset_f32, "vq16bq4UiWiq4f", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u32base_offset_s32, "vq16bq4UiWiq4i", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u32base_offset_u32, "vq16bq4UiWiq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u32base_s32, "vq16bq4Uiq4i", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u32base_u32, "vq16bq4Uiq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u32offset_f32, "vq16bf*q4Uiq4f", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u32offset_s32, "vq16bSi*q4Uiq4i", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u32offset_u32, "vq16bUi*q4Uiq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u64base_f64, "vq16bq2UWiq2d", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u64base_index_f64, "vq16bq2UWiWiq2d", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u64base_index_s64, "vq16bq2UWiWiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u64base_index_u64, "vq16bq2UWiWiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u64base_offset_f64, "vq16bq2UWiWiq2d", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u64base_offset_s64, "vq16bq2UWiWiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u64base_offset_u64, "vq16bq2UWiWiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u64base_s64, "vq16bq2UWiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u64base_u64, "vq16bq2UWiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u64index_f64, "vq16bd*q2UWiq2d", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u64index_s64, "vq16bSWi*q2UWiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u64index_u64, "vq16bUWi*q2UWiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u64offset_f64, "vq16bd*q2UWiq2d", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u64offset_s64, "vq16bSWi*q2UWiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_scatter_u64offset_u64, "vq16bUWi*q2UWiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1_u16, "vq16bUs*q8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_u16_x2, "vQaUs*q16Us", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_u16_x4, "vQaUs*q32Us", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_u32, "vq16bUi*q4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_u32_x2, "vQaUi*q8Ui", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_u32_x4, "vQaUi*q16Ui", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_u64, "vq16bUWi*q2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_u64_x2, "vQaUWi*q4UWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_u64_x4, "vQaUWi*q8UWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_u8, "vq16bUc*q16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_u8_x2, "vQaUc*q32Uc", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_u8_x4, "vQaUc*q64Uc", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_bf16, "vq16by*Wiq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_bf16_x2, "vQay*Wiq16y", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_bf16_x4, "vQay*Wiq32y", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_f16, "vq16bh*Wiq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_f16_x2, "vQah*Wiq16h", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_f16_x4, "vQah*Wiq32h", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_f32, "vq16bf*Wiq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_f32_x2, "vQaf*Wiq8f", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_f32_x4, "vQaf*Wiq16f", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_f64, "vq16bd*Wiq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_f64_x2, "vQad*Wiq4d", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_f64_x4, "vQad*Wiq8d", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_s16, "vq16bSs*Wiq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_s16_x2, "vQaSs*Wiq16s", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_s16_x4, "vQaSs*Wiq32s", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_s32, "vq16bSi*Wiq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_s32_x2, "vQaSi*Wiq8i", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_s32_x4, "vQaSi*Wiq16i", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_s64, "vq16bSWi*Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_s64_x2, "vQaSWi*Wiq4Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_s64_x4, "vQaSWi*Wiq8Wi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_s8, "vq16bSc*Wiq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_s8_x2, "vQaSc*Wiq32Sc", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_s8_x4, "vQaSc*Wiq64Sc", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_u16, "vq16bUs*Wiq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_u16_x2, "vQaUs*Wiq16Us", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_u16_x4, "vQaUs*Wiq32Us", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_u32, "vq16bUi*Wiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_u32_x2, "vQaUi*Wiq8Ui", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_u32_x4, "vQaUi*Wiq16Ui", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_u64, "vq16bUWi*Wiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_u64_x2, "vQaUWi*Wiq4UWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_u64_x4, "vQaUWi*Wiq8UWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_u8, "vq16bUc*Wiq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_u8_x2, "vQaUc*Wiq32Uc", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1_vnum_u8_x4, "vQaUc*Wiq64Uc", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svstnt1b_scatter_s64offset_s64, "vq16bSc*q2Wiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1b_scatter_s64offset_u64, "vq16bUc*q2Wiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1b_scatter_u32base_offset_s32, "vq16bq4UiWiq4i", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1b_scatter_u32base_offset_u32, "vq16bq4UiWiq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1b_scatter_u32base_s32, "vq16bq4Uiq4i", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1b_scatter_u32base_u32, "vq16bq4Uiq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1b_scatter_u32offset_s32, "vq16bSc*q4Uiq4i", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1b_scatter_u32offset_u32, "vq16bUc*q4Uiq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1b_scatter_u64base_offset_s64, "vq16bq2UWiWiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1b_scatter_u64base_offset_u64, "vq16bq2UWiWiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1b_scatter_u64base_s64, "vq16bq2UWiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1b_scatter_u64base_u64, "vq16bq2UWiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1b_scatter_u64offset_s64, "vq16bSc*q2UWiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1b_scatter_u64offset_u64, "vq16bUc*q2UWiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_s64index_s64, "vq16bSs*q2Wiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_s64index_u64, "vq16bUs*q2Wiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_s64offset_s64, "vq16bSs*q2Wiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_s64offset_u64, "vq16bUs*q2Wiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_u32base_index_s32, "vq16bq4UiWiq4i", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_u32base_index_u32, "vq16bq4UiWiq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_u32base_offset_s32, "vq16bq4UiWiq4i", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_u32base_offset_u32, "vq16bq4UiWiq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_u32base_s32, "vq16bq4Uiq4i", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_u32base_u32, "vq16bq4Uiq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_u32offset_s32, "vq16bSs*q4Uiq4i", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_u32offset_u32, "vq16bUs*q4Uiq4Ui", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_u64base_index_s64, "vq16bq2UWiWiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_u64base_index_u64, "vq16bq2UWiWiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_u64base_offset_s64, "vq16bq2UWiWiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_u64base_offset_u64, "vq16bq2UWiWiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_u64base_s64, "vq16bq2UWiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_u64base_u64, "vq16bq2UWiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_u64index_s64, "vq16bSs*q2UWiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_u64index_u64, "vq16bUs*q2UWiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_u64offset_s64, "vq16bSs*q2UWiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1h_scatter_u64offset_u64, "vq16bUs*q2UWiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1w_scatter_s64index_s64, "vq16bSi*q2Wiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1w_scatter_s64index_u64, "vq16bUi*q2Wiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1w_scatter_s64offset_s64, "vq16bSi*q2Wiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1w_scatter_s64offset_u64, "vq16bUi*q2Wiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1w_scatter_u64base_index_s64, "vq16bq2UWiWiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1w_scatter_u64base_index_u64, "vq16bq2UWiWiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1w_scatter_u64base_offset_s64, "vq16bq2UWiWiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1w_scatter_u64base_offset_u64, "vq16bq2UWiWiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1w_scatter_u64base_s64, "vq16bq2UWiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1w_scatter_u64base_u64, "vq16bq2UWiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1w_scatter_u64index_s64, "vq16bSi*q2UWiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1w_scatter_u64index_u64, "vq16bUi*q2UWiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1w_scatter_u64offset_s64, "vq16bSi*q2UWiq2Wi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svstnt1w_scatter_u64offset_u64, "vq16bUi*q2UWiq2UWi", "n", "sve,sve2")
TARGET_BUILTIN(__builtin_sve_svsub_bf16_m, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svsub_bf16_x, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svsub_bf16_z, "q8yq16bq8yq8y", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svsub_f16_m, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_f16_x, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_f16_z, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_f32_m, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_f32_x, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_f32_z, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_f64_m, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_f64_x, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_f64_z, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_bf16_m, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svsub_n_bf16_x, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svsub_n_bf16_z, "q8yq16bq8yy", "n", "(sve,sve2,sve-b16b16)|(sme,sme2,sve-b16b16)")
TARGET_BUILTIN(__builtin_sve_svsub_n_f16_m, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_f16_x, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_f16_z, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_f32_m, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_f32_x, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_f32_z, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_f64_m, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_f64_x, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_f64_z, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_s16_m, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_s16_x, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_s16_z, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_s32_m, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_s32_x, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_s32_z, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_s64_m, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_s64_x, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_s64_z, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_s8_m, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_s8_x, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_s8_z, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_u16_m, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_u16_x, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_u16_z, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_u32_m, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_u32_x, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_u32_z, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_u8_m, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_u8_x, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_n_u8_z, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_s16_m, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_s16_x, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_s16_z, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_s32_m, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_s32_x, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_s32_z, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_s8_m, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_s8_x, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_s8_z, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_u16_m, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_u16_x, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_u16_z, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsub_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnb_n_s16, "q16Scq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnb_n_s32, "q8sq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnb_n_s64, "q4iq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnb_n_u16, "q16Ucq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnb_n_u32, "q8Usq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnb_n_u64, "q4Uiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnb_s16, "q16Scq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnb_s32, "q8sq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnb_s64, "q4iq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnb_u16, "q16Ucq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnb_u32, "q8Usq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnb_u64, "q4Uiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnt_n_s16, "q16Scq16Scq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnt_n_s32, "q8sq8sq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnt_n_s64, "q4iq4iq2WiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnt_n_u16, "q16Ucq16Ucq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnt_n_u32, "q8Usq8Usq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnt_n_u64, "q4Uiq4Uiq2UWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnt_s16, "q16Scq16Scq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnt_s32, "q8sq8sq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnt_s64, "q4iq4iq2Wiq2Wi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnt_u16, "q16Ucq16Ucq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnt_u32, "q8Usq8Usq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubhnt_u64, "q4Uiq4Uiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublb_n_s16, "q8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublb_n_s32, "q4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublb_n_s64, "q2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublb_n_u16, "q8Usq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublb_n_u32, "q4Uiq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublb_n_u64, "q2UWiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublb_s16, "q8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublb_s32, "q4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublb_s64, "q2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublb_u16, "q8Usq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublb_u32, "q4Uiq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublb_u64, "q2UWiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublbt_n_s16, "q8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublbt_n_s32, "q4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublbt_n_s64, "q2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublbt_s16, "q8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublbt_s32, "q4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublbt_s64, "q2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublt_n_s16, "q8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublt_n_s32, "q4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublt_n_s64, "q2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublt_n_u16, "q8Usq16UcUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublt_n_u32, "q4Uiq8UsUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublt_n_u64, "q2UWiq4UiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublt_s16, "q8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublt_s32, "q4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublt_s64, "q2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublt_u16, "q8Usq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublt_u32, "q4Uiq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsublt_u64, "q2UWiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubltb_n_s16, "q8sq16ScSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubltb_n_s32, "q4iq8ss", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubltb_n_s64, "q2Wiq4ii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubltb_s16, "q8sq16Scq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubltb_s32, "q4iq8sq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubltb_s64, "q2Wiq4iq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_f16_m, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_f16_x, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_f16_z, "q8hq16bq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_f32_m, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_f32_x, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_f32_z, "q4fq16bq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_f64_m, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_f64_x, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_f64_z, "q2dq16bq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_f16_m, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_f16_x, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_f16_z, "q8hq16bq8hh", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_f32_m, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_f32_x, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_f32_z, "q4fq16bq4ff", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_f64_m, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_f64_x, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_f64_z, "q2dq16bq2dd", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_s16_m, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_s16_x, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_s16_z, "q8sq16bq8ss", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_s32_m, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_s32_x, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_s32_z, "q4iq16bq4ii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_s64_m, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_s64_x, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_s64_z, "q2Wiq16bq2WiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_s8_m, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_s8_x, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_s8_z, "q16Scq16bq16ScSc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_u16_m, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_u16_x, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_u16_z, "q8Usq16bq8UsUs", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_u32_m, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_u32_x, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_u32_z, "q4Uiq16bq4UiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_u64_m, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_u64_x, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_u64_z, "q2UWiq16bq2UWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_u8_m, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_u8_x, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_n_u8_z, "q16Ucq16bq16UcUc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_s16_m, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_s16_x, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_s16_z, "q8sq16bq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_s32_m, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_s32_x, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_s32_z, "q4iq16bq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_s64_m, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_s64_x, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_s64_z, "q2Wiq16bq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_s8_m, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_s8_x, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_s8_z, "q16Scq16bq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_u16_m, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_u16_x, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_u16_z, "q8Usq16bq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_u32_m, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_u32_x, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_u32_z, "q4Uiq16bq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_u64_m, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_u64_x, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_u64_z, "q2UWiq16bq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_u8_m, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_u8_x, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubr_u8_z, "q16Ucq16bq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svsubwb_n_s16, "q8sq8sSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwb_n_s32, "q4iq4is", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwb_n_s64, "q2Wiq2Wii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwb_n_u16, "q8Usq8UsUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwb_n_u32, "q4Uiq4UiUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwb_n_u64, "q2UWiq2UWiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwb_s16, "q8sq8sq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwb_s32, "q4iq4iq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwb_s64, "q2Wiq2Wiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwb_u16, "q8Usq8Usq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwb_u32, "q4Uiq4Uiq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwb_u64, "q2UWiq2UWiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwt_n_s16, "q8sq8sSc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwt_n_s32, "q4iq4is", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwt_n_s64, "q2Wiq2Wii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwt_n_u16, "q8Usq8UsUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwt_n_u32, "q4Uiq4UiUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwt_n_u64, "q2UWiq2UWiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwt_s16, "q8sq8sq16Sc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwt_s32, "q4iq4iq8s", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwt_s64, "q2Wiq2Wiq4i", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwt_u16, "q8Usq8Usq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwt_u32, "q4Uiq4Uiq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsubwt_u64, "q2UWiq2UWiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svsudot_lane_s32, "q4iq4iq16Scq16UcIUWi", "n", "(sve,i8mm)|(sme,i8mm)")
TARGET_BUILTIN(__builtin_sve_svsudot_n_s32, "q4iq4iq16ScUc", "n", "(sve,i8mm)|(sme,i8mm)")
TARGET_BUILTIN(__builtin_sve_svsudot_s32, "q4iq4iq16Scq16Uc", "n", "(sve,i8mm)|(sme,i8mm)")
TARGET_BUILTIN(__builtin_sve_svtbl2_bf16, "q8yq16yq8Us", "n", "(sve,sve2,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svtbl2_f16, "q8hq16hq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbl2_f32, "q4fq8fq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbl2_f64, "q2dq4dq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbl2_s16, "q8sq16sq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbl2_s32, "q4iq8iq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbl2_s64, "q2Wiq4Wiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbl2_s8, "q16Scq32Scq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbl2_u16, "q8Usq16Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbl2_u32, "q4Uiq8Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbl2_u64, "q2UWiq4UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbl2_u8, "q16Ucq32Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbl_bf16, "q8yq8yq8Us", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svtbl_f16, "q8hq8hq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtbl_f32, "q4fq4fq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtbl_f64, "q2dq2dq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtbl_s16, "q8sq8sq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtbl_s32, "q4iq4iq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtbl_s64, "q2Wiq2Wiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtbl_s8, "q16Scq16Scq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtbl_u16, "q8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtbl_u32, "q4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtbl_u64, "q2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtbl_u8, "q16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtblq_bf16, "q8yq8yq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtblq_f16, "q8hq8hq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtblq_f32, "q4fq4fq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtblq_f64, "q2dq2dq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtblq_mf8, "q16mq16mq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtblq_s16, "q8sq8sq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtblq_s32, "q4iq4iq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtblq_s64, "q2Wiq2Wiq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtblq_s8, "q16Scq16Scq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtblq_u16, "q8Usq8Usq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtblq_u32, "q4Uiq4Uiq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtblq_u64, "q2UWiq2UWiq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtblq_u8, "q16Ucq16Ucq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtbx_bf16, "q8yq8yq8yq8Us", "n", "(sve,sve2,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svtbx_f16, "q8hq8hq8hq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbx_f32, "q4fq4fq4fq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbx_f64, "q2dq2dq2dq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbx_s16, "q8sq8sq8sq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbx_s32, "q4iq4iq4iq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbx_s64, "q2Wiq2Wiq2Wiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbx_s8, "q16Scq16Scq16Scq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbx_u16, "q8Usq8Usq8Usq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbx_u32, "q4Uiq4Uiq4Uiq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbx_u64, "q2UWiq2UWiq2UWiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbx_u8, "q16Ucq16Ucq16Ucq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svtbxq_bf16, "q8yq8yq8yq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtbxq_f16, "q8hq8hq8hq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtbxq_f32, "q4fq4fq4fq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtbxq_f64, "q2dq2dq2dq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtbxq_mf8, "q16mq16mq16mq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtbxq_s16, "q8sq8sq8sq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtbxq_s32, "q4iq4iq4iq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtbxq_s64, "q2Wiq2Wiq2Wiq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtbxq_s8, "q16Scq16Scq16Scq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtbxq_u16, "q8Usq8Usq8Usq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtbxq_u32, "q4Uiq4Uiq4Uiq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtbxq_u64, "q2UWiq2UWiq2UWiq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtbxq_u8, "q16Ucq16Ucq16Ucq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svtmad_f16, "q8hq8hq8hIUWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svtmad_f32, "q4fq4fq4fIUWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svtmad_f64, "q2dq2dq2dIUWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svtrn1_b16, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn1_b32, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn1_b64, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn1_b8, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn1_bf16, "q8yq8yq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svtrn1_f16, "q8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn1_f32, "q4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn1_f64, "q2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn1_s16, "q8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn1_s32, "q4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn1_s64, "q2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn1_s8, "q16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn1_u16, "q8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn1_u32, "q4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn1_u64, "q2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn1_u8, "q16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn1q_bf16, "q8yq8yq8y", "n", "sve,bf16,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn1q_f16, "q8hq8hq8h", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn1q_f32, "q4fq4fq4f", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn1q_f64, "q2dq2dq2d", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn1q_s16, "q8sq8sq8s", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn1q_s32, "q4iq4iq4i", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn1q_s64, "q2Wiq2Wiq2Wi", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn1q_s8, "q16Scq16Scq16Sc", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn1q_u16, "q8Usq8Usq8Us", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn1q_u32, "q4Uiq4Uiq4Ui", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn1q_u64, "q2UWiq2UWiq2UWi", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn1q_u8, "q16Ucq16Ucq16Uc", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn2_b16, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn2_b32, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn2_b64, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn2_b8, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn2_bf16, "q8yq8yq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svtrn2_f16, "q8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn2_f32, "q4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn2_f64, "q2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn2_s16, "q8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn2_s32, "q4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn2_s64, "q2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn2_s8, "q16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn2_u16, "q8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn2_u32, "q4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn2_u64, "q2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn2_u8, "q16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svtrn2q_bf16, "q8yq8yq8y", "n", "sve,bf16,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn2q_f16, "q8hq8hq8h", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn2q_f32, "q4fq4fq4f", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn2q_f64, "q2dq2dq2d", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn2q_s16, "q8sq8sq8s", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn2q_s32, "q4iq4iq4i", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn2q_s64, "q2Wiq2Wiq2Wi", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn2q_s8, "q16Scq16Scq16Sc", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn2q_u16, "q8Usq8Usq8Us", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn2q_u32, "q4Uiq4Uiq4Ui", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn2q_u64, "q2UWiq2UWiq2UWi", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtrn2q_u8, "q16Ucq16Ucq16Uc", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svtsmul_f16, "q8hq8hq8Us", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svtsmul_f32, "q4fq4fq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svtsmul_f64, "q2dq2dq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svtssel_f16, "q8hq8hq8Us", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svtssel_f32, "q4fq4fq4Ui", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svtssel_f64, "q2dq2dq2UWi", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svundef2_b, "q32b", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svundef2_bf16, "q16yv", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svundef2_f16, "q16hv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef2_f32, "q8fv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef2_f64, "q4dv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef2_s16, "q16sv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef2_s32, "q8iv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef2_s64, "q4Wiv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef2_s8, "q32Scv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef2_u16, "q16Usv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef2_u32, "q8Uiv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef2_u64, "q4UWiv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef2_u8, "q32Ucv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef3_bf16, "q24yv", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svundef3_f16, "q24hv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef3_f32, "q12fv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef3_f64, "q6dv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef3_s16, "q24sv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef3_s32, "q12iv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef3_s64, "q6Wiv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef3_s8, "q48Scv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef3_u16, "q24Usv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef3_u32, "q12Uiv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef3_u64, "q6UWiv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef3_u8, "q48Ucv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef4_b, "q64b", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svundef4_bf16, "q32yv", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svundef4_f16, "q32hv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef4_f32, "q16fv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef4_f64, "q8dv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef4_s16, "q32sv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef4_s32, "q16iv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef4_s64, "q8Wiv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef4_s8, "q64Scv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef4_u16, "q32Usv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef4_u32, "q16Uiv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef4_u64, "q8UWiv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef4_u8, "q64Ucv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef_bf16, "q8yv", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svundef_f16, "q8hv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef_f32, "q4fv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef_f64, "q2dv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef_s16, "q8sv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef_s32, "q4iv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef_s64, "q2Wiv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef_s8, "q16Scv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef_u16, "q8Usv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef_u32, "q4Uiv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef_u64, "q2UWiv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svundef_u8, "q16Ucv", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svunpk_s16_s8_x2, "q16sq16Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svunpk_s16_s8_x4, "q32sq32Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svunpk_s32_s16_x2, "q8iq8s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svunpk_s32_s16_x4, "q16iq16s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svunpk_s64_s32_x2, "q4Wiq4i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svunpk_s64_s32_x4, "q8Wiq8i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svunpk_u16_u8_x2, "q16Usq16Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svunpk_u16_u8_x4, "q32Usq32Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svunpk_u32_u16_x2, "q8Uiq8Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svunpk_u32_u16_x4, "q16Uiq16Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svunpk_u64_u32_x2, "q4UWiq4Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svunpk_u64_u32_x4, "q8UWiq8Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svunpkhi_b, "q16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svunpkhi_s16, "q8sq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svunpkhi_s32, "q4iq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svunpkhi_s64, "q2Wiq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svunpkhi_u16, "q8Usq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svunpkhi_u32, "q4Uiq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svunpkhi_u64, "q2UWiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svunpklo_b, "q16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svunpklo_s16, "q8sq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svunpklo_s32, "q4iq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svunpklo_s64, "q2Wiq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svunpklo_u16, "q8Usq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svunpklo_u32, "q4Uiq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svunpklo_u64, "q2UWiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_n_s16_m, "q8sq16bq8sUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_n_s16_x, "q8sq16bq8sUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_n_s16_z, "q8sq16bq8sUs", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_n_s32_m, "q4iq16bq4iUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_n_s32_x, "q4iq16bq4iUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_n_s32_z, "q4iq16bq4iUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_n_s64_m, "q2Wiq16bq2WiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_n_s64_x, "q2Wiq16bq2WiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_n_s64_z, "q2Wiq16bq2WiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_n_s8_m, "q16Scq16bq16ScUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_n_s8_x, "q16Scq16bq16ScUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_n_s8_z, "q16Scq16bq16ScUc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_s16_m, "q8sq16bq8sq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_s16_x, "q8sq16bq8sq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_s16_z, "q8sq16bq8sq8Us", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_s32_m, "q4iq16bq4iq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_s32_x, "q4iq16bq4iq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_s32_z, "q4iq16bq4iq4Ui", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_s64_m, "q2Wiq16bq2Wiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_s64_x, "q2Wiq16bq2Wiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_s64_z, "q2Wiq16bq2Wiq2UWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_s8_m, "q16Scq16bq16Scq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_s8_x, "q16Scq16bq16Scq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svuqadd_s8_z, "q16Scq16bq16Scq16Uc", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svusdot_lane_s32, "q4iq4iq16Ucq16ScIUWi", "n", "(sve,i8mm)|(sme,i8mm)")
TARGET_BUILTIN(__builtin_sve_svusdot_n_s32, "q4iq4iq16UcSc", "n", "(sve,i8mm)|(sme,i8mm)")
TARGET_BUILTIN(__builtin_sve_svusdot_s32, "q4iq4iq16Ucq16Sc", "n", "(sve,i8mm)|(sme,i8mm)")
TARGET_BUILTIN(__builtin_sve_svusmmla_s32, "q4iq4iq16Ucq16Sc", "n", "sve,i8mm")
TARGET_BUILTIN(__builtin_sve_svuzp1_b16, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp1_b32, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp1_b64, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp1_b8, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp1_bf16, "q8yq8yq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svuzp1_f16, "q8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp1_f32, "q4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp1_f64, "q2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp1_s16, "q8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp1_s32, "q4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp1_s64, "q2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp1_s8, "q16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp1_u16, "q8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp1_u32, "q4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp1_u64, "q2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp1_u8, "q16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp1q_bf16, "q8yq8yq8y", "n", "sve,bf16,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp1q_f16, "q8hq8hq8h", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp1q_f32, "q4fq4fq4f", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp1q_f64, "q2dq2dq2d", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp1q_s16, "q8sq8sq8s", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp1q_s32, "q4iq4iq4i", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp1q_s64, "q2Wiq2Wiq2Wi", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp1q_s8, "q16Scq16Scq16Sc", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp1q_u16, "q8Usq8Usq8Us", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp1q_u32, "q4Uiq4Uiq4Ui", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp1q_u64, "q2UWiq2UWiq2UWi", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp1q_u8, "q16Ucq16Ucq16Uc", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp2_b16, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp2_b32, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp2_b64, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp2_b8, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp2_bf16, "q8yq8yq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svuzp2_f16, "q8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp2_f32, "q4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp2_f64, "q2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp2_s16, "q8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp2_s32, "q4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp2_s64, "q2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp2_s8, "q16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp2_u16, "q8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp2_u32, "q4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp2_u64, "q2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp2_u8, "q16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svuzp2q_bf16, "q8yq8yq8y", "n", "sve,bf16,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp2q_f16, "q8hq8hq8h", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp2q_f32, "q4fq4fq4f", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp2q_f64, "q2dq2dq2d", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp2q_s16, "q8sq8sq8s", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp2q_s32, "q4iq4iq4i", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp2q_s64, "q2Wiq2Wiq2Wi", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp2q_s8, "q16Scq16Scq16Sc", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp2q_u16, "q8Usq8Usq8Us", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp2q_u32, "q4Uiq4Uiq4Ui", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp2q_u64, "q2UWiq2UWiq2UWi", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp2q_u8, "q16Ucq16Ucq16Uc", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svuzp_bf16_x2, "q16yq16y", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_bf16_x4, "q32yq32y", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_f16_x2, "q16hq16h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_f16_x4, "q32hq32h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_f32_x2, "q8fq8f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_f32_x4, "q16fq16f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_f64_x2, "q4dq4d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_f64_x4, "q8dq8d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_s16_x2, "q16sq16s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_s16_x4, "q32sq32s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_s32_x2, "q8iq8i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_s32_x4, "q16iq16i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_s64_x2, "q4Wiq4Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_s64_x4, "q8Wiq8Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_s8_x2, "q32Scq32Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_s8_x4, "q64Scq64Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_u16_x2, "q16Usq16Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_u16_x4, "q32Usq32Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_u32_x2, "q8Uiq8Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_u32_x4, "q16Uiq16Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_u64_x2, "q4UWiq4UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_u64_x4, "q8UWiq8UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_u8_x2, "q32Ucq32Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzp_u8_x4, "q64Ucq64Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq1_bf16, "q8yq8yq8y", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq1_f16, "q8hq8hq8h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq1_f32, "q4fq4fq4f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq1_f64, "q2dq2dq2d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq1_mf8, "q16mq16mq16m", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq1_s16, "q8sq8sq8s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq1_s32, "q4iq4iq4i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq1_s64, "q2Wiq2Wiq2Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq1_s8, "q16Scq16Scq16Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq1_u16, "q8Usq8Usq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq1_u32, "q4Uiq4Uiq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq1_u64, "q2UWiq2UWiq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq1_u8, "q16Ucq16Ucq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq2_bf16, "q8yq8yq8y", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq2_f16, "q8hq8hq8h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq2_f32, "q4fq4fq4f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq2_f64, "q2dq2dq2d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq2_mf8, "q16mq16mq16m", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq2_s16, "q8sq8sq8s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq2_s32, "q4iq4iq4i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq2_s64, "q2Wiq2Wiq2Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq2_s8, "q16Scq16Scq16Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq2_u16, "q8Usq8Usq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq2_u32, "q4Uiq4Uiq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq2_u64, "q2UWiq2UWiq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq2_u8, "q16Ucq16Ucq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svuzpq_bf16_x2, "q16yq16y", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_bf16_x4, "q32yq32y", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_f16_x2, "q16hq16h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_f16_x4, "q32hq32h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_f32_x2, "q8fq8f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_f32_x4, "q16fq16f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_f64_x2, "q4dq4d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_f64_x4, "q8dq8d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_s16_x2, "q16sq16s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_s16_x4, "q32sq32s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_s32_x2, "q8iq8i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_s32_x4, "q16iq16i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_s64_x2, "q4Wiq4Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_s64_x4, "q8Wiq8Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_s8_x2, "q32Scq32Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_s8_x4, "q64Scq64Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_u16_x2, "q16Usq16Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_u16_x4, "q32Usq32Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_u32_x2, "q8Uiq8Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_u32_x4, "q16Uiq16Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_u64_x2, "q4UWiq4UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_u64_x4, "q8UWiq8UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_u8_x2, "q32Ucq32Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svuzpq_u8_x4, "q64Ucq64Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svwhilege_b16_s32, "q16bii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilege_b16_s64, "q16bWiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilege_b16_s64_x2, "q32bWiWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilege_b16_u32, "q16bUiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilege_b16_u64, "q16bUWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilege_b16_u64_x2, "q32bUWiUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilege_b32_s32, "q16bii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilege_b32_s64, "q16bWiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilege_b32_s64_x2, "q32bWiWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilege_b32_u32, "q16bUiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilege_b32_u64, "q16bUWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilege_b32_u64_x2, "q32bUWiUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilege_b64_s32, "q16bii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilege_b64_s64, "q16bWiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilege_b64_s64_x2, "q32bWiWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilege_b64_u32, "q16bUiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilege_b64_u64, "q16bUWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilege_b64_u64_x2, "q32bUWiUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilege_b8_s32, "q16bii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilege_b8_s64, "q16bWiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilege_b8_s64_x2, "q32bWiWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilege_b8_u32, "q16bUiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilege_b8_u64, "q16bUWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilege_b8_u64_x2, "q32bUWiUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilege_c16_s64, "QaWiWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilege_c16_u64, "QaUWiUWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilege_c32_s64, "QaWiWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilege_c32_u64, "QaUWiUWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilege_c64_s64, "QaWiWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilege_c64_u64, "QaUWiUWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilege_c8_s64, "QaWiWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilege_c8_u64, "QaUWiUWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b16_s32, "q16bii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b16_s64, "q16bWiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b16_s64_x2, "q32bWiWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b16_u32, "q16bUiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b16_u64, "q16bUWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b16_u64_x2, "q32bUWiUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b32_s32, "q16bii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b32_s64, "q16bWiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b32_s64_x2, "q32bWiWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b32_u32, "q16bUiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b32_u64, "q16bUWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b32_u64_x2, "q32bUWiUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b64_s32, "q16bii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b64_s64, "q16bWiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b64_s64_x2, "q32bWiWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b64_u32, "q16bUiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b64_u64, "q16bUWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b64_u64_x2, "q32bUWiUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b8_s32, "q16bii", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b8_s64, "q16bWiWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b8_s64_x2, "q32bWiWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b8_u32, "q16bUiUi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b8_u64, "q16bUWiUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilegt_b8_u64_x2, "q32bUWiUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilegt_c16_s64, "QaWiWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilegt_c16_u64, "QaUWiUWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilegt_c32_s64, "QaWiWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilegt_c32_u64, "QaUWiUWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilegt_c64_s64, "QaWiWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilegt_c64_u64, "QaUWiUWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilegt_c8_s64, "QaWiWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilegt_c8_u64, "QaUWiUWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilele_b16_s32, "q16bii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilele_b16_s64, "q16bWiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilele_b16_s64_x2, "q32bWiWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilele_b16_u32, "q16bUiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilele_b16_u64, "q16bUWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilele_b16_u64_x2, "q32bUWiUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilele_b32_s32, "q16bii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilele_b32_s64, "q16bWiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilele_b32_s64_x2, "q32bWiWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilele_b32_u32, "q16bUiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilele_b32_u64, "q16bUWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilele_b32_u64_x2, "q32bUWiUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilele_b64_s32, "q16bii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilele_b64_s64, "q16bWiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilele_b64_s64_x2, "q32bWiWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilele_b64_u32, "q16bUiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilele_b64_u64, "q16bUWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilele_b64_u64_x2, "q32bUWiUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilele_b8_s32, "q16bii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilele_b8_s64, "q16bWiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilele_b8_s64_x2, "q32bWiWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilele_b8_u32, "q16bUiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilele_b8_u64, "q16bUWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilele_b8_u64_x2, "q32bUWiUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilele_c16_s64, "QaWiWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilele_c16_u64, "QaUWiUWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilele_c32_s64, "QaWiWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilele_c32_u64, "QaUWiUWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilele_c64_s64, "QaWiWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilele_c64_u64, "QaUWiUWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilele_c8_s64, "QaWiWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilele_c8_u64, "QaUWiUWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b16_s32, "q16bii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b16_s64, "q16bWiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b16_s64_x2, "q32bWiWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b16_u32, "q16bUiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b16_u64, "q16bUWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b16_u64_x2, "q32bUWiUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b32_s32, "q16bii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b32_s64, "q16bWiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b32_s64_x2, "q32bWiWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b32_u32, "q16bUiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b32_u64, "q16bUWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b32_u64_x2, "q32bUWiUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b64_s32, "q16bii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b64_s64, "q16bWiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b64_s64_x2, "q32bWiWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b64_u32, "q16bUiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b64_u64, "q16bUWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b64_u64_x2, "q32bUWiUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b8_s32, "q16bii", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b8_s64, "q16bWiWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b8_s64_x2, "q32bWiWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b8_u32, "q16bUiUi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b8_u64, "q16bUWiUWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svwhilelt_b8_u64_x2, "q32bUWiUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilelt_c16_s64, "QaWiWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilelt_c16_u64, "QaUWiUWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilelt_c32_s64, "QaWiWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilelt_c32_u64, "QaUWiUWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilelt_c64_s64, "QaWiWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilelt_c64_u64, "QaUWiUWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilelt_c8_s64, "QaWiWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilelt_c8_u64, "QaUWiUWiIUWi", "n", "(sve,sve2p1)|(sme,sme2)")
TARGET_BUILTIN(__builtin_sve_svwhilerw_bf16, "q16byC*yC*", "n", "(sve,sve2,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svwhilerw_f16, "q16bhC*hC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilerw_f32, "q16bfC*fC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilerw_f64, "q16bdC*dC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilerw_s16, "q16bSsC*SsC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilerw_s32, "q16bSiC*SiC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilerw_s64, "q16bSWiC*SWiC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilerw_s8, "q16bScC*ScC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilerw_u16, "q16bUsC*UsC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilerw_u32, "q16bUiC*UiC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilerw_u64, "q16bUWiC*UWiC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilerw_u8, "q16bUcC*UcC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilewr_bf16, "q16byC*yC*", "n", "(sve,sve2,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svwhilewr_f16, "q16bhC*hC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilewr_f32, "q16bfC*fC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilewr_f64, "q16bdC*dC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilewr_s16, "q16bSsC*SsC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilewr_s32, "q16bSiC*SiC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilewr_s64, "q16bSWiC*SWiC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilewr_s8, "q16bScC*ScC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilewr_u16, "q16bUsC*UsC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilewr_u32, "q16bUiC*UiC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilewr_u64, "q16bUWiC*UWiC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwhilewr_u8, "q16bUcC*UcC*", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svwrffr, "vq16b", "n", "sve")
TARGET_BUILTIN(__builtin_sve_svxar_n_s16, "q8sq8sq8sIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svxar_n_s32, "q4iq4iq4iIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svxar_n_s64, "q2Wiq2Wiq2WiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svxar_n_s8, "q16Scq16Scq16ScIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svxar_n_u16, "q8Usq8Usq8UsIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svxar_n_u32, "q4Uiq4Uiq4UiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svxar_n_u64, "q2UWiq2UWiq2UWiIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svxar_n_u8, "q16Ucq16Ucq16UcIUWi", "n", "(sve,sve2)|sme")
TARGET_BUILTIN(__builtin_sve_svzip1_b16, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip1_b32, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip1_b64, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip1_b8, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip1_bf16, "q8yq8yq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svzip1_f16, "q8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip1_f32, "q4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip1_f64, "q2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip1_s16, "q8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip1_s32, "q4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip1_s64, "q2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip1_s8, "q16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip1_u16, "q8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip1_u32, "q4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip1_u64, "q2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip1_u8, "q16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip1q_bf16, "q8yq8yq8y", "n", "sve,bf16,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip1q_f16, "q8hq8hq8h", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip1q_f32, "q4fq4fq4f", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip1q_f64, "q2dq2dq2d", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip1q_s16, "q8sq8sq8s", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip1q_s32, "q4iq4iq4i", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip1q_s64, "q2Wiq2Wiq2Wi", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip1q_s8, "q16Scq16Scq16Sc", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip1q_u16, "q8Usq8Usq8Us", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip1q_u32, "q4Uiq4Uiq4Ui", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip1q_u64, "q2UWiq2UWiq2UWi", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip1q_u8, "q16Ucq16Ucq16Uc", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip2_b16, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip2_b32, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip2_b64, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip2_b8, "q16bq16bq16b", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip2_bf16, "q8yq8yq8y", "n", "(sve,bf16)|(sme,bf16)")
TARGET_BUILTIN(__builtin_sve_svzip2_f16, "q8hq8hq8h", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip2_f32, "q4fq4fq4f", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip2_f64, "q2dq2dq2d", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip2_s16, "q8sq8sq8s", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip2_s32, "q4iq4iq4i", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip2_s64, "q2Wiq2Wiq2Wi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip2_s8, "q16Scq16Scq16Sc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip2_u16, "q8Usq8Usq8Us", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip2_u32, "q4Uiq4Uiq4Ui", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip2_u64, "q2UWiq2UWiq2UWi", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip2_u8, "q16Ucq16Ucq16Uc", "n", "sve|sme")
TARGET_BUILTIN(__builtin_sve_svzip2q_bf16, "q8yq8yq8y", "n", "sve,bf16,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip2q_f16, "q8hq8hq8h", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip2q_f32, "q4fq4fq4f", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip2q_f64, "q2dq2dq2d", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip2q_s16, "q8sq8sq8s", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip2q_s32, "q4iq4iq4i", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip2q_s64, "q2Wiq2Wiq2Wi", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip2q_s8, "q16Scq16Scq16Sc", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip2q_u16, "q8Usq8Usq8Us", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip2q_u32, "q4Uiq4Uiq4Ui", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip2q_u64, "q2UWiq2UWiq2UWi", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip2q_u8, "q16Ucq16Ucq16Uc", "n", "sve,f64mm")
TARGET_BUILTIN(__builtin_sve_svzip_bf16_x2, "q16yq16y", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_bf16_x4, "q32yq32y", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_f16_x2, "q16hq16h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_f16_x4, "q32hq32h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_f32_x2, "q8fq8f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_f32_x4, "q16fq16f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_f64_x2, "q4dq4d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_f64_x4, "q8dq8d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_s16_x2, "q16sq16s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_s16_x4, "q32sq32s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_s32_x2, "q8iq8i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_s32_x4, "q16iq16i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_s64_x2, "q4Wiq4Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_s64_x4, "q8Wiq8Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_s8_x2, "q32Scq32Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_s8_x4, "q64Scq64Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_u16_x2, "q16Usq16Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_u16_x4, "q32Usq32Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_u32_x2, "q8Uiq8Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_u32_x4, "q16Uiq16Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_u64_x2, "q4UWiq4UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_u64_x4, "q8UWiq8UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_u8_x2, "q32Ucq32Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzip_u8_x4, "q64Ucq64Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq1_bf16, "q8yq8yq8y", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq1_f16, "q8hq8hq8h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq1_f32, "q4fq4fq4f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq1_f64, "q2dq2dq2d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq1_mf8, "q16mq16mq16m", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq1_s16, "q8sq8sq8s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq1_s32, "q4iq4iq4i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq1_s64, "q2Wiq2Wiq2Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq1_s8, "q16Scq16Scq16Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq1_u16, "q8Usq8Usq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq1_u32, "q4Uiq4Uiq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq1_u64, "q2UWiq2UWiq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq1_u8, "q16Ucq16Ucq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq2_bf16, "q8yq8yq8y", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq2_f16, "q8hq8hq8h", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq2_f32, "q4fq4fq4f", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq2_f64, "q2dq2dq2d", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq2_mf8, "q16mq16mq16m", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq2_s16, "q8sq8sq8s", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq2_s32, "q4iq4iq4i", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq2_s64, "q2Wiq2Wiq2Wi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq2_s8, "q16Scq16Scq16Sc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq2_u16, "q8Usq8Usq8Us", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq2_u32, "q4Uiq4Uiq4Ui", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq2_u64, "q2UWiq2UWiq2UWi", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq2_u8, "q16Ucq16Ucq16Uc", "n", "sve,sve2p1")
TARGET_BUILTIN(__builtin_sve_svzipq_bf16_x2, "q16yq16y", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_bf16_x4, "q32yq32y", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_f16_x2, "q16hq16h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_f16_x4, "q32hq32h", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_f32_x2, "q8fq8f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_f32_x4, "q16fq16f", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_f64_x2, "q4dq4d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_f64_x4, "q8dq8d", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_s16_x2, "q16sq16s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_s16_x4, "q32sq32s", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_s32_x2, "q8iq8i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_s32_x4, "q16iq16i", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_s64_x2, "q4Wiq4Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_s64_x4, "q8Wiq8Wi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_s8_x2, "q32Scq32Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_s8_x4, "q64Scq64Sc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_u16_x2, "q16Usq16Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_u16_x4, "q32Usq32Us", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_u32_x2, "q8Uiq8Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_u32_x4, "q16Uiq16Ui", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_u64_x2, "q4UWiq4UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_u64_x4, "q8UWiq8UWi", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_u8_x2, "q32Ucq32Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_svzipq_u8_x4, "q64Ucq64Uc", "n", "sme,sme2")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_s8, "q16Scq16Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_u8, "q16Scq16Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_mf8, "q16Scq16m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_s16, "q16Scq8s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_u16, "q16Scq8Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_s32, "q16Scq4i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_u32, "q16Scq4Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_s64, "q16Scq2Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_u64, "q16Scq2UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_f16, "q16Scq8h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_bf16, "q16Scq8y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_f32, "q16Scq4f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_f64, "q16Scq2d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_s8, "q16Ucq16Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_u8, "q16Ucq16Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_mf8, "q16Ucq16m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_s16, "q16Ucq8s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_u16, "q16Ucq8Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_s32, "q16Ucq4i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_u32, "q16Ucq4Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_s64, "q16Ucq2Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_u64, "q16Ucq2UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_f16, "q16Ucq8h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_bf16, "q16Ucq8y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_f32, "q16Ucq4f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_f64, "q16Ucq2d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_s8, "q16mq16Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_u8, "q16mq16Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_mf8, "q16mq16m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_s16, "q16mq8s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_u16, "q16mq8Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_s32, "q16mq4i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_u32, "q16mq4Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_s64, "q16mq2Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_u64, "q16mq2UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_f16, "q16mq8h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_bf16, "q16mq8y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_f32, "q16mq4f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_f64, "q16mq2d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_s8, "q8sq16Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_u8, "q8sq16Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_mf8, "q8sq16m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_s16, "q8sq8s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_u16, "q8sq8Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_s32, "q8sq4i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_u32, "q8sq4Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_s64, "q8sq2Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_u64, "q8sq2UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_f16, "q8sq8h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_bf16, "q8sq8y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_f32, "q8sq4f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_f64, "q8sq2d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_s8, "q8Usq16Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_u8, "q8Usq16Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_mf8, "q8Usq16m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_s16, "q8Usq8s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_u16, "q8Usq8Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_s32, "q8Usq4i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_u32, "q8Usq4Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_s64, "q8Usq2Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_u64, "q8Usq2UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_f16, "q8Usq8h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_bf16, "q8Usq8y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_f32, "q8Usq4f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_f64, "q8Usq2d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_s8, "q4iq16Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_u8, "q4iq16Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_mf8, "q4iq16m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_s16, "q4iq8s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_u16, "q4iq8Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_s32, "q4iq4i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_u32, "q4iq4Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_s64, "q4iq2Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_u64, "q4iq2UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_f16, "q4iq8h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_bf16, "q4iq8y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_f32, "q4iq4f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_f64, "q4iq2d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_s8, "q4Uiq16Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_u8, "q4Uiq16Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_mf8, "q4Uiq16m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_s16, "q4Uiq8s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_u16, "q4Uiq8Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_s32, "q4Uiq4i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_u32, "q4Uiq4Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_s64, "q4Uiq2Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_u64, "q4Uiq2UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_f16, "q4Uiq8h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_bf16, "q4Uiq8y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_f32, "q4Uiq4f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_f64, "q4Uiq2d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_s8, "q2Wiq16Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_u8, "q2Wiq16Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_mf8, "q2Wiq16m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_s16, "q2Wiq8s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_u16, "q2Wiq8Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_s32, "q2Wiq4i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_u32, "q2Wiq4Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_s64, "q2Wiq2Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_u64, "q2Wiq2UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_f16, "q2Wiq8h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_bf16, "q2Wiq8y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_f32, "q2Wiq4f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_f64, "q2Wiq2d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_s8, "q2UWiq16Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_u8, "q2UWiq16Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_mf8, "q2UWiq16m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_s16, "q2UWiq8s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_u16, "q2UWiq8Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_s32, "q2UWiq4i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_u32, "q2UWiq4Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_s64, "q2UWiq2Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_u64, "q2UWiq2UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_f16, "q2UWiq8h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_bf16, "q2UWiq8y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_f32, "q2UWiq4f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_f64, "q2UWiq2d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_s8, "q8hq16Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_u8, "q8hq16Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_mf8, "q8hq16m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_s16, "q8hq8s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_u16, "q8hq8Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_s32, "q8hq4i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_u32, "q8hq4Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_s64, "q8hq2Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_u64, "q8hq2UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_f16, "q8hq8h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_bf16, "q8hq8y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_f32, "q8hq4f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_f64, "q8hq2d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_s8, "q8yq16Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_u8, "q8yq16Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_mf8, "q8yq16m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_s16, "q8yq8s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_u16, "q8yq8Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_s32, "q8yq4i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_u32, "q8yq4Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_s64, "q8yq2Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_u64, "q8yq2UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_f16, "q8yq8h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_bf16, "q8yq8y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_f32, "q8yq4f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_f64, "q8yq2d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_s8, "q4fq16Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_u8, "q4fq16Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_mf8, "q4fq16m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_s16, "q4fq8s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_u16, "q4fq8Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_s32, "q4fq4i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_u32, "q4fq4Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_s64, "q4fq2Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_u64, "q4fq2UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_f16, "q4fq8h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_bf16, "q4fq8y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_f32, "q4fq4f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_f64, "q4fq2d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_s8, "q2dq16Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_u8, "q2dq16Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_mf8, "q2dq16m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_s16, "q2dq8s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_u16, "q2dq8Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_s32, "q2dq4i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_u32, "q2dq4Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_s64, "q2dq2Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_u64, "q2dq2UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_f16, "q2dq8h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_bf16, "q2dq8y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_f32, "q2dq4f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_f64, "q2dq2d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_s8_x2, "q32Scq32Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_u8_x2, "q32Scq32Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_mf8_x2, "q32Scq32m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_s16_x2, "q32Scq16s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_u16_x2, "q32Scq16Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_s32_x2, "q32Scq8i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_u32_x2, "q32Scq8Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_s64_x2, "q32Scq4Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_u64_x2, "q32Scq4UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_f16_x2, "q32Scq16h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_bf16_x2, "q32Scq16y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_f32_x2, "q32Scq8f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_f64_x2, "q32Scq4d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_s8_x2, "q32Ucq32Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_u8_x2, "q32Ucq32Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_mf8_x2, "q32Ucq32m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_s16_x2, "q32Ucq16s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_u16_x2, "q32Ucq16Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_s32_x2, "q32Ucq8i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_u32_x2, "q32Ucq8Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_s64_x2, "q32Ucq4Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_u64_x2, "q32Ucq4UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_f16_x2, "q32Ucq16h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_bf16_x2, "q32Ucq16y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_f32_x2, "q32Ucq8f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_f64_x2, "q32Ucq4d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_s8_x2, "q32mq32Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_u8_x2, "q32mq32Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_mf8_x2, "q32mq32m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_s16_x2, "q32mq16s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_u16_x2, "q32mq16Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_s32_x2, "q32mq8i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_u32_x2, "q32mq8Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_s64_x2, "q32mq4Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_u64_x2, "q32mq4UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_f16_x2, "q32mq16h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_bf16_x2, "q32mq16y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_f32_x2, "q32mq8f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_f64_x2, "q32mq4d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_s8_x2, "q16sq32Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_u8_x2, "q16sq32Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_mf8_x2, "q16sq32m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_s16_x2, "q16sq16s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_u16_x2, "q16sq16Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_s32_x2, "q16sq8i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_u32_x2, "q16sq8Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_s64_x2, "q16sq4Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_u64_x2, "q16sq4UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_f16_x2, "q16sq16h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_bf16_x2, "q16sq16y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_f32_x2, "q16sq8f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_f64_x2, "q16sq4d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_s8_x2, "q16Usq32Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_u8_x2, "q16Usq32Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_mf8_x2, "q16Usq32m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_s16_x2, "q16Usq16s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_u16_x2, "q16Usq16Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_s32_x2, "q16Usq8i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_u32_x2, "q16Usq8Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_s64_x2, "q16Usq4Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_u64_x2, "q16Usq4UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_f16_x2, "q16Usq16h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_bf16_x2, "q16Usq16y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_f32_x2, "q16Usq8f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_f64_x2, "q16Usq4d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_s8_x2, "q8iq32Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_u8_x2, "q8iq32Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_mf8_x2, "q8iq32m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_s16_x2, "q8iq16s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_u16_x2, "q8iq16Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_s32_x2, "q8iq8i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_u32_x2, "q8iq8Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_s64_x2, "q8iq4Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_u64_x2, "q8iq4UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_f16_x2, "q8iq16h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_bf16_x2, "q8iq16y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_f32_x2, "q8iq8f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_f64_x2, "q8iq4d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_s8_x2, "q8Uiq32Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_u8_x2, "q8Uiq32Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_mf8_x2, "q8Uiq32m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_s16_x2, "q8Uiq16s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_u16_x2, "q8Uiq16Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_s32_x2, "q8Uiq8i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_u32_x2, "q8Uiq8Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_s64_x2, "q8Uiq4Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_u64_x2, "q8Uiq4UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_f16_x2, "q8Uiq16h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_bf16_x2, "q8Uiq16y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_f32_x2, "q8Uiq8f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_f64_x2, "q8Uiq4d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_s8_x2, "q4Wiq32Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_u8_x2, "q4Wiq32Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_mf8_x2, "q4Wiq32m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_s16_x2, "q4Wiq16s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_u16_x2, "q4Wiq16Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_s32_x2, "q4Wiq8i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_u32_x2, "q4Wiq8Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_s64_x2, "q4Wiq4Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_u64_x2, "q4Wiq4UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_f16_x2, "q4Wiq16h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_bf16_x2, "q4Wiq16y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_f32_x2, "q4Wiq8f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_f64_x2, "q4Wiq4d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_s8_x2, "q4UWiq32Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_u8_x2, "q4UWiq32Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_mf8_x2, "q4UWiq32m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_s16_x2, "q4UWiq16s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_u16_x2, "q4UWiq16Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_s32_x2, "q4UWiq8i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_u32_x2, "q4UWiq8Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_s64_x2, "q4UWiq4Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_u64_x2, "q4UWiq4UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_f16_x2, "q4UWiq16h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_bf16_x2, "q4UWiq16y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_f32_x2, "q4UWiq8f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_f64_x2, "q4UWiq4d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_s8_x2, "q16hq32Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_u8_x2, "q16hq32Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_mf8_x2, "q16hq32m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_s16_x2, "q16hq16s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_u16_x2, "q16hq16Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_s32_x2, "q16hq8i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_u32_x2, "q16hq8Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_s64_x2, "q16hq4Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_u64_x2, "q16hq4UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_f16_x2, "q16hq16h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_bf16_x2, "q16hq16y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_f32_x2, "q16hq8f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_f64_x2, "q16hq4d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_s8_x2, "q16yq32Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_u8_x2, "q16yq32Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_mf8_x2, "q16yq32m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_s16_x2, "q16yq16s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_u16_x2, "q16yq16Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_s32_x2, "q16yq8i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_u32_x2, "q16yq8Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_s64_x2, "q16yq4Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_u64_x2, "q16yq4UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_f16_x2, "q16yq16h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_bf16_x2, "q16yq16y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_f32_x2, "q16yq8f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_f64_x2, "q16yq4d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_s8_x2, "q8fq32Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_u8_x2, "q8fq32Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_mf8_x2, "q8fq32m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_s16_x2, "q8fq16s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_u16_x2, "q8fq16Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_s32_x2, "q8fq8i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_u32_x2, "q8fq8Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_s64_x2, "q8fq4Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_u64_x2, "q8fq4UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_f16_x2, "q8fq16h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_bf16_x2, "q8fq16y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_f32_x2, "q8fq8f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_f64_x2, "q8fq4d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_s8_x2, "q4dq32Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_u8_x2, "q4dq32Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_mf8_x2, "q4dq32m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_s16_x2, "q4dq16s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_u16_x2, "q4dq16Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_s32_x2, "q4dq8i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_u32_x2, "q4dq8Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_s64_x2, "q4dq4Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_u64_x2, "q4dq4UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_f16_x2, "q4dq16h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_bf16_x2, "q4dq16y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_f32_x2, "q4dq8f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_f64_x2, "q4dq4d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_s8_x3, "q48Scq48Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_u8_x3, "q48Scq48Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_mf8_x3, "q48Scq48m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_s16_x3, "q48Scq24s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_u16_x3, "q48Scq24Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_s32_x3, "q48Scq12i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_u32_x3, "q48Scq12Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_s64_x3, "q48Scq6Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_u64_x3, "q48Scq6UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_f16_x3, "q48Scq24h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_bf16_x3, "q48Scq24y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_f32_x3, "q48Scq12f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_f64_x3, "q48Scq6d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_s8_x3, "q48Ucq48Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_u8_x3, "q48Ucq48Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_mf8_x3, "q48Ucq48m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_s16_x3, "q48Ucq24s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_u16_x3, "q48Ucq24Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_s32_x3, "q48Ucq12i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_u32_x3, "q48Ucq12Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_s64_x3, "q48Ucq6Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_u64_x3, "q48Ucq6UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_f16_x3, "q48Ucq24h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_bf16_x3, "q48Ucq24y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_f32_x3, "q48Ucq12f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_f64_x3, "q48Ucq6d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_s8_x3, "q48mq48Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_u8_x3, "q48mq48Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_mf8_x3, "q48mq48m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_s16_x3, "q48mq24s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_u16_x3, "q48mq24Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_s32_x3, "q48mq12i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_u32_x3, "q48mq12Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_s64_x3, "q48mq6Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_u64_x3, "q48mq6UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_f16_x3, "q48mq24h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_bf16_x3, "q48mq24y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_f32_x3, "q48mq12f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_f64_x3, "q48mq6d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_s8_x3, "q24sq48Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_u8_x3, "q24sq48Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_mf8_x3, "q24sq48m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_s16_x3, "q24sq24s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_u16_x3, "q24sq24Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_s32_x3, "q24sq12i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_u32_x3, "q24sq12Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_s64_x3, "q24sq6Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_u64_x3, "q24sq6UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_f16_x3, "q24sq24h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_bf16_x3, "q24sq24y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_f32_x3, "q24sq12f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_f64_x3, "q24sq6d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_s8_x3, "q24Usq48Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_u8_x3, "q24Usq48Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_mf8_x3, "q24Usq48m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_s16_x3, "q24Usq24s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_u16_x3, "q24Usq24Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_s32_x3, "q24Usq12i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_u32_x3, "q24Usq12Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_s64_x3, "q24Usq6Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_u64_x3, "q24Usq6UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_f16_x3, "q24Usq24h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_bf16_x3, "q24Usq24y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_f32_x3, "q24Usq12f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_f64_x3, "q24Usq6d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_s8_x3, "q12iq48Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_u8_x3, "q12iq48Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_mf8_x3, "q12iq48m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_s16_x3, "q12iq24s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_u16_x3, "q12iq24Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_s32_x3, "q12iq12i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_u32_x3, "q12iq12Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_s64_x3, "q12iq6Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_u64_x3, "q12iq6UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_f16_x3, "q12iq24h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_bf16_x3, "q12iq24y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_f32_x3, "q12iq12f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_f64_x3, "q12iq6d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_s8_x3, "q12Uiq48Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_u8_x3, "q12Uiq48Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_mf8_x3, "q12Uiq48m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_s16_x3, "q12Uiq24s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_u16_x3, "q12Uiq24Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_s32_x3, "q12Uiq12i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_u32_x3, "q12Uiq12Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_s64_x3, "q12Uiq6Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_u64_x3, "q12Uiq6UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_f16_x3, "q12Uiq24h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_bf16_x3, "q12Uiq24y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_f32_x3, "q12Uiq12f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_f64_x3, "q12Uiq6d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_s8_x3, "q6Wiq48Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_u8_x3, "q6Wiq48Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_mf8_x3, "q6Wiq48m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_s16_x3, "q6Wiq24s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_u16_x3, "q6Wiq24Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_s32_x3, "q6Wiq12i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_u32_x3, "q6Wiq12Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_s64_x3, "q6Wiq6Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_u64_x3, "q6Wiq6UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_f16_x3, "q6Wiq24h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_bf16_x3, "q6Wiq24y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_f32_x3, "q6Wiq12f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_f64_x3, "q6Wiq6d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_s8_x3, "q6UWiq48Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_u8_x3, "q6UWiq48Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_mf8_x3, "q6UWiq48m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_s16_x3, "q6UWiq24s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_u16_x3, "q6UWiq24Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_s32_x3, "q6UWiq12i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_u32_x3, "q6UWiq12Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_s64_x3, "q6UWiq6Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_u64_x3, "q6UWiq6UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_f16_x3, "q6UWiq24h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_bf16_x3, "q6UWiq24y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_f32_x3, "q6UWiq12f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_f64_x3, "q6UWiq6d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_s8_x3, "q24hq48Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_u8_x3, "q24hq48Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_mf8_x3, "q24hq48m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_s16_x3, "q24hq24s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_u16_x3, "q24hq24Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_s32_x3, "q24hq12i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_u32_x3, "q24hq12Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_s64_x3, "q24hq6Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_u64_x3, "q24hq6UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_f16_x3, "q24hq24h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_bf16_x3, "q24hq24y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_f32_x3, "q24hq12f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_f64_x3, "q24hq6d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_s8_x3, "q24yq48Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_u8_x3, "q24yq48Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_mf8_x3, "q24yq48m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_s16_x3, "q24yq24s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_u16_x3, "q24yq24Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_s32_x3, "q24yq12i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_u32_x3, "q24yq12Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_s64_x3, "q24yq6Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_u64_x3, "q24yq6UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_f16_x3, "q24yq24h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_bf16_x3, "q24yq24y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_f32_x3, "q24yq12f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_f64_x3, "q24yq6d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_s8_x3, "q12fq48Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_u8_x3, "q12fq48Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_mf8_x3, "q12fq48m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_s16_x3, "q12fq24s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_u16_x3, "q12fq24Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_s32_x3, "q12fq12i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_u32_x3, "q12fq12Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_s64_x3, "q12fq6Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_u64_x3, "q12fq6UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_f16_x3, "q12fq24h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_bf16_x3, "q12fq24y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_f32_x3, "q12fq12f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_f64_x3, "q12fq6d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_s8_x3, "q6dq48Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_u8_x3, "q6dq48Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_mf8_x3, "q6dq48m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_s16_x3, "q6dq24s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_u16_x3, "q6dq24Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_s32_x3, "q6dq12i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_u32_x3, "q6dq12Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_s64_x3, "q6dq6Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_u64_x3, "q6dq6UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_f16_x3, "q6dq24h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_bf16_x3, "q6dq24y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_f32_x3, "q6dq12f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_f64_x3, "q6dq6d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_s8_x4, "q64Scq64Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_u8_x4, "q64Scq64Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_mf8_x4, "q64Scq64m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_s16_x4, "q64Scq32s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_u16_x4, "q64Scq32Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_s32_x4, "q64Scq16i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_u32_x4, "q64Scq16Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_s64_x4, "q64Scq8Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_u64_x4, "q64Scq8UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_f16_x4, "q64Scq32h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_bf16_x4, "q64Scq32y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_f32_x4, "q64Scq16f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s8_f64_x4, "q64Scq8d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_s8_x4, "q64Ucq64Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_u8_x4, "q64Ucq64Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_mf8_x4, "q64Ucq64m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_s16_x4, "q64Ucq32s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_u16_x4, "q64Ucq32Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_s32_x4, "q64Ucq16i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_u32_x4, "q64Ucq16Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_s64_x4, "q64Ucq8Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_u64_x4, "q64Ucq8UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_f16_x4, "q64Ucq32h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_bf16_x4, "q64Ucq32y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_f32_x4, "q64Ucq16f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u8_f64_x4, "q64Ucq8d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_s8_x4, "q64mq64Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_u8_x4, "q64mq64Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_mf8_x4, "q64mq64m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_s16_x4, "q64mq32s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_u16_x4, "q64mq32Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_s32_x4, "q64mq16i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_u32_x4, "q64mq16Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_s64_x4, "q64mq8Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_u64_x4, "q64mq8UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_f16_x4, "q64mq32h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_bf16_x4, "q64mq32y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_f32_x4, "q64mq16f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_mf8_f64_x4, "q64mq8d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_s8_x4, "q32sq64Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_u8_x4, "q32sq64Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_mf8_x4, "q32sq64m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_s16_x4, "q32sq32s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_u16_x4, "q32sq32Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_s32_x4, "q32sq16i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_u32_x4, "q32sq16Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_s64_x4, "q32sq8Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_u64_x4, "q32sq8UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_f16_x4, "q32sq32h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_bf16_x4, "q32sq32y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_f32_x4, "q32sq16f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s16_f64_x4, "q32sq8d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_s8_x4, "q32Usq64Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_u8_x4, "q32Usq64Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_mf8_x4, "q32Usq64m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_s16_x4, "q32Usq32s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_u16_x4, "q32Usq32Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_s32_x4, "q32Usq16i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_u32_x4, "q32Usq16Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_s64_x4, "q32Usq8Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_u64_x4, "q32Usq8UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_f16_x4, "q32Usq32h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_bf16_x4, "q32Usq32y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_f32_x4, "q32Usq16f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u16_f64_x4, "q32Usq8d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_s8_x4, "q16iq64Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_u8_x4, "q16iq64Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_mf8_x4, "q16iq64m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_s16_x4, "q16iq32s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_u16_x4, "q16iq32Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_s32_x4, "q16iq16i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_u32_x4, "q16iq16Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_s64_x4, "q16iq8Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_u64_x4, "q16iq8UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_f16_x4, "q16iq32h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_bf16_x4, "q16iq32y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_f32_x4, "q16iq16f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s32_f64_x4, "q16iq8d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_s8_x4, "q16Uiq64Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_u8_x4, "q16Uiq64Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_mf8_x4, "q16Uiq64m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_s16_x4, "q16Uiq32s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_u16_x4, "q16Uiq32Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_s32_x4, "q16Uiq16i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_u32_x4, "q16Uiq16Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_s64_x4, "q16Uiq8Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_u64_x4, "q16Uiq8UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_f16_x4, "q16Uiq32h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_bf16_x4, "q16Uiq32y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_f32_x4, "q16Uiq16f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u32_f64_x4, "q16Uiq8d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_s8_x4, "q8Wiq64Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_u8_x4, "q8Wiq64Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_mf8_x4, "q8Wiq64m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_s16_x4, "q8Wiq32s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_u16_x4, "q8Wiq32Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_s32_x4, "q8Wiq16i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_u32_x4, "q8Wiq16Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_s64_x4, "q8Wiq8Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_u64_x4, "q8Wiq8UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_f16_x4, "q8Wiq32h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_bf16_x4, "q8Wiq32y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_f32_x4, "q8Wiq16f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_s64_f64_x4, "q8Wiq8d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_s8_x4, "q8UWiq64Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_u8_x4, "q8UWiq64Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_mf8_x4, "q8UWiq64m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_s16_x4, "q8UWiq32s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_u16_x4, "q8UWiq32Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_s32_x4, "q8UWiq16i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_u32_x4, "q8UWiq16Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_s64_x4, "q8UWiq8Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_u64_x4, "q8UWiq8UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_f16_x4, "q8UWiq32h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_bf16_x4, "q8UWiq32y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_f32_x4, "q8UWiq16f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_u64_f64_x4, "q8UWiq8d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_s8_x4, "q32hq64Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_u8_x4, "q32hq64Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_mf8_x4, "q32hq64m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_s16_x4, "q32hq32s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_u16_x4, "q32hq32Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_s32_x4, "q32hq16i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_u32_x4, "q32hq16Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_s64_x4, "q32hq8Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_u64_x4, "q32hq8UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_f16_x4, "q32hq32h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_bf16_x4, "q32hq32y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_f32_x4, "q32hq16f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f16_f64_x4, "q32hq8d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_s8_x4, "q32yq64Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_u8_x4, "q32yq64Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_mf8_x4, "q32yq64m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_s16_x4, "q32yq32s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_u16_x4, "q32yq32Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_s32_x4, "q32yq16i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_u32_x4, "q32yq16Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_s64_x4, "q32yq8Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_u64_x4, "q32yq8UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_f16_x4, "q32yq32h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_bf16_x4, "q32yq32y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_f32_x4, "q32yq16f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_bf16_f64_x4, "q32yq8d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_s8_x4, "q16fq64Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_u8_x4, "q16fq64Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_mf8_x4, "q16fq64m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_s16_x4, "q16fq32s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_u16_x4, "q16fq32Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_s32_x4, "q16fq16i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_u32_x4, "q16fq16Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_s64_x4, "q16fq8Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_u64_x4, "q16fq8UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_f16_x4, "q16fq32h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_bf16_x4, "q16fq32y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_f32_x4, "q16fq16f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f32_f64_x4, "q16fq8d", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_s8_x4, "q8dq64Sc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_u8_x4, "q8dq64Uc", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_mf8_x4, "q8dq64m", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_s16_x4, "q8dq32s", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_u16_x4, "q8dq32Us", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_s32_x4, "q8dq16i", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_u32_x4, "q8dq16Ui", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_s64_x4, "q8dq8Wi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_u64_x4, "q8dq8UWi", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_f16_x4, "q8dq32h", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_bf16_x4, "q8dq32y", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_f32_x4, "q8dq16f", "n", "sme|sve")
TARGET_BUILTIN(__builtin_sve_reinterpret_f64_f64_x4, "q8dq8d", "n", "sme|sve")
#endif

